copyWith method
Returns a copy of this FPortalArrowStyle with the given properties replaced.
See customizing widget styles.
Parameters
- FPortalArrowStyle.cornerSpacing - The minimum spacing between the arrow and the decoration's rounded corners.
- FPortalArrowStyle.baseRadius - The radius of the rounded corners where the arrow's sides meet the decoration's edge.
- FPortalArrowStyle.width - The base's width.
- FPortalArrowStyle.height - The height from base to tip.
- FPortalArrowStyle.tipRadius - The tip's radius.
Implementation
@useResult
FPortalArrowStyle copyWith({
double? cornerSpacing,
double? baseRadius,
double? width,
double? height,
double? tipRadius,
}) => .new(
cornerSpacing: cornerSpacing ?? this.cornerSpacing,
baseRadius: baseRadius ?? this.baseRadius,
width: width ?? this.width,
height: height ?? this.height,
tipRadius: tipRadius ?? this.tipRadius,
);