accessibleNavigation property
True if a screen reader or similar service is changing the interaction model.
Implementation
final bool accessibleNavigation;
True if a screen reader or similar service is changing the interaction model.
final bool accessibleNavigation;