FAccessibilityContext extension type
Provides convenient access to the nearest FAccessibility.
- on
Constructors
- FAccessibilityContext(BuildContext context)
Properties
-
True if a screen reader or similar service is changing the interaction model.
no setter
- context → BuildContext
-
final
- focusHighlight → bool
-
True if focused widgets should show a focus highlight, such as a focus ring.
no setter
- motion → FAccessibilityMotion
-
The motion preference.
no setter