FFocusedOutlineStyle class

The FFocusedOutline's style.

Implemented types
Mixed-in types
Available extensions

Constructors

FFocusedOutlineStyle({required Color color, required BorderRadiusGeometry borderRadius, double width = 1, double spacing = 3})
Creates a FFocusedOutlineStyle.
const

Properties

borderRadius → BorderRadiusGeometry
The border radius.
final
color → Color
The outline's color.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spacing → double
The spacing between the outline and the outlined widget. Can be negative. Defaults to 3.
final
width → double
The outline's width. Defaults to 1.
final

Methods

call(covariant Object _) → FFocusedOutlineStyle
Returns itself.
inherited
copyWith({Color? color, BorderRadiusGeometry? borderRadius, double? width, double? spacing}) → FFocusedOutlineStyle

Available on FFocusedOutlineStyle, provided by the $FFocusedOutlineStyleTransformations extension

Returns a copy of this FFocusedOutlineStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FFocusedOutlineStyle other, double t) → FFocusedOutlineStyle

Available on FFocusedOutlineStyle, provided by the $FFocusedOutlineStyleTransformations extension

Linearly interpolate between this and another FFocusedOutlineStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited