FFormFieldProperties<T> mixin

A form field's properties.

Mixin applications

Properties

autovalidateMode → AutovalidateMode
Used to enable/disable this form field's auto validation and update its error text.
no setter
description → Widget?
The description.
no setter
enabled → bool
Whether the form is able to receive user input.
no setter
errorBuilder → Widget Function(BuildContext context, String message)?
The builder for errors displayed below the description. Defaults to displaying the error message.
no setter
forceErrorText → String?
An optional property that forces the FormFieldState into an error state by directly setting the FormFieldState.errorText property without running the validator function.
no setter
hashCode → int
The hash code for this object.
no setterinherited
label → Widget?
The label.
no setter
onReset → VoidCallback?
An optional method to call when the form field is reset via FormFieldState.reset.
no setter
onSaved → FormFieldSetter<T>?
An optional method to call with the final value when the form is saved via FormState.save.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validator → FormFieldValidator<T>?
An optional method that validates an input. Returns an error string to display if the input is invalid, or null otherwise.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

defaultErrorBuilder(BuildContext context, String error) → Widget
The default builder for errors displayed below the description. Prefixes the message with FIcons.error.
defaultValidator(Object? _) → String?
The default validator that always returns null (no validation error).