FOverlayManagedControl class

An FOverlayManagedControl enables widgets to manage their own controller internally while exposing parameters for common configurations.

Subclass ManagedControl to create variants with different defaults or behaviors, e.g., FCalendarControl.date() vs FCalendarControl.range().

Inheritance

Constructors

FOverlayManagedControl({OverlayPortalController? controller, bool? initial})
Creates a FOverlayControl.
const

Properties

controller OverlayPortalController?
The controller.
final
hashCode int
The hash code for this object.
no setterinherited
initial bool?
Whether the overlay is initially shown. Defaults to false (hidden).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createController() OverlayPortalController
Creates a OverlayPortalController.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited