FPortal class

A portal that "floats" on top of and relative to a child widget.

See:

Inheritance

Constructors

FPortal({required Widget portalBuilder(BuildContext context, OverlayPortalController controller, ValueListenable<FPortalGeometry?> geometry), FOverlayControl control = const .managed(), FPortalConstraints constraints = const FPortalConstraints(), AlignmentGeometry portalAnchor = .topCenter, AlignmentGeometry childAnchor = .bottomCenter, FPortalSpacing spacing = .zero, FPortalOverflow overflow = .flip, Offset offset = .zero, bool useViewPadding = true, bool useViewInsets = true, EdgeInsetsGeometry padding = .zero, OverlayChildLocation overlayLocation = .nearestOverlay, bool traversalGrouped = true, Widget barrier(RenderBox? cutout)?, ValueWidgetBuilder<OverlayPortalController> builder = FOverlay.defaultBuilder, Widget? child, Key? key})
Creates a portal.
const

Properties

barrier → Widget Function(RenderBox? cutout)?
An optional barrier builder that is displayed behind the portal.
final
builder → ValueWidgetBuilder<OverlayPortalController>
An optional builder for the child widget.
final
child → Widget?
The child which the portal is aligned to.
final
childAnchor → AlignmentGeometry
The anchor point on the child used for positioning relative to the portalAnchor.
final
constraints → FPortalConstraints
The portal's size constraints.
final
control → FOverlayControl
The control.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
offset → Offset
Additional translation to apply to the portal's position.
final
overflow → FPortalOverflow
The callback used to shift a portal when it overflows out of the viewport.
final
overlayLocation → OverlayChildLocation
The Overlay that the portal is attached to.
final
padding → EdgeInsetsGeometry
The additional padding between the edges of the view and the edges of the portal.
final
portalAnchor → AlignmentGeometry
The anchor point on the portal used for positioning relative to the childAnchor.
final
portalBuilder → Widget Function(BuildContext context, OverlayPortalController controller, ValueListenable<FPortalGeometry?> geometry)
The portal builder which returns the floating content.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spacing → FPortalSpacing
The spacing between the portalAnchor and childAnchor.
final
traversalGrouped → bool
Whether the portal's content is traversed immediately after the child.
final
useViewInsets → bool
Whether to avoid the platform view's insets (the soft keyboard).
final
useViewPadding → bool
Whether to avoid the platform view's padding (static safe areas like the notch and status bar).
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<FPortal>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited