builder property

An optional builder for the child widget.

Can incorporate a value-independent widget subtree from the child into the returned widget tree.

The child can be null if the entire widget subtree the builder builds does not require the controller.

Implementation

final ValueWidgetBuilder<OverlayPortalController> builder;