FPortalArrowAlignment class abstract interface

How an arrow is positioned along the portal's edge that faces its child.

See:

Constructors

FPortalArrowAlignment.end(double offset)
Places the arrow offset from the portal edge's end.
const
factory
FPortalArrowAlignment.fraction(double fraction)
Places the arrow at a fraction of the portal edge's length from its start.
const
factory
FPortalArrowAlignment.start(double offset)
Places the arrow offset from the portal edge's start.
const
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call({required Axis axis, required TextDirection direction, required double length, required double min, required double max, required double childStart, required double childEnd}) → double?
Returns the arrow's center along the edge, or null to hide the arrow.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

childCenter → const FPortalArrowAlignment
Centers the arrow on the child, shifting it inward if it clashes with the portal's FPortalArrowStyle.cornerSpacing.