FPortalArrowStyleDelta class abstract

A delta that applies modifications to a FPortalArrowStyle.

A FPortalArrowStyle is itself a FPortalArrowStyleDelta.

Mixed-in types
Implementers

Constructors

FPortalArrowStyleDelta.context()
Creates a delta that returns the FPortalArrowStyle in the current context.
const
factory
FPortalArrowStyleDelta.delta({double? cornerSpacing, double? baseRadius, double? width, double? height, double? tipRadius})
Creates a partial modification of a FPortalArrowStyle.
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(covariant FPortalArrowStyle value) FPortalArrowStyle
Applies this delta to the given value.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited