FPortalConstraints class sealed

Size constraints for a portal.

Inheritance
Implementers

Constructors

FPortalConstraints({double minWidth, double maxWidth, double minHeight, double maxHeight})
Creates a FPortalConstraints with the given constraints.
const
factory
FPortalConstraints.tightFor({double? width, double? height})
Creates a FPortalConstraints that require the given width or height.
const
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNormalized → bool
Whether the constraint is expressed in a consistent manner.
no setterinherited
isTight → bool
Whether there is exactly one size possible given these constraints.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

debugAssertIsValid({bool isAppliedConstraint = false, InformationCollector? informationCollector}) → bool
Asserts that the constraints are valid.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited