FPortalSpacing class abstract interface

An interface for computing the spacing between a widget and its portal.

See:

  • Visualization for a visual demonstration of how the spacing works.

Constructors

FPortalSpacing(double spacing, {bool diagonal})
Creates a FPortalSpacing that adds spacing between the anchors of the portal and widget when they do not overlap.
const
factory
FPortalSpacing.spacing(double spacing, {bool diagonal})
Creates a FPortalSpacing that adds spacing between the anchors of the portal and widget when they do not overlap.
const
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(Alignment child, Alignment portal) → Offset
Returns the spacing offset for the portal.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

zero → const FPortalSpacing
A FPortalSpacing that does not apply any spacing.