onDisabledPress property
A callback for when the widget is pressed while disabled. Setting it does not enable the widget.
The widget remains styled and announced as disabled but can receive focus and be activated. Useful for showing feedback, such as a validation error, when a user presses a disabled widget.
Implementation
final VoidCallback? onDisabledPress;