onDoubleTapDown property
A callback for when a pointer that might cause a double tap has contacted the widget.
Analogous to GestureDetector.onDoubleTapDown.
Implementation
final GestureTapDownCallback? onDoubleTapDown;
A callback for when a pointer that might cause a double tap has contacted the widget.
Analogous to GestureDetector.onDoubleTapDown.
final GestureTapDownCallback? onDoubleTapDown;