onLongPressCancel property

GestureLongPressCancelCallback? onLongPressCancel
final

A callback for when the pointer that previously triggered onLongPressDown will not end up causing a long press.

Analogous to GestureDetector.onLongPressCancel.

Implementation

final GestureLongPressCancelCallback? onLongPressCancel;