onLongPressMove property
A callback for when a primary pointer is moving after being recognised as a long press.
Analogous to GestureDetector.onLongPressMoveUpdate.
Implementation
final GestureLongPressMoveUpdateCallback? onLongPressMove;
A callback for when a primary pointer is moving after being recognised as a long press.
Analogous to GestureDetector.onLongPressMoveUpdate.
final GestureLongPressMoveUpdateCallback? onLongPressMove;