onLongPressStart property
A callback for when a long press has been recognised by a primary pointer.
Analogous to GestureDetector.onLongPressStart. Fires alongside onLongPress.
Implementation
final GestureLongPressStartCallback? onLongPressStart;
A callback for when a long press has been recognised by a primary pointer.
Analogous to GestureDetector.onLongPressStart. Fires alongside onLongPress.
final GestureLongPressStartCallback? onLongPressStart;