onPressCancel property
A callback for when a primary pointer that previously triggered onPressDown will not end up causing a tap.
Analogous to GestureDetector.onTapCancel.
Implementation
final GestureTapCancelCallback? onPressCancel;
A callback for when a primary pointer that previously triggered onPressDown will not end up causing a tap.
Analogous to GestureDetector.onTapCancel.
final GestureTapCancelCallback? onPressCancel;