onPressDown property
A callback for when a primary pointer initially contacts the widget.
Analogous to GestureDetector.onTapDown.
Implementation
final GestureTapDownCallback? onPressDown;
A callback for when a primary pointer initially contacts the widget.
Analogous to GestureDetector.onTapDown.
final GestureTapDownCallback? onPressDown;