onSecondaryLongPressDown property

GestureLongPressDownCallback? onSecondaryLongPressDown
final

A callback for when a secondary pointer that might cause a long press has contacted the widget.

Analogous to GestureDetector.onSecondaryLongPressDown.

There is no equivalent GestureDetector.onSecondaryLongPressUp. Use onSecondaryLongPressEnd instead.

Implementation

final GestureLongPressDownCallback? onSecondaryLongPressDown;