onSecondaryLongPressEnd property
A callback for when a long press recognised by a secondary pointer is ending.
Analogous to GestureDetector.onSecondaryLongPressEnd.
Implementation
final GestureLongPressEndCallback? onSecondaryLongPressEnd;
A callback for when a long press recognised by a secondary pointer is ending.
Analogous to GestureDetector.onSecondaryLongPressEnd.
final GestureLongPressEndCallback? onSecondaryLongPressEnd;