onSecondaryPressDown property
A callback for when a secondary pointer initially contacts the widget.
Analogous to GestureDetector.onSecondaryTapDown.
Implementation
final GestureTapDownCallback? onSecondaryPressDown;
A callback for when a secondary pointer initially contacts the widget.
Analogous to GestureDetector.onSecondaryTapDown.
final GestureTapDownCallback? onSecondaryPressDown;