semanticsInMutuallyExclusiveGroup property
Whether this tappable belongs to a mutually exclusive group, such as a radio button. Null if not applicable.
Implementation
final bool? semanticsInMutuallyExclusiveGroup;
Whether this tappable belongs to a mutually exclusive group, such as a radio button. Null if not applicable.
final bool? semanticsInMutuallyExclusiveGroup;