slidePressHapticFeedback property
The haptic feedback for when the user slides from one tappable to another.
Defaults to FHapticFeedback.noFeedback.
Implementation
final Future<void> Function() slidePressHapticFeedback;
The haptic feedback for when the user slides from one tappable to another.
Defaults to FHapticFeedback.noFeedback.
final Future<void> Function() slidePressHapticFeedback;