FTappableStyle class

A FTappable's style.

Implemented types
Mixed-in types
Available extensions

Constructors

FTappableStyle({FVariants<FTappableVariantConstraint, FTappableVariant, MouseCursor, Delta> cursor = const .all(.defer), Duration pressedEnterDuration = const Duration(milliseconds: 100), Duration pressedExitDuration = const Duration(milliseconds: 100), FTappableMotion motion = const FTappableMotion()})
Creates a FTappableStyle.

Properties

cursor → FVariants<FTappableVariantConstraint, FTappableVariant, MouseCursor, Delta>
The mouse cursor for mouse pointers that are hovering over the region. Defaults to MouseCursor.defer.
final
hashCode → int
The hash code for this object.
no setterinherited
motion → FTappableMotion
Motion-related properties for the tappable. Defaults to FTappableMotion.
final
pressedEnterDuration → Duration
The duration to wait before applying the pressed effect after the user presses the tile. Defaults to 100ms.
final
pressedExitDuration → Duration
The duration to wait before removing the pressed effect after the user stops pressing the tile. Defaults to 100ms.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(covariant Object _) → FTappableStyle
Returns itself.
inherited
copyWith({FVariantsValueDelta<FTappableVariantConstraint, FTappableVariant, MouseCursor, Delta>? cursor, Duration? pressedEnterDuration, Duration? pressedExitDuration, FTappableMotionDelta? motion}) → FTappableStyle

Available on FTappableStyle, provided by the $FTappableStyleTransformations extension

Returns a copy of this FTappableStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FTappableStyle other, double t) → FTappableStyle

Available on FTappableStyle, provided by the $FTappableStyleTransformations extension

Linearly interpolate between this and another FTappableStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited