FTypeaheadController class

A TextEditingController with typeahead support.

A typeahead controller manages suggestions and provides inline completions as the user types. When the current text matches the beginning of a suggestion, the remaining text is shown as a completion that can be accepted.

Inheritance
Implementers

Constructors

FTypeaheadController({required FTypeaheadControllerTextStyles textStyles, List<String> suggestions = const [], String? text})
Creates a FTypeaheadController with an optional initial text and completion.
FTypeaheadController.fromValue(TextEditingValue? value, {required FTypeaheadControllerTextStyles textStyles, List<String> suggestions = const []})
Creates a FTypeaheadController from a TextEditingValue.

Properties

current ↔ ({String completion, String replacement})?
The current completion and corresponding replacement text, or null if no completion is available.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
rawValue ↔ TextEditingValue
The raw value of the controller without triggering completion logic.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selection ↔ TextSelection
The currently selected range within text.
getter/setter pairinherited
suggestions → List<String>
The suggestions from which a completion is derived.
no setter
text ↔ String
The current string the user is editing.
getter/setter pairinherited-getteroverride-setter
value ↔ TextEditingValue
The current value stored in this notifier.
getter/setter pairinherited-getteroverride-setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
buildTextSpan({required BuildContext context, required bool withComposing, TextStyle? style}) → TextSpan
Builds TextSpan from current editing value.
override
clear() → void
Set the value to empty.
inherited
clearComposing() → void
Set the composing region to an empty range.
inherited
complete() → void
Completes the current typeahead suggestion by replacing the text with the replacement.
dispose() → void
Discards any resources used by the object.
override
findCompletion([String? text]) → void
Finds and sets the current completion based on the current text and available suggestions.
loadSuggestions(FutureOr<Iterable<String>> suggestions) → Future<void>
Loads suggestions from a Future or an Iterable.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited