FDefaultLocalizations class
The default localization for when no localization is provided.
- Inheritance
-
- Object
- FLocalizations
- FDefaultLocalizations
- Available extensions
Constructors
- FDefaultLocalizations()
-
Creates a FDefaultLocalizations.
factory
Properties
- autocompleteNoResults → String
-
The message displayed when there are no matching results.
no setteroverride
- barrierLabel → String
-
The label for the barrier rendered underneath the content of a bottom sheet (used as the 'modalRouteContentName' of the 'barrierOnTapHint' message).
no setteroverride
- calendarNextMonthSemanticsLabel → String
-
The label for the calendar header's next-month navigation button.
no setteroverride
- calendarNextYearSemanticsLabel → String
-
The label for the calendar header's next-year navigation button.
no setteroverride
- calendarNextYearsSemanticsLabel → String
-
The label for the calendar header's next-years navigation button.
no setteroverride
- calendarPreviousMonthSemanticsLabel → String
-
The label for the calendar header's previous-month navigation button.
no setteroverride
- calendarPreviousYearSemanticsLabel → String
-
The label for the calendar header's previous-year navigation button.
no setteroverride
- calendarPreviousYearsSemanticsLabel → String
-
The label for the calendar header's previous-years navigation button.
no setteroverride
- contextMenuSemanticsLabel → String
-
The semantic label for a context menu.
no setteroverride
- dateFieldHint → String
-
The hint text for the calendar-only date field.
no setteroverride
- dateFieldInvalidDateError → String
-
Error message displayed to the user when they have entered a text string in a time field that is not in a valid time format.
no setteroverride
- dateTimePickerToday → String
-
The label for today's date in the date time picker.
no setteroverride
- dialogSemanticsLabel → String
-
The sheet's label.
no setteroverride
- firstDayOfWeek → int
-
Available on FLocalizations, provided by the FDateTimeLocalizations extension
The first day of the week, in ISO 8601 style, where the first day of the week, i.e. index 1, is Monday.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- localeName → String
-
finalinherited
- multiSelectHint → String
-
The hint text for the multi-select field.
no setteroverride
-
narrowWeekDays
→ List<
String> -
Available on FLocalizations, provided by the FDateTimeLocalizations extension
Very short names for days of the week, starting with Sunday, e.g. 'Su'.no setter - paginationNextSemanticsLabel → String
-
The label for the next button in a pagination control.
no setteroverride
- paginationPreviousSemanticsLabel → String
-
The label for the previous button in a pagination control.
no setteroverride
- passwordFieldLabel → String
-
The password text field's label.
no setteroverride
- passwordFieldObscureTextButtonSemanticsLabel → String
-
The semantic label for the unobscure text button in a text field when the text is obscured.
no setteroverride
- passwordFieldUnobscureTextButtonSemanticsLabel → String
-
No description provided for @passwordFieldUnobscureTextButtonSemanticsLabel.
no setteroverride
- popoverSemanticsLabel → String
-
The semantic label for a popover.
no setteroverride
- progressSemanticsLabel → String
-
The default semantics label for a progress indicator.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectHint → String
-
The hint text for the select field.
no setteroverride
- selectNoResults → String
-
The message displayed when there are no matching results.
no setteroverride
- selectScrollDownSemanticsLabel → String
-
The semantic label for the scroll handle in a select field.
no setteroverride
- selectScrollUpSemanticsLabel → String
-
The semantic label for the scroll handle in a select field.
no setteroverride
- selectSearchHint → String
-
The hint text for the search field in a select field.
no setteroverride
- sheetSemanticsLabel → String
-
The semantic label for a sheet.
no setteroverride
- shortDateSeparator → String
-
The short date's separator, typically /.
no setteroverride
- shortDateSuffix → String
-
The short date's suffix, typically empty.
no setteroverride
-
shortWeekDays
→ List<
String> -
Available on FLocalizations, provided by the FDateTimeLocalizations extension
Short names for days of the week, starting with Sunday, e.g. 'Sun'.no setter - textFieldClearButtonSemanticsLabel → String
-
The semantic label for the clear button in a text field.
no setteroverride
- textFieldEmailLabel → String
-
The email text field's label.
no setteroverride
- timeFieldHint → String
-
The hint text for the picker-only time field.
no setteroverride
- timeFieldInvalidDateError → String
-
No description provided for @timeFieldInvalidDateError.
no setteroverride
- timeFieldPeriodSeparator → String
-
The time field's period separator, typically ' '.
no setteroverride
- timeFieldSuffix → String
-
The time field's suffix, typically none.
no setteroverride
- timeFieldTimeSeparator → String
-
The time field's time separator, typically ':'.
no setteroverride
Methods
-
barrierOnTapHint(
String modalRouteContentName) → String -
The onTapHint for the barrier rendered underneath the content of a modal route (especially a sheet) which users can tap to dismiss the content.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited