theme library

Classes and functions for configuring the Forui widgets' theme. A theme configures the colors and typographic choices of Forui widgets.

Classes

BoxDecorationDelta
A delta that applies modifications to a BoxDecoration.
DecorationDelta
A delta that applies modifications to a Decoration.
EdgeInsetsDelta
A delta that applies modifications to an EdgeInsets.
EdgeInsetsDirectionalDelta
A delta that applies modifications to an EdgeInsetsDirectional.
EdgeInsetsGeometryDelta
A delta that applies modifications to an EdgeInsetsGeometry.
FAdaptiveScope
Provides the current platform variant down the widget tree.
FBasicTheme
Applies a theme to descendant widgets.
FBorderRadius
Tokens for the various border radius sizes.
FBreakpoints
The responsive breakpoints based on Tailwind CSS.
FColors
The color tokens.
FFormFieldStyle
A form field state's style.
FFormFieldStyleDelta
A delta that applies modifications to a FFormFieldStyle.
FHapticFeedback
The haptic feedback configuration.
FIcons
The icon tokens used by Forui's widgets. Defaults to icons in FLucideIcons.
FPlatformThemeData
A pair of FThemeData for desktop and touch platforms.
FScalableExtension<T extends FScalableExtension<T>>
A ThemeExtension that scales with the font size scalar, used for typographical tokens in a FTypography and FTypeface.
FSizes
Reference tokens for the various size categories. Changing these values will not update the sizes of actual widgets.
FStyle
A set of miscellaneous tokens that are part of a FThemeData.
FStyleDelta
A delta that applies modifications to a FStyle.
FTheme
Applies a theme to descendant widgets with animated transitions over a given duration whenever the provided FThemeData changes.
FThemeData
Defines the configuration of the overall visual FTheme for a widget subtree.
FThemeMotion
The motion-related properties for FTheme.
FThemeMotionDelta
A delta that applies modifications to a FThemeMotion.
FTypeface
Typographical tokens across different sizes, which are based on Tailwind CSS.
FTypography
The typographical tokens grouped by their semantic roles.
FVariant
Represents a condition under which a widget can be styled differently.
FVariantConstraint
Represents a combination of variants under which a widget can be styled differently.
FVariantOperation<K extends FVariantConstraint, E extends FVariant, V, D extends Delta>
An operation in FVariantsDelta.delta that modifies FVariants using deltas.
FVariants<K extends FVariantConstraint, E extends FVariant, V, D extends Delta>
Maps variant constraints to values.
FVariantsDelta<K extends FVariantConstraint, E extends FVariant, V, D extends Delta>
Describes modifications to an FVariants in terms of deltas.
FVariantsValueDelta<K extends FVariantConstraint, E extends FVariant, V, D extends Delta>
A delta that describes modifications to an FVariants in terms of concrete values.
FVariantValueDeltaOperation<K extends FVariantConstraint, E extends FVariant, V, D extends Delta>
An operation in FVariantsValueDelta.delta that modifies FVariants using concrete values.
IconThemeDataDelta
A delta that applies modifications to an IconThemeData.
ShapeDecorationDelta
A delta that applies modifications to a ShapeDecoration.
TextStyleDelta
A delta that applies modifications to a TextStyle.

Mixins

Delta
A mixin for types that can be applied to a base value to produce a new value.

Extension Types

FFormFieldErrorVariant
Represents a variant.
FFormFieldErrorVariantConstraint
Represents a combination of variants.
FFormFieldVariant
Represents a variant.
FFormFieldVariantConstraint
Represents a combination of variants.
FPlatformVariant
Represents a platform.
FPlatformVariantConstraint
Represents a combination of platform variants.

Extensions

$FFormFieldStyleTransformations on FFormFieldStyle
Provides copyWith and lerp methods.
$FStyleTransformations on FStyle
Provides copyWith and lerp methods.
$FThemeMotionTransformations on FThemeMotion
Provides copyWith and lerp methods.
Decorations on Decoration
Provides function to access common visual properties from a Decoration.
FBuildContext on BuildContext
Provides functions for accessing the current FThemeData.
Sentinels on Never
Special values that indicate the absence of a value of a particular type.

Functions

toVariants(Set<WidgetState> states) Set<FVariant>
Converts a set of WidgetStates to a set of FVariants.

Typedefs

FIconBuilder = Widget Function(BuildContext context, {String? semanticsLabel})
Builds an icon given a BuildContext. The icon inherits its size/color from the ambient IconTheme; callers should wrap the builder's result in an IconTheme with the desired IconThemeData.