EdgeInsetsGeometryDelta class abstract

A delta that applies modifications to an EdgeInsetsGeometry.

Mixed-in types

Constructors

EdgeInsetsGeometryDelta.add(EdgeInsetsGeometry insets)
Creates an additive modification, adding the specified insets to the current edges.
const
factory
EdgeInsetsGeometryDelta.scale(double factor)
Scales all edges by factor. Preserves the concrete type (i.e. EdgeInsets stays EdgeInsets, EdgeInsetsDirectional stays EdgeInsetsDirectional).
const
factory
EdgeInsetsGeometryDelta.value(EdgeInsetsGeometry insets)
Creates a complete replacement for an EdgeInsetsGeometry.
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(covariant EdgeInsetsGeometry? insets) EdgeInsetsGeometry
Applies this delta to the given value.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited