FBorderRadius class final

Tokens for the various border radius sizes.

Mixed-in types

Constructors

FBorderRadius({BorderRadius xs2 = const .all(.circular(4)), BorderRadius xs = const .all(.circular(6)), BorderRadius sm = const .all(.circular(8)), BorderRadius md = const .all(.circular(10)), BorderRadius lg = const .all(.circular(14)), BorderRadius xl = const .all(.circular(18)), BorderRadius xl2 = const .all(.circular(22)), BorderRadius xl3 = const .all(.circular(26)), BorderRadius pill = const .all(.circular(100))})
Creates an FBorderRadius.
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
lg → BorderRadius
The large border radius. Defaults to 14px.
final
md → BorderRadius
The medium border radius. Defaults to 10px.
final
pill → BorderRadius
The pill border radius. Defaults to 100px.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sm → BorderRadius
The small border radius. Defaults to 8px.
final
xl → BorderRadius
The extra-large border radius. Defaults to 18px.
final
xl2 → BorderRadius
The extra-large border radius. Defaults to 22px.
final
xl3 → BorderRadius
The extra-large border radius. Defaults to 26px.
final
xs → BorderRadius
The extra-small border radius. Defaults to 6px.
final
xs2 → BorderRadius
The extra-extra-small border radius. Defaults to 4px.
final

Methods

copyWith({BorderRadius? xs2, BorderRadius? xs, BorderRadius? sm, BorderRadius? md, BorderRadius? lg, BorderRadius? xl, BorderRadius? xl2, BorderRadius? xl3, BorderRadius? pill}) → FBorderRadius
Returns a copy of this FBorderRadius with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
lerp(FBorderRadius other, double t) → FBorderRadius
Linearly interpolate between this and other using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scale(double scalar) → FBorderRadius
Scales all border radii by the given scalar.
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override