FCapturedTheme class

Similar to InheritedTheme.capture, FCapturedTheme captures FTheme's fields from one BuildContext to another. This is typically used when a navigator pushes a new route.

See:

Constructors

FCapturedTheme({ValueListenable<FThemeData>? theme, ValueListenable<FAccessibility>? accessibility, ValueListenable<FPlatformVariant>? platform})
Creates a FCapturedTheme.
const

Properties

accessibility ValueListenable<FAccessibility>?
The captured accessibility features, or null if no accessibility scope was captured.
final
hashCode int
The hash code for this object.
no setterinherited
platform ValueListenable<FPlatformVariant>?
The captured platform variant, or null if no adaptive scope was captured.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
theme ValueListenable<FThemeData>?
The captured theme data, or null if no theme was captured.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
wrap(Widget child) Widget
Wraps the given child in widgets that re-establish and observe the captured scopes.

Operators

operator ==(Object other) bool
The equality operator.
inherited