brightness property
The system brightness.
This is typically used to determine the appearance of native UI elements such as on-screen keyboards.
The system brightness.
This is typically used to determine the appearance of native UI elements such as on-screen keyboards.