systemOverlayStyle property
The system overlay style.
This is typically used to determine the appearance of native system overlays such as status bars.
The system overlay style.
This is typically used to determine the appearance of native system overlays such as status bars.