FFormFieldErrorVariantConstraint extension type
Represents a combination of variants.
See also:
- FFormFieldErrorVariant, which represents individual variants.
- on
- Implemented types
- Implementers
Constructors
- FFormFieldErrorVariantConstraint.not(FFormFieldErrorVariant variant)
-
Creates a FFormFieldErrorVariantConstraint that negates
variant.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
and(
FFormFieldErrorVariantConstraint other) → FFormFieldErrorVariantConstraint -
Combines this with
otherusing a logical AND operation. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
satisfiedBy(
Set< FVariant> variants) → bool -
Returns true if all variants in this constraint are present in
variants.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- android → const FFormFieldErrorVariant
- The Android platform variant.
- desktop → const FFormFieldErrorVariant
- A platform variant that matches all desktop-based platforms, windows, macOS and linux.
- disabled → const FFormFieldErrorVariant
- The semantic variant when this widget is disabled and cannot be interacted with.
- fuchsia → const FFormFieldErrorVariant
- The Fuchsia platform variant.
- iOS → const FFormFieldErrorVariant
- The iOS platform variant.
- linux → const FFormFieldErrorVariant
- The Linux platform variant.
- macOS → const FFormFieldErrorVariant
- The macOS platform variant.
- touch → const FFormFieldErrorVariant
- A platform variant that matches all touch-based platforms, android, iOS and fuchsia.
- web → const FFormFieldErrorVariant
- The web platform variant.
- windows → const FFormFieldErrorVariant
- The Windows platform variant.