errorNotification property
Provides a haptic feedback indicating that a task or action has failed.
Defaults to HapticFeedback.errorNotification.
Provides a haptic feedback indicating that a task or action has failed.
Defaults to HapticFeedback.errorNotification.