heavyImpact property
Provides a haptic feedback corresponding to a collision impact with a heavy mass.
Defaults to HapticFeedback.heavyImpact.
Implementation
final Future<void> Function() heavyImpact;
Provides a haptic feedback corresponding to a collision impact with a heavy mass.
Defaults to HapticFeedback.heavyImpact.
final Future<void> Function() heavyImpact;