successNotification property
Provides a haptic feedback indicating that a task or action has completed successfully.
Defaults to HapticFeedback.successNotification.
Provides a haptic feedback indicating that a task or action has completed successfully.
Defaults to HapticFeedback.successNotification.