warningNotification property
Provides a haptic feedback indicating that a task or action has produced a warning.
Defaults to HapticFeedback.warningNotification.
Provides a haptic feedback indicating that a task or action has produced a warning.
Defaults to HapticFeedback.warningNotification.