An icon that is used by Forui widgets.
Contract
Subclasses should implement == and hashCode so that two icons that render the same glyph are equal. Not doing so may cause widgets to "flicker" whenever the same FThemeData is recreated.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
BuildContext context, {String? semanticsLabel}) → Widget - Builds an icon given a BuildContext.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited