FStyle class

A set of miscellaneous tokens that are part of a FThemeData.

Implemented types
Mixed-in types
Available extensions

Constructors

FStyle({required FFormFieldStyle formFieldStyle, required FFocusedOutlineStyle focusedOutlineStyle, required IconThemeData iconStyle, required FSizes sizes, required FTappableStyle tappableStyle, FBorderRadius borderRadius = const FBorderRadius(), double borderWidth = 1, EdgeInsets pagePadding = const .symmetric(vertical: 8, horizontal: 12), List<BoxShadow> shadow = const [BoxShadow(color: Color(0x0d000000), offset: Offset(0, 1), blurRadius: 2)], Iterable<ThemeExtension> extensions = const []})
Creates an FStyle.
FStyle.inherit({required FColors colors, required FTypography typography, required bool touch})
Creates an FStyle that inherits its properties.
factory

Properties

borderRadius → FBorderRadius
The border radius.
final
borderWidth → double
The border width. Defaults to 1.
final
extensions → Set<ThemeExtension>
All ThemeExtensions defined in this style.
no setter
focusedOutlineStyle → FFocusedOutlineStyle
The focused outline style.
final
formFieldStyle → FFormFieldStyle
The style for the form field.
final
hashCode → int
The hash code for this object.
no setterinherited
iconStyle → IconThemeData
The icon style.
final
pagePadding → EdgeInsets
The page's padding. Defaults to EdgeInsets.symmetric(vertical: 8, horizontal: 12).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadow → List<BoxShadow>
The shadow used for elevated widgets.
final
sizes → FSizes
The size tokens.
final
tappableStyle → FTappableStyle
The tappable style.
final

Methods

call(covariant Object _) → FStyle
Returns itself.
inherited
copyWith({FFormFieldStyleDelta? formFieldStyle, FFocusedOutlineStyleDelta? focusedOutlineStyle, IconThemeDataDelta? iconStyle, FSizes? sizes, FTappableStyleDelta? tappableStyle, FBorderRadius? borderRadius, double? borderWidth, EdgeInsetsDelta? pagePadding, List<BoxShadow>? shadow, Set<ThemeExtension>? extensions}) → FStyle

Available on FStyle, provided by the $FStyleTransformations extension

Returns a copy of this FStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
extension<T extends Object>() → T
Obtains a particular ThemeExtension.
lerp(FStyle other, double t) → FStyle

Available on FStyle, provided by the $FStyleTransformations extension

Linearly interpolate between this and another FStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited