fontFamilyFallback property
The font families to use as fallbacks when a glyph is not found in fontFamily. Defaults to an empty list.
Implementation
final List<String> fontFamilyFallback;
The font families to use as fallbacks when a glyph is not found in fontFamily. Defaults to an empty list.
final List<String> fontFamilyFallback;