xs3 property
The font size for extra extra extra small text.
Defaults to:
- Desktop —
fontSize= 8,height= 1. - Touch —
fontSize= 10,height= 1.
Implementation
final TextStyle xs3;
The font size for extra extra extra small text.
Defaults to:
fontSize = 8, height = 1.fontSize = 10, height = 1.final TextStyle xs3;