ShapeDecorationDelta class abstract

A delta that applies modifications to a ShapeDecoration.

Mixed-in types

Constructors

ShapeDecorationDelta.delta({Color? color, DecorationImage? image, Gradient? gradient, List<BoxShadow>? shadows, ShapeBorder? shape})
Creates a partial modification of a ShapeDecoration.
const
factory
ShapeDecorationDelta.value(ShapeDecoration decoration)
Creates a complete replacement for a ShapeDecoration.
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(covariant ShapeDecoration? decoration) ShapeDecoration
Applies this delta to the given value.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited