FAccordionMotionDelta class abstract
A delta that applies modifications to a FAccordionMotion.
A FAccordionMotion is itself a FAccordionMotionDelta.
- Mixed-in types
- Implementers
Constructors
- FAccordionMotionDelta.context()
-
Creates a delta that returns the FAccordionMotion in the current context.
constfactory
-
FAccordionMotionDelta.delta({Duration? expandDuration, Duration? collapseDuration, Curve? expandCurve, Curve? collapseCurve, Curve? iconExpandCurve, Curve? iconCollapseCurve, Animatable<
double> ? revealTween, Animatable<double> ? iconTween}) -
Creates a partial modification of a FAccordionMotion.
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
covariant FAccordionMotion value) → FAccordionMotion -
Applies this delta to the given value.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited