FAlertStyle class final

A FAlert style.

Implemented types
Mixed-in types
Available extensions

Constructors

FAlertStyle({required Decoration decoration, required IconThemeData iconStyle, required TextStyle titleTextStyle, required TextStyle subtitleTextStyle, EdgeInsetsGeometry padding = const .symmetric(horizontal: 16, vertical: 12)})
Creates a FAlertStyle.

Properties

decoration Decoration
The decoration.
final
hashCode int
The hash code for this object.
no setterinherited
iconStyle IconThemeData
The icon's style.
final
padding EdgeInsetsGeometry
The padding. Defaults to EdgeInsets.symmetric(horizontal: 16, vertical: 12).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitleTextStyle TextStyle
The subtitle's TextStyle.
final
titleTextStyle TextStyle
The title's TextStyle.
final

Methods

call(covariant Object _) FAlertStyle
Returns itself.
inherited
copyWith({DecorationDelta? decoration, EdgeInsetsGeometryDelta? padding, IconThemeDataDelta? iconStyle, TextStyleDelta? titleTextStyle, TextStyleDelta? subtitleTextStyle}) FAlertStyle

Available on FAlertStyle, provided by the $FAlertStyleTransformations extension

Returns a copy of this FAlertStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FAlertStyle other, double t) FAlertStyle

Available on FAlertStyle, provided by the $FAlertStyleTransformations extension

Linearly interpolate between this and another FAlertStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited