contentBuilder property
A callback builds the list of items based on search results returned by filter.
Implementation
final FAutocompleteContentBuilder<T> contentBuilder;
A callback builds the list of items based on search results returned by filter.
final FAutocompleteContentBuilder<T> contentBuilder;