contentErrorBuilder property

Widget Function(BuildContext context, FAutocompleteContentStyle style, Object? error, StackTrace stackTrace)? contentErrorBuilder
final

A callback that is used to show an error message when filter is asynchronous and fails. Defaults to defaultContentErrorBuilder.

Pass null to hide the popover entirely when there is an error.

Implementation

final Widget Function(BuildContext context, FAutocompleteContentStyle style, Object? error, StackTrace stackTrace)?
contentErrorBuilder;