retainFocus property

bool? retainFocus
final

Whether the field should retain focus after a suggestion is tapped.

Defaults to true on desktop and false on touch.

Implementation

final bool? retainFocus;