FAutocompleteContentStyle class

An FAutocomplete's content style.

Inheritance
Implemented types
Mixed-in types
Available extensions

Constructors

FAutocompleteContentStyle({required TextStyle emptyTextStyle, required FCircularProgressStyle progressStyle, required FAutocompleteSectionStyle sectionStyle, required Decoration decoration, EdgeInsetsGeometry padding = const .symmetric(vertical: 6), ImageFilter barrierFilter(BuildContext context, double animation)?, ImageFilter backgroundFilter(BuildContext context, double animation)?, EdgeInsetsGeometry popoverPadding = const .all(5), FPortalArrowStyle arrowStyle = const FPortalArrowStyle(), FPopoverMotion motion = const FPopoverMotion()})
Creates an FAutocompleteContentStyle.
FAutocompleteContentStyle.inherit({required FColors colors, required FTypography typography, required FStyle style, required bool touch})
Creates a FAutocompleteContentStyle that inherits its properties.

Properties

arrowStyle → FPortalArrowStyle
no setterinherited
backgroundFilter → ImageFilter Function(BuildContext context, double animation)?
no setterinherited
barrierFilter → ImageFilter Function(BuildContext context, double animation)?
no setterinherited
decoration → Decoration
no setterinherited
emptyTextStyle → TextStyle
The default text style when there are no results.
final
hashCode → int
The hash code for this object.
no setterinherited
motion → FPopoverMotion
no setterinherited
padding → EdgeInsetsGeometry
The padding surrounding the content. Defaults to const EdgeInsets.symmetric(vertical: 6).
final
popoverPadding → EdgeInsetsGeometry
no setterinherited
progressStyle → FCircularProgressStyle
The loading progress's style.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sectionStyle → FAutocompleteSectionStyle
The section's style.
final

Methods

call(covariant Object _) → FAutocompleteContentStyle
Returns itself.
inherited
copyWith({TextStyleDelta? emptyTextStyle, FCircularProgressStyleDelta? progressStyle, FAutocompleteSectionStyleDelta? sectionStyle, EdgeInsetsGeometryDelta? padding, DecorationDelta? decoration, ImageFilter Function(BuildContext context, double animation)? barrierFilter()?, ImageFilter Function(BuildContext context, double animation)? backgroundFilter()?, EdgeInsetsGeometryDelta? popoverPadding, FPortalArrowStyleDelta? arrowStyle, FPopoverMotionDelta? motion}) → FAutocompleteContentStyle

Available on FAutocompleteContentStyle, provided by the $FAutocompleteContentStyleTransformations extension

Returns a copy of this FAutocompleteContentStyle with the given properties replaced.
copyWith({DecorationDelta? decoration, ImageFilter barrierFilter(BuildContext context, double animation)? = Sentinels.imageFilterFunction, ImageFilter backgroundFilter(BuildContext context, double animation)? = Sentinels.imageFilterFunction, EdgeInsetsGeometryDelta? popoverPadding, FPortalArrowStyleDelta? arrowStyle, FPopoverMotionDelta? motion}) → FPopoverStyle

Available on FPopoverStyle, provided by the $FPopoverStyleTransformations extension

Returns a copy of this FPopoverStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FAutocompleteContentStyle other, double t) → FAutocompleteContentStyle

Available on FAutocompleteContentStyle, provided by the $FAutocompleteContentStyleTransformations extension

Linearly interpolate between this and another FAutocompleteContentStyle using the given factor t.
lerp(FPopoverStyle other, double t) → FPopoverStyle

Available on FPopoverStyle, provided by the $FPopoverStyleTransformations extension

Linearly interpolate between this and another FPopoverStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited