FAutocompleteContentStyleDelta.delta constructor
const
FAutocompleteContentStyleDelta.delta({
- TextStyleDelta? emptyTextStyle,
- EdgeInsetsGeometryDelta? padding,
- FCircularProgressStyleDelta? progressStyle,
- FAutocompleteSectionStyleDelta? sectionStyle,
- DecorationDelta? decoration,
- ImageFilter Function(double)? barrierFilter()?,
- ImageFilter Function(double)? backgroundFilter()?,
- EdgeInsetsGeometryDelta? popoverPadding,
Creates a partial modification of a FAutocompleteContentStyle.
Parameters
- FAutocompleteContentStyle.emptyTextStyle - The default text style when there are no results.
- FAutocompleteContentStyle.padding - The padding surrounding the content.
- FAutocompleteContentStyle.progressStyle - The loading progress's style.
- FAutocompleteContentStyle.sectionStyle - The section's style.
- FAutocompleteContentStyle.decoration - The popover's decoration.
- FAutocompleteContentStyle.barrierFilter - An optional callback that takes the current animation transition value (0.0 to 1.0) and returns an ImageFilter that is used as the barrier.
- FAutocompleteContentStyle.backgroundFilter - An optional callback that takes the current animation transition value (0.0 to 1.0) and returns an ImageFilter that is used as the background.
- FAutocompleteContentStyle.popoverPadding - The additional padding between the edges of the view and the edges of the popover.
Implementation
const factory FAutocompleteContentStyleDelta.delta({
TextStyleDelta? emptyTextStyle,
EdgeInsetsGeometryDelta? padding,
FCircularProgressStyleDelta? progressStyle,
FAutocompleteSectionStyleDelta? sectionStyle,
DecorationDelta? decoration,
ImageFilter Function(double)? Function()? barrierFilter,
ImageFilter Function(double)? Function()? backgroundFilter,
EdgeInsetsGeometryDelta? popoverPadding,
}) = _FAutocompleteContentStyleDelta;