FAutocompleteController class

A controller for managing autocomplete functionality in a text field.

Inheritance

Constructors

FAutocompleteController({String? text, List<String> suggestions = const []})
Creates a FAutocompleteController with an optional initial text and suggestions.
FAutocompleteController.fromValue(TextEditingValue? value, {List<String> suggestions = const []})
Creates a FAutocompleteController from a TextEditingValue.

Properties

current ↔ ({String completion, String replacement})?
The current completion and corresponding replacement text, or null if no completion is available.
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
rawValue ↔ TextEditingValue
The raw value of the controller without triggering completion logic.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selection ↔ TextSelection
The currently selected range within text.
getter/setter pairinherited
suggestions → List<String>
The suggestions from which a completion is derived.
no setterinherited
text ↔ String
The current string the user is editing.
getter/setter pairinherited
value ↔ TextEditingValue
The current value stored in this notifier.
getter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
buildTextSpan({required BuildContext context, required bool withComposing, TextStyle? style}) → TextSpan
Builds TextSpan from current editing value.
inherited
clear() → void
Set the value to empty.
inherited
clearComposing() → void
Set the composing region to an empty range.
inherited
complete() → void
Completes the current typeahead suggestion by replacing the text with the replacement.
inherited
dispose() → void
Discards any resources used by the object.
inherited
findCompletion([String? text]) → void
Finds and sets the current completion based on the current text and available suggestions.
inherited
loadSuggestions(FutureOr<Iterable<String>> suggestions) → Future<void>
Loads suggestions from a Future or an Iterable.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited