FAutocompleteItem<T> class abstract

A suggestion in a FAutocomplete that can optionally be nested in a FAutocompleteSection.

Inheritance
Mixed-in types

Constructors

FAutocompleteItem({required T value, FItemStyleDelta style, bool? enabled, Widget? prefix, Widget? title, Widget? subtitle, Widget? suffix, Key? key})
Creates a FAutocompleteItem with a custom title and value.
factory
FAutocompleteItem.item({required T value, FItemStyleDelta style, bool? enabled, Widget? prefix, Widget? title, Widget? subtitle, Widget? suffix, Key? key})
Creates a FAutocompleteItem with a custom title and value.
factory
FAutocompleteItem.raw({required Widget child, required T value, FItemStyleDelta style, bool? enabled, Widget? prefix, Key? key})
Creates a FAutocompleteItem with raw layout that delegates to FItem.raw.
factory

Properties

enabled → bool?
True if the item is enabled. Disabled items cannot be selected, and is skipped during traversal.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
prefix → Widget?
A prefix.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → FItemStyleDelta
The style. Defaults to the FItemStyle inherited from the parent FAutocompleteSection or FAutocomplete.
final
value → T
The value.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
inherited
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited