FAutocompleteSection<T> class

A section in a FAutocomplete that can contain multiple FAutocompleteItems.

Inheritance
Mixed-in types

Constructors

FAutocompleteSection({required Widget label, required List<T> items, FAutocompleteSectionStyleDelta style = const .context(), bool? enabled, FItemDivider divider = .none, Key? key})
Creates a FAutocompleteSection from the given items.
FAutocompleteSection.rich({required Widget label, required List<FAutocompleteItem<T>> children, FAutocompleteSectionStyleDelta style = const .context(), bool? enabled, FItemDivider divider = .none, Key? key})
Creates a FAutocompleteSection with the given children.
const

Properties

children → List<FAutocompleteItem<T>>
The nested FAutocompleteItems.
final
divider → FItemDivider
The divider style. Defaults to the FItemDivider inherited from the parent FAutocomplete. Defaults to FItemDivider.none.
final
enabled → bool?
True if the section is enabled. Disabled sections cannot be selected, and is skipped during traversal.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label → Widget
The label.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → FAutocompleteSectionStyleDelta
The style. Defaults to the FAutocompleteSectionStyle inherited from the parent FAutocomplete.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited