FAutocompleteSectionStyleDelta.delta constructor
const
FAutocompleteSectionStyleDelta.delta({
- FVariantsDelta<
FAutocompleteSectionVariantConstraint, FAutocompleteSectionVariant, TextStyle, TextStyleDelta> ? labelTextStyle, - EdgeInsetsGeometryDelta? labelPadding,
- FVariantsValueDelta<
FItemGroupVariantConstraint, FItemGroupVariant, Color, Delta> ? dividerColor, - double? dividerWidth,
- FItemStyleDelta? itemStyle,
- double? spacing,
Creates a partial modification of a FAutocompleteSectionStyle.
Parameters
- FAutocompleteSectionStyle.labelTextStyle - The enabled label's text style.
- FAutocompleteSectionStyle.labelPadding - The padding around the label.
- FAutocompleteSectionStyle.dividerColor - The color of the divider between items in this section.
- FAutocompleteSectionStyle.dividerWidth - The width of the divider between items in this section.
- FAutocompleteSectionStyle.itemStyle - The section's items' style.
- FAutocompleteSectionStyle.spacing - The spacing below the section.
Implementation
const factory FAutocompleteSectionStyleDelta.delta({
FVariantsDelta<FAutocompleteSectionVariantConstraint, FAutocompleteSectionVariant, TextStyle, TextStyleDelta>?
labelTextStyle,
EdgeInsetsGeometryDelta? labelPadding,
FVariantsValueDelta<FItemGroupVariantConstraint, FItemGroupVariant, Color, Delta>? dividerColor,
double? dividerWidth,
FItemStyleDelta? itemStyle,
double? spacing,
}) = _FAutocompleteSectionStyleDelta;