FAutocompleteStyle class

An FAutocomplete's style.

Implemented types
Mixed-in types
Available extensions

Constructors

FAutocompleteStyle({required FAutocompleteFieldSizeStyles fieldStyles, required FAutocompleteContentStyle contentStyle})
Creates a FAutocompleteStyle.
FAutocompleteStyle.inherit({required FColors colors, required FTypography typography, required FStyle style, required bool touch})
Creates a FAutocompleteStyle that inherits its properties.

Properties

contentStyle FAutocompleteContentStyle
The content's style.
final
fieldStyles FAutocompleteFieldSizeStyles
The field's styles.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(covariant Object _) FAutocompleteStyle
Returns itself.
inherited
copyWith({FVariantsDelta<FTextFieldSizeVariantConstraint, FTextFieldSizeVariant, FAutocompleteFieldStyle, FAutocompleteFieldStyleDelta>? fieldStyles, FAutocompleteContentStyleDelta? contentStyle}) FAutocompleteStyle

Available on FAutocompleteStyle, provided by the $FAutocompleteStyleTransformations extension

Returns a copy of this FAutocompleteStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FAutocompleteStyle other, double t) FAutocompleteStyle

Available on FAutocompleteStyle, provided by the $FAutocompleteStyleTransformations extension

Linearly interpolate between this and another FAutocompleteStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited