FAvatarStyle class

FAvatar's style.

All motion is automatically disabled when FAccessibility.motion is FAccessibilityMotion.disabled.

Implemented types
Mixed-in types
Available extensions

Constructors

FAvatarStyle({required Color backgroundColor, required Color foregroundColor, required TextStyle textStyle, required FIcon fallbackIcon, Duration fadeInDuration = const Duration(milliseconds: 500)})
Creates a FAvatarStyle.
const
FAvatarStyle.inherit({required FColors colors, required FIcons icons, required FTypography typography})
Creates a FAvatarStyle that inherits its properties.

Properties

backgroundColor → Color
The fallback's background color.
final
fadeInDuration → Duration
Duration for the transition animation. Defaults to 500ms.
final
fallbackIcon → FIcon
The fallback icon builder shown when no image is loaded. Defaults to FIcons.userRound.
final
foregroundColor → Color
The fallback's color.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textStyle → TextStyle
The text style for the fallback text.
final

Methods

call(covariant Object _) → FAvatarStyle
Returns itself.
inherited
copyWith({Color? backgroundColor, Color? foregroundColor, TextStyleDelta? textStyle, FIcon? fallbackIcon, Duration? fadeInDuration}) → FAvatarStyle

Available on FAvatarStyle, provided by the $FAvatarStyleTransformations extension

Returns a copy of this FAvatarStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FAvatarStyle other, double t) → FAvatarStyle

Available on FAvatarStyle, provided by the $FAvatarStyleTransformations extension

Linearly interpolate between this and another FAvatarStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited