fallbackIcon property
The fallback icon builder shown when no image is loaded. Defaults to FIcons.userRound.
Implementation
@override
final FIconBuilder fallbackIcon;
The fallback icon builder shown when no image is loaded. Defaults to FIcons.userRound.
@override
final FIconBuilder fallbackIcon;