widgets/badge library Widgets

A badge. Badges are typically used to draw attention to specific information, such as labels and counts.

See https://forui.dev/docs/widgets/data/badge for working examples.

Classes

FBadge
A badge. Badges are typically used to draw attention to specific information, such as labels and counts.
FBadgeStyle
A FBadge's style.
FBadgeStyleDelta
A delta that applies modifications to a FBadgeStyle.

Extension Types

FBadgeStyles
The FBadgeStyles.
FBadgeVariant
Represents a variant.
FBadgeVariantConstraint
Represents a combination of variants.

Extensions

$FBadgeStyleTransformations on FBadgeStyle
Provides copyWith and lerp methods.