FBadgeStyles extension type

The FBadgeStyles.

on
Implemented types

Constructors

FBadgeStyles(FVariants<FBadgeVariantConstraint, FBadgeVariant, FBadgeStyle, FBadgeStyleDelta> _)
FBadgeStyles.inherit({required FColors colors, required FTypography typography, required FStyle style, required bool touch})
Creates a FBadgeStyles that inherits its properties.
factory

Properties

base FBadgeStyle
The base variant.
finalinherited
destructive FBadgeStyle
The destructive badge style.
no setter
hashCode int
The hash code for this object.
no setterinherited
outline FBadgeStyle
The outline badge style.
no setter
primary FBadgeStyle
The primary badge style.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondary FBadgeStyle
The secondary badge style.
no setter
variants Map<FBadgeVariantConstraint, FBadgeStyle>
The variants.
finalinherited

Methods

apply(List<FVariantOperation<FBadgeVariantConstraint, FBadgeVariant, FBadgeStyle, FBadgeStyleDelta>> operations) FVariants<FBadgeVariantConstraint, FBadgeVariant, FBadgeStyle, FBadgeStyleDelta>
Applies a sequence of delta-based operations to this FVariants.
inherited
applyValues(List<FVariantValueDeltaOperation<FBadgeVariantConstraint, FBadgeVariant, FBadgeStyle, FBadgeStyleDelta>> operations) FVariants<FBadgeVariantConstraint, FBadgeVariant, FBadgeStyle, FBadgeStyleDelta>
Applies a sequence of value-based operations to this FVariants.
inherited
call(covariant FVariants<FBadgeVariantConstraint, FBadgeVariant, FBadgeStyle, FBadgeStyleDelta> _) FVariants<FBadgeVariantConstraint, FBadgeVariant, FBadgeStyle, FBadgeStyleDelta>
Applies this delta to the given value.
inherited
cast<T1 extends FVariantConstraint, T2 extends FVariant>() FVariants<T1, T2, FBadgeStyle, FBadgeStyleDelta>
Returns a new FVariants with the variant type parameters cast to T1 and T2.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(Set<FVariant> variants) FBadgeStyle
Returns most specific matching variant, or base if no constraints match.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited