FBottomNavigationBar class

A bottom navigation bar.

A bottom navigation bar is usually present at the bottom of root pages. It is used to navigate between a small number of views, typically between three and five.

See:

Inheritance

Constructors

FBottomNavigationBar({required List<Widget> children, FBottomNavigationBarStyleDelta style = const .context(), bool safeAreaTop = false, bool safeAreaBottom = false, int index = -1, ValueChanged<int>? onChange, Key? key})
Creates a FBottomNavigationBar with FBottomNavigationBarItems.
const

Properties

children → List<Widget>
The children.
final
hashCode → int
The hash code for this object.
no setterinherited
index → int
The index.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onChange → ValueChanged<int>?
A callback for when an item is selected.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
safeAreaBottom → bool
Whether to avoid system intrusions on the bottom. Defaults to false.
final
safeAreaTop → bool
Whether to avoid system intrusions on the top. Defaults to false.
final
style → FBottomNavigationBarStyleDelta
The style.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited