FBottomNavigationBarData class

Inheritance

Constructors

FBottomNavigationBarData({required FBottomNavigationBarItemStyle itemStyle, required bool selected, required int index, required int length, required ValueChanged<int>? onChange, required Widget child, Key? key})
Creates a FBottomNavigationBarData.
const

Properties

child → Widget
The widget below this widget in the tree.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
index → int
The item's index.
final
itemStyle → FBottomNavigationBarItemStyle
The item's style.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
length → int
The total number of items in the bottom navigation bar.
final
onChange → ValueChanged<int>?
A callback for when an item is selected.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selected → bool
True if the item is selected.
final

Methods

createElement() → InheritedElement
Inflates this configuration to a concrete instance.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
updateShouldNotify(covariant FBottomNavigationBarData old) → bool
Whether the framework should notify widgets that inherit from this widget.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

of(BuildContext context) → FBottomNavigationBarData
Returns the FBottomNavigationBarItemStyle and current states of the FBottomNavigationBar in the given context.