semanticsLabel property

String? semanticsLabel
final

The semantic label used by accessibility frameworks.

It is strongly recommended to provide this if an item has no label so screen readers can announce it.

Implementation

final String? semanticsLabel;