FBottomNavigationBarItemStyle class

Implemented types
Mixed-in types
Available extensions

Constructors

FBottomNavigationBarItemStyle({required FVariants<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta> iconStyle, required FVariants<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta> textStyle, required FTappableStyle tappableStyle, required FFocusedOutlineStyle focusedOutlineStyle, EdgeInsetsGeometry padding = const .all(5), double spacing = 2})
Creates a FBottomNavigationBarItemStyle.
FBottomNavigationBarItemStyle.inherit({required FColors colors, required FTypography typography, required FStyle style})
Creates a FBottomNavigationBarItemStyle that inherits its properties.

Properties

focusedOutlineStyle → FFocusedOutlineStyle
The item's focused outline style.
final
hashCode → int
The hash code for this object.
no setterinherited
iconStyle → FVariants<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta>
The icon's style.
final
padding → EdgeInsetsGeometry
The padding. Defaults to EdgeInsets.all(5).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spacing → double
The spacing between the icon and the label. Defaults to 2.
final
tappableStyle → FTappableStyle
The item's tappable's style.
final
textStyle → FVariants<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta>
The text style.
final

Methods

call(covariant Object _) → FBottomNavigationBarItemStyle
Returns itself.
inherited
copyWith({FVariantsDelta<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta>? iconStyle, FVariantsDelta<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta>? textStyle, FTappableStyleDelta? tappableStyle, FFocusedOutlineStyleDelta? focusedOutlineStyle, EdgeInsetsGeometryDelta? padding, double? spacing}) → FBottomNavigationBarItemStyle

Available on FBottomNavigationBarItemStyle, provided by the $FBottomNavigationBarItemStyleTransformations extension

Returns a copy of this FBottomNavigationBarItemStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FBottomNavigationBarItemStyle other, double t) → FBottomNavigationBarItemStyle

Available on FBottomNavigationBarItemStyle, provided by the $FBottomNavigationBarItemStyleTransformations extension

Linearly interpolate between this and another FBottomNavigationBarItemStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited