FBottomNavigationBarStyle class

Implemented types
Mixed-in types
Available extensions

Constructors

FBottomNavigationBarStyle({required Decoration decoration, required FBottomNavigationBarItemStyle itemStyle, ImageFilter? backgroundFilter, EdgeInsetsGeometry padding = const .all(5), FVariants<FPlatformVariantConstraint, FPlatformVariant, bool, Delta> slideableItems = const .all(true)})
Creates a FBottomNavigationBarStyle.
const
FBottomNavigationBarStyle.inherit({required FColors colors, required FTypography typography, required FStyle style})
Creates a FBottomNavigationBarStyle that inherits its properties.

Properties

backgroundFilter → ImageFilter?
An optional background filter. This only takes effect if the decoration has a transparent or translucent background color.
final
decoration → Decoration
The decoration.
final
hashCode → int
The hash code for this object.
no setterinherited
itemStyle → FBottomNavigationBarItemStyle
The item's style.
final
padding → EdgeInsetsGeometry
The padding. Defaults to EdgeInsets.all(5).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slideableItems → FVariants<FPlatformVariantConstraint, FPlatformVariant, bool, Delta>
Whether the items support pressing an item and sliding to another. Defaults to true.
final

Methods

call(covariant Object _) → FBottomNavigationBarStyle
Returns itself.
inherited
copyWith({DecorationDelta? decoration, FBottomNavigationBarItemStyleDelta? itemStyle, ImageFilter? backgroundFilter = Sentinels.imageFilter, EdgeInsetsGeometryDelta? padding, FVariantsValueDelta<FPlatformVariantConstraint, FPlatformVariant, bool, Delta>? slideableItems}) → FBottomNavigationBarStyle

Available on FBottomNavigationBarStyle, provided by the $FBottomNavigationBarStyleTransformations extension

Returns a copy of this FBottomNavigationBarStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FBottomNavigationBarStyle other, double t) → FBottomNavigationBarStyle

Available on FBottomNavigationBarStyle, provided by the $FBottomNavigationBarStyleTransformations extension

Linearly interpolate between this and another FBottomNavigationBarStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited