slideableItems property
Whether the items support pressing an item and sliding to another. Defaults to true.
Implementation
@override
final FVariants<FPlatformVariantConstraint, FPlatformVariant, bool, Delta> slideableItems;
Whether the items support pressing an item and sliding to another. Defaults to true.
@override
final FVariants<FPlatformVariantConstraint, FPlatformVariant, bool, Delta> slideableItems;