A breadcrumb item.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- FBreadcrumbItem
Constructors
-
FBreadcrumbItem({required Widget child, bool current, bool autofocus, FocusNode? focusNode, ValueChanged<
bool> ? onFocusChange, ValueChanged<bool> ? onHoverChange, FTappableVariantChangeCallback? onVariantChange, VoidCallback? onPress, Key? key}) -
Creates a crumb that typically represents a single item in the navigation path.
constfactory
-
FBreadcrumbItem.collapsed({FPopoverMenuStyleDelta popoverMenuStyle, FPopoverControl popoverControl, ScrollController? scrollController, double? cacheExtent, double maxHeight, bool intrinsicWidth, DragStartBehavior dragStartBehavior, FItemDivider divider, AlignmentGeometry childAnchor, FPortalSpacing spacing, FPortalOverflow overflow, Offset offset, FPopoverHideRegion hideRegion, bool cutout, void cutoutBuilder(Path path, Rect bounds), VoidCallback? onTapHide, bool autofocus, FocusScopeNode? focusNode, ValueChanged<
bool> ? onFocusChange, ValueChanged<bool> ? onHoverChange, FTappableVariantChangeCallback? onVariantChange, TraversalEdgeBehavior traversalEdgeBehavior, String? semanticsLabel, Key? key}) -
Creates a collapsed crumb using FItems.
constfactory
-
FBreadcrumbItem.collapsedTiles({FPopoverMenuStyleDelta popoverMenuStyle, FPopoverControl popoverControl, ScrollController? scrollController, double? cacheExtent, double maxHeight, bool intrinsicWidth, DragStartBehavior dragStartBehavior, FItemDivider divider, AlignmentGeometry childAnchor, FPortalSpacing spacing, FPortalOverflow overflow, Offset offset, FPopoverHideRegion hideRegion, bool cutout, void cutoutBuilder(Path path, Rect bounds), bool autofocus, FocusScopeNode? focusNode, ValueChanged<
bool> ? onFocusChange, ValueChanged<bool> ? onHoverChange, FTappableVariantChangeCallback? onVariantChange, TraversalEdgeBehavior traversalEdgeBehavior, String? semanticsLabel, Key? key}) -
Creates a collapsed crumb using FTiles.
constfactory
Properties
Methods
-
createElement(
) → Element -
Inflates this configuration to a concrete instance.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited