FBreadcrumbStyle class

The FBreadcrumb styles.

Implemented types
Mixed-in types
Available extensions

Constructors

FBreadcrumbStyle({required FVariants<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta> textStyle, required IconThemeData iconStyle, required FTappableStyle tappableStyle, required FFocusedOutlineStyle focusedOutlineStyle, required EdgeInsetsGeometry padding, required EdgeInsetsGeometry collapsedPadding})
Creates a FBreadcrumbStyle.
FBreadcrumbStyle.inherit({required FColors colors, required FTypography typography, required FStyle style, required bool touch})
Creates a FBreadcrumbStyle that inherits its properties.
factory

Properties

collapsedPadding → EdgeInsetsGeometry
The padding for collapsed breadcrumb items.
final
focusedOutlineStyle → FFocusedOutlineStyle
The focused outline style.
final
hashCode → int
The hash code for this object.
no setterinherited
iconStyle → IconThemeData
The divider icon style.
final
padding → EdgeInsetsGeometry
The padding for breadcrumb items.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tappableStyle → FTappableStyle
The tappable's style.
final
textStyle → FVariants<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta>
The text style.
final

Methods

call(covariant Object _) → FBreadcrumbStyle
Returns itself.
inherited
copyWith({FVariantsDelta<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta>? textStyle, IconThemeDataDelta? iconStyle, FTappableStyleDelta? tappableStyle, FFocusedOutlineStyleDelta? focusedOutlineStyle, EdgeInsetsGeometryDelta? padding, EdgeInsetsGeometryDelta? collapsedPadding}) → FBreadcrumbStyle

Available on FBreadcrumbStyle, provided by the $FBreadcrumbStyleTransformations extension

Returns a copy of this FBreadcrumbStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FBreadcrumbStyle other, double t) → FBreadcrumbStyle

Available on FBreadcrumbStyle, provided by the $FBreadcrumbStyleTransformations extension

Linearly interpolate between this and another FBreadcrumbStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited