onDoubleTap property
A callback for when the widget is double tapped.
The widget is disabled when every primary and secondary gesture callback (including all lifecycle variants) is null.
Implementation
final VoidCallback? onDoubleTap;
A callback for when the widget is double tapped.
The widget is disabled when every primary and secondary gesture callback (including all lifecycle variants) is null.
final VoidCallback? onDoubleTap;