onLongPress property

VoidCallback? onLongPress
final

A callback for when the widget is long pressed.

The widget is disabled when every primary and secondary gesture callback (including all lifecycle variants) is null.

Implementation

final VoidCallback? onLongPress;