onPress property
A callback for when the widget is pressed.
The widget is disabled when every primary and secondary gesture callback (including all lifecycle variants) is null.
Implementation
final VoidCallback? onPress;
A callback for when the widget is pressed.
The widget is disabled when every primary and secondary gesture callback (including all lifecycle variants) is null.
final VoidCallback? onPress;