onSecondaryPress property
A callback for when the widget is pressed with a secondary button (usually right-click on desktop).
The widget is disabled when every primary and secondary gesture callback (including all lifecycle variants) is null.
Implementation
final VoidCallback? onSecondaryPress;