size property

FButtonSizeVariant size
final

The button size. Defaults to FButtonSizeVariant.md.

The current platform variant is automatically included during style resolution. To change the platform variant, update the enclosing FTheme.platform/FAdaptiveScope.platform.

For example, to create a small button:

FButton(
  size: .sm,
  mainAxisSize: .min, // optional: shrink to fit content horizontally.
  onPress: () {},
  child: Text('Delete'),
)

Implementation

final FButtonSizeVariant size;