variant property

FButtonVariant variant
final

The variant. Defaults to FButtonVariant.primary.

The current platform variant is automatically included during style resolution. To change the platform variant, update the enclosing FTheme.platform/FAdaptiveScope.platform.

For example, to create a destructive button:

FButton(
  variant: .destructive,
  onPress: () {},
  child: Text('Delete'),
)

Implementation

final FButtonVariant variant;