widgets/calendar library Widgets

A calendar.

See https://forui.dev/docs/widgets/data/calendar for working examples.

Classes

FCalendar
A calendar.
FCalendarControl
A FCalendarControl defines how a FCalendar's navigation is controlled.
FCalendarController
A controller for a FCalendar.
FCalendarDayPickerController
Controls a calendar's day picker.
FCalendarDayPickerStyle
A day picker's style.
FCalendarDayPickerStyleDelta
A delta that applies modifications to a FCalendarDayPickerStyle.
FCalendarDayStyle
A calendar's day style.
FCalendarDayStyleDelta
A delta that applies modifications to a FCalendarDayStyle.
FCalendarHeaderStyle
A calendar header's style.
FCalendarHeaderStyleDelta
A delta that applies modifications to a FCalendarHeaderStyle.
FCalendarManagedControl
A FCalendarManagedControl enables widgets to manage their own controller internally while exposing parameters for common configurations.
FCalendarMonthPickerController
Controls a calendar's month picker.
FCalendarMonthPickerStyle
A month picker's style.
FCalendarMonthPickerStyleDelta
A delta that applies modifications to a FCalendarMonthPickerStyle.
FCalendarMonthStyle
A calendar's month style.
FCalendarMonthStyleDelta
A delta that applies modifications to a FCalendarMonthStyle.
FCalendarStyle
FCalendar's style.
FCalendarStyleDelta
A delta that applies modifications to a FCalendarStyle.
FCalendarYearPickerController
Controls a calendar's year picker.
FCalendarYearPickerStyle
A year picker's style.
FCalendarYearPickerStyleDelta
A delta that applies modifications to a FCalendarYearPickerStyle.
FCalendarYearStyle
A calendar's year style.
FCalendarYearStyleDelta
A delta that applies modifications to a FCalendarYearStyle.
FDateSelectionControl<T>
A FDateSelectionControl defines how date selection is controlled.
FDateSelectionController<T>
A controller that controls date selection.
FDateSelectionManagedControl<T>
A FDateSelectionManagedControl enables widgets to manage their own controller internally while exposing parameters for common configurations.
FGridCalendarControl
A FCalendarControl backed by a FGridCalendarController that cycles through the day, month and year grid pickers.
FGridCalendarController
A controller for a FCalendar that cycles through day/month/year grid pickers.
FGridSplitCalendarControl
A FCalendarControl backed by a FGridSplitCalendarController whose month and year grid pickers are independently togglable.
FGridSplitCalendarController
A controller for a FCalendar with a split header whose month and year grid pickers are independently togglable.
FWheelCalendarControl
A FCalendarControl backed by a FWheelCalendarController that toggles between a day grid picker and a month-year wheel picker.
FWheelCalendarController
A controller for a FCalendar that toggles between a day grid picker and a month-year wheel picker.

Enums

FCalendarPickerGridType
The calendar grid type.

Extension Types

FCalendarDayStyles
FCalendarDayStyle's variants.
FCalendarDayVariant
Represents a variant.
FCalendarDayVariantConstraint
Represents a combination of variants.
FCalendarMonthStyles
FCalendarMonthStyle's variants.
FCalendarMonthVariant
Represents a variant.
FCalendarMonthVariantConstraint
Represents a combination of variants.
FCalendarYearStyles
FCalendarYearStyle's variants.
FCalendarYearVariant
Represents a variant.
FCalendarYearVariantConstraint
Represents a combination of variants.

Typedefs

FCalendarDayBuilder = Widget Function(BuildContext, FCalendarDayStyles, FLocalizations, DateTime, Set<FCalendarDayVariant>)
A calendar day builder.
FCalendarFooterBuilder<C extends FCalendarController> = Widget Function(BuildContext context, C controller, FDateSelectionController selectionController)
Builds a FCalendar's footer, shown below the picker.
FCalendarHeaderBuilder<C extends FCalendarController> = Widget Function(BuildContext context, C controller, FDateSelectionController selectionController, Widget child)
Builds a FCalendar's header. The child is the always default header for the currently shown picker.
FCalendarMonthBuilder = Widget Function(BuildContext, FCalendarMonthStyles, FLocalizations, DateTime, Set<FCalendarMonthVariant>)
A calendar month builder.
FCalendarYearBuilder = Widget Function(BuildContext, FCalendarYearStyles, FLocalizations, DateTime, Set<FCalendarYearVariant>)
A calendar year builder.