FCalendarDayPickerStyle class

A day picker's style.

Implemented types
Mixed-in types
Available extensions

Constructors

FCalendarDayPickerStyle({required TextStyle weekdayTextStyle, required FCalendarDayStyles dayStyles, required Size daySize, double headerSpacing = 0, int? firstDayOfWeek, double daySpacing = 2})
Creates a FCalendarDayPickerStyle.
const
FCalendarDayPickerStyle.inherit({required FColors colors, required FTypography typography, required FStyle style, required bool touch})
Creates a FCalendarDayPickerStyle that inherits its properties.
factory

Properties

daySize → Size
The size of each day. Defaults to FSizes.calendar.
final
daySpacing → double
The vertical spacing between days in the day picker. Defaults to 2.
final
dayStyles → FCalendarDayStyles
The styles of the day tiles.
final
firstDayOfWeek → int?
The starting day of the week. Defaults to the current locale's preferred starting day.
final
hashCode → int
The hash code for this object.
no setterinherited
headerSpacing → double
The spacing between the header and the day picker. Defaults to 0. Does nothing if there is no header.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
weekdayTextStyle → TextStyle
The text style for the days of the weekday headers.
final

Methods

call(covariant Object _) → FCalendarDayPickerStyle
Returns itself.
inherited
copyWith({TextStyleDelta? weekdayTextStyle, FVariantsDelta<FCalendarDayVariantConstraint, FCalendarDayVariant, FCalendarDayStyle, FCalendarDayStyleDelta>? dayStyles, Size? daySize, double? headerSpacing, int? firstDayOfWeek()?, double? daySpacing}) → FCalendarDayPickerStyle

Available on FCalendarDayPickerStyle, provided by the $FCalendarDayPickerStyleTransformations extension

Returns a copy of this FCalendarDayPickerStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FCalendarDayPickerStyle other, double t) → FCalendarDayPickerStyle

Available on FCalendarDayPickerStyle, provided by the $FCalendarDayPickerStyleTransformations extension

Linearly interpolate between this and another FCalendarDayPickerStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited