FCalendarDayStyle class

A calendar's day style.

Implemented types
Mixed-in types
Available extensions

Constructors

FCalendarDayStyle({required TextStyle textStyle, required Decoration foreground, Decoration background = const BoxDecoration()})
Creates a FCalendarDayStyle.

Properties

background → Decoration
The decoration painted behind foreground. Defaults to BoxDecoration().
final
foreground → Decoration
The decoration painted in front of background.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textStyle → TextStyle
The day's text style.
final

Methods

call(covariant Object _) → FCalendarDayStyle
Returns itself.
inherited
copyWith({TextStyleDelta? textStyle, DecorationDelta? foreground, DecorationDelta? background}) → FCalendarDayStyle

Available on FCalendarDayStyle, provided by the $FCalendarDayStyleTransformations extension

Returns a copy of this FCalendarDayStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FCalendarDayStyle other, double t) → FCalendarDayStyle

Available on FCalendarDayStyle, provided by the $FCalendarDayStyleTransformations extension

Linearly interpolate between this and another FCalendarDayStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited