FCalendarDayVariant extension type

Represents a variant.

Each variant has a tier that determines its specificity. Higher tiers take precedence during resolution.

See also:

on
Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

and(FCalendarDayVariantConstraint other) FCalendarDayVariantConstraint
Combines this with other using a logical AND operation.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
satisfiedBy(Set<FVariant> variants) bool
Returns true if all variants in this constraint are present in variants.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

adjacent → const FCalendarDayVariant
The semantic variant when the day is not in the current month.
android → const FCalendarDayVariant
The Android platform variant.
disabled → const FCalendarDayVariant
The semantic variant when this widget is disabled and cannot be interacted with.
end → const FCalendarDayVariant
The day is the end of a contiguous selection.
focused → const FCalendarDayVariant
The interaction variant when the given widget or any of its descendants have focus.
fuchsia → const FCalendarDayVariant
The Fuchsia platform variant.
hovered → const FCalendarDayVariant
The interaction variant when the user drags their mouse cursor over the given widget.
iOS → const FCalendarDayVariant
The iOS platform variant.
linux → const FCalendarDayVariant
The Linux platform variant.
macOS → const FCalendarDayVariant
The macOS platform variant.
middle → const FCalendarDayVariant
The day is inside a contiguous selection, between a start and end.
pressed → const FCalendarDayVariant
The interaction variant when the user is actively pressing down on the given widget.
primaryFocused → const FCalendarDayVariant
The interaction variant when a given widget (and not its descendants) has focus.
single → const FCalendarDayVariant
The day is selected but is not part of a contiguous selection.
start → const FCalendarDayVariant
The day is the start of a contiguous selection.
today → const FCalendarDayVariant
The semantic variant when the day is the current day.
web → const FCalendarDayVariant
The web platform variant.
windows → const FCalendarDayVariant
The Windows platform variant.