start constant
FCalendarDayVariant
const start
The day is the start of a contiguous selection.
Implementation
static const start = FCalendarDayVariant._(.new(4, 'start'));
The day is the start of a contiguous selection.
static const start = FCalendarDayVariant._(.new(4, 'start'));