FCalendarEntryStyle class

A calendar entry's style.

Implemented types
Mixed-in types
Available extensions

Properties

backgroundColor FVariants<FTappableVariantConstraint, FTappableVariant, Color, Delta>
The day's background color.
final
borderRadius BorderRadius
The entry border's radius.
final
borderSide FVariants<FTappableVariantConstraint, FTappableVariant, BorderSide?, Delta>
The border side.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textStyle FVariants<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta>
The day's text style.
final

Methods

call(covariant Object _) FCalendarEntryStyle
Returns itself.
inherited
copyWith({FVariantsValueDelta<FTappableVariantConstraint, FTappableVariant, Color, Delta>? backgroundColor, FVariantsValueDelta<FTappableVariantConstraint, FTappableVariant, BorderSide?, Delta>? borderSide, FVariantsDelta<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta>? textStyle, BorderRadius? borderRadius}) FCalendarEntryStyle

Available on FCalendarEntryStyle, provided by the $FCalendarEntryStyleTransformations extension

Returns a copy of this FCalendarEntryStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FCalendarEntryStyle other, double t) FCalendarEntryStyle

Available on FCalendarEntryStyle, provided by the $FCalendarEntryStyleTransformations extension

Linearly interpolate between this and another FCalendarEntryStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited