FCalendarHeaderStyle class

A calendar header's style.

All motion is automatically disabled when FAccessibility.motion is not FAccessibilityMotion.all.

Implemented types
Mixed-in types
Available extensions

Constructors

FCalendarHeaderStyle({required FVariants<FTappableVariantConstraint, FTappableVariant, Decoration, DecorationDelta> headerDecoration, required FVariants<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta> headerTextStyle, required FVariants<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta> toggleIconStyle, required FFocusedOutlineStyle headerFocusedOutlineStyle, required FButtonStyle buttonStyle, required FIcon toggleIcon, required FIcon previousIcon, required FIcon nextIcon, EdgeInsetsGeometry padding = .zero, EdgeInsetsGeometry tappablePadding = const .directional(start: 8, end: 2, top: 4, bottom: 4), Duration animationDuration = const Duration(milliseconds: 100)})
Creates a FCalendarHeaderStyle.
const
FCalendarHeaderStyle.inherit({required FColors colors, required FTypography typography, required FIcons icons, required FStyle style, required bool touch})
Creates a FCalendarHeaderStyle that inherits its properties.
factory

Properties

animationDuration → Duration
The arrow turn animation's duration. Defaults to 100ms.
final
buttonStyle → FButtonStyle
The navigation buttons' style.
final
hashCode → int
The hash code for this object.
no setterinherited
headerDecoration → FVariants<FTappableVariantConstraint, FTappableVariant, Decoration, DecorationDelta>
The month and year tap targets' decoration. Defaults to a FColors.secondary background when hovered or pressed.
final
headerFocusedOutlineStyle → FFocusedOutlineStyle
The focused outline style for the header tappable.
final
headerTextStyle → FVariants<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta>
The month and year labels' text style.
final
nextIcon → FIcon
The next-month icon builder. Defaults to FIcons.chevronRight.
final
padding → EdgeInsetsGeometry
The padding around the entire header. Defaults to EdgeInsets.zero.
final
previousIcon → FIcon
The previous-month icon builder. Defaults to FIcons.chevronLeft.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tappablePadding → EdgeInsetsGeometry
The month and year tap targets' padding. Defaults to EdgeInsetsDirectional.only(start: 8, end: 2, top: 4, bottom: 4).
final
toggleIcon → FIcon
The toggle icon builder. Defaults to FIcons.chevronRight.
final
toggleIconStyle → FVariants<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta>
The month and year toggle icons' style. Defaults to FColors.mutedForeground.
final

Methods

call(covariant Object _) → FCalendarHeaderStyle
Returns itself.
inherited
copyWith({FVariantsDelta<FTappableVariantConstraint, FTappableVariant, Decoration, DecorationDelta>? headerDecoration, FVariantsDelta<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta>? headerTextStyle, FVariantsDelta<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta>? toggleIconStyle, FFocusedOutlineStyleDelta? headerFocusedOutlineStyle, FButtonStyleDelta? buttonStyle, FIcon? toggleIcon, FIcon? previousIcon, FIcon? nextIcon, EdgeInsetsGeometryDelta? padding, EdgeInsetsGeometryDelta? tappablePadding, Duration? animationDuration}) → FCalendarHeaderStyle

Available on FCalendarHeaderStyle, provided by the $FCalendarHeaderStyleTransformations extension

Returns a copy of this FCalendarHeaderStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FCalendarHeaderStyle other, double t) → FCalendarHeaderStyle

Available on FCalendarHeaderStyle, provided by the $FCalendarHeaderStyleTransformations extension

Linearly interpolate between this and another FCalendarHeaderStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited