buttonStyle property
The button style. Defaults to outline sm on touch and outline xs on desktop.
Implementation
@override
final FButtonStyle buttonStyle;
The button style. Defaults to outline sm on touch and outline xs on desktop.
@override
final FButtonStyle buttonStyle;