FCalendarHeaderStyleDelta class abstract

A delta that applies modifications to a FCalendarHeaderStyle.

A FCalendarHeaderStyle is itself a FCalendarHeaderStyleDelta.

Mixed-in types
Implementers

Constructors

FCalendarHeaderStyleDelta.context()
Creates a delta that returns the FCalendarHeaderStyle in the current context.
const
factory
FCalendarHeaderStyleDelta.delta({EdgeInsetsGeometryDelta? padding, FVariantsDelta<FTappableVariantConstraint, FTappableVariant, Decoration, DecorationDelta>? headerDecoration, EdgeInsetsGeometryDelta? tappablePadding, FVariantsDelta<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta>? headerTextStyle, FVariantsDelta<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta>? toggleIconStyle, FFocusedOutlineStyleDelta? headerFocusedOutlineStyle, FButtonStyleDelta? buttonStyle, Widget toggleIcon(BuildContext, {String? semanticsLabel})?, Widget previousIcon(BuildContext, {String? semanticsLabel})?, Widget nextIcon(BuildContext, {String? semanticsLabel})?, Duration? animationDuration})
Creates a partial modification of a FCalendarHeaderStyle.
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(covariant FCalendarHeaderStyle value) FCalendarHeaderStyle
Applies this delta to the given value.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited