selectable property
A predicate that determines if a date can be selected. Defaults to always true.
Contract
Throws AssertionError if selectable and controller are both provided.
Implementation
@override
final bool Function(DateTime)? selectable;
A predicate that determines if a date can be selected. Defaults to always true.
Throws AssertionError if selectable and controller are both provided.
@override
final bool Function(DateTime)? selectable;