FCalendarMonthStyleDelta class abstract

A delta that applies modifications to a FCalendarMonthStyle.

A FCalendarMonthStyle is itself a FCalendarMonthStyleDelta.

Mixed-in types
Implementers

Constructors

FCalendarMonthStyleDelta.context()
Creates a delta that returns the FCalendarMonthStyle in the current context.
const
factory
FCalendarMonthStyleDelta.delta({TextStyleDelta? textStyle, DecorationDelta? decoration})
Creates a partial modification of a FCalendarMonthStyle.
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(covariant FCalendarMonthStyle value) FCalendarMonthStyle
Applies this delta to the given value.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited