FCalendarMonthVariant extension type
Represents a variant.
Each variant has a tier that determines its specificity. Higher tiers take precedence during resolution.
See also:
- FCalendarMonthVariantConstraint, which represents combinations of variants.
- on
- Implemented types
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
and(
FCalendarMonthVariantConstraint other) → FCalendarMonthVariantConstraint -
Combines this with
otherusing a logical AND operation.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
satisfiedBy(
Set< FVariant> variants) → bool -
Returns true if all variants in this constraint are present in
variants.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- android → const FCalendarMonthVariant
- The Android platform variant.
- disabled → const FCalendarMonthVariant
- The semantic variant when this widget is disabled and cannot be interacted with.
- focused → const FCalendarMonthVariant
- The interaction variant when the given widget or any of its descendants have focus.
- fuchsia → const FCalendarMonthVariant
- The Fuchsia platform variant.
- hovered → const FCalendarMonthVariant
- The interaction variant when the user drags their mouse cursor over the given widget.
- iOS → const FCalendarMonthVariant
- The iOS platform variant.
- linux → const FCalendarMonthVariant
- The Linux platform variant.
- macOS → const FCalendarMonthVariant
- The macOS platform variant.
- pressed → const FCalendarMonthVariant
- The interaction variant when the user is actively pressing down on the given widget.
- primaryFocused → const FCalendarMonthVariant
- The interaction variant when a given widget (and not its descendants) has focus.
- today → const FCalendarMonthVariant
- The semantic variant when the month is the current month.
- web → const FCalendarMonthVariant
- The web platform variant.
- windows → const FCalendarMonthVariant
- The Windows platform variant.