FCalendarYearStyle class
A calendar's year style.
- Implemented types
- Mixed-in types
- Available extensions
Constructors
- FCalendarYearStyle({required TextStyle textStyle, required Decoration decoration})
- Creates a FCalendarYearStyle.
Properties
- decoration → Decoration
-
The decoration painted behind the year's text.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textStyle → TextStyle
-
The year's text style.
final
Methods
-
call(
covariant Object _) → FCalendarYearStyle -
Returns itself.
inherited
-
copyWith(
{TextStyleDelta? textStyle, DecorationDelta? decoration}) → FCalendarYearStyle -
Available on FCalendarYearStyle, provided by the $FCalendarYearStyleTransformations extension
Returns a copy of this FCalendarYearStyle with the given properties replaced. -
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
lerp(
FCalendarYearStyle other, double t) → FCalendarYearStyle -
Available on FCalendarYearStyle, provided by the $FCalendarYearStyleTransformations extension
Linearly interpolate between this and another FCalendarYearStyle using the given factort. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited