managedRange static method

FDateSelectionControl<(DateTime, DateTime)?> managedRange({
  1. FDateSelectionController<(DateTime, DateTime)?>? controller,
  2. (DateTime, DateTime)? initial,
  3. ValueChanged<(DateTime, DateTime)?>? onChange,
})

Creates a FDateSelectionControl for range selection.

Both the start and end dates of the range are inclusive. Unlike managedOpenRange, selecting the first date returns a complete range, (first date, first date).

Contract

Throws AssertionError if initial's end date is less than its start date.

Implementation

static FDateSelectionControl<(DateTime, DateTime)?> managedRange({
  FDateSelectionController<(DateTime, DateTime)?>? controller,
  (DateTime, DateTime)? initial,
  ValueChanged<(DateTime, DateTime)?>? onChange,
}) => _Range(controller: controller, initial: initial, onChange: onChange);