FDateSelectionController<T> class abstract

A controller that controls date selection.

All returned DateTimes are in UTC timezone with no time component. Given DateTimes are truncated and converted to dates in UTC timezone.

This class should be extended to customize date selection. By default, the following controllers are provided:

Inheritance

Constructors

FDateSelectionController(T _value)
Creates a FDateSelectionController with the given initial value.

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value ↔ T
The current value stored in this notifier.
getter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
contains(DateTime date) bool
Returns true if the given date is selected.
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
select(DateTime date) → void
Selects the given date.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

multi({Set<DateTime> initial = const {}}) FDateSelectionController<Set<DateTime>>
Creates a FDateSelectionController that allows multiple dates to be selected, with the given initial selected dates.
range({(DateTime, DateTime)? initial}) FDateSelectionController<(DateTime, DateTime)?>
Creates a FDateSelectionController that allows a single range to be selected, with the given initial range.
single({DateTime? initial, bool toggleable = true}) FDateSelectionController<DateTime?>
Creates a FDateSelectionController that allows only a single date to be selected, with the given initially selected date.