FDateSelectionLiftedControl<T> class abstract

A FDateSelectionLiftedControl enables a parent to own the selection state and update it via a callback.

Inheritance

Constructors

FDateSelectionLiftedControl({required T value, required ValueChanged<T> onChange})
Creates a FDateSelectionLiftedControl.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
onChange ValueChanged<T>
Called with the new selection when a date is selected.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T
The currently selected value.
final

Methods

createController() FDateSelectionController<T>
Creates a FDateSelectionController<T>.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited