FGridCalendarControl class

A FCalendarControl backed by a FGridCalendarController that cycles through the day, month and year grid pickers.

Subclass ManagedControl to create variants with different defaults or behaviors, e.g., FDateSelectionControl.date() vs FDateSelectionControl.range().

Inheritance

Constructors

FGridCalendarControl({FGridCalendarController? controller, bool selectable(DateTime)?, DateTime? start, DateTime? today, DateTime? initial, DateTime? end})
Creates a FGridCalendarControl.
const

Properties

controller → FCalendarController?
The controller.
finalinherited
end → DateTime?
The end date, inclusive. Defaults to DateTime.utc(2100).
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
initial → DateTime?
The initial month shown. Defaults to today.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectable → bool Function(DateTime)?
A predicate that determines if a date can be selected. Defaults to always true.
finalinherited
start → DateTime?
The start date, inclusive. Defaults to DateTime.utc(1900).
finalinherited
today → DateTime?
Today's date. Defaults to DateTime.now.
finalinherited

Methods

createController() → FCalendarController
Creates a FCalendarController.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited