animateToMonthPicker method

Future<void> animateToMonthPicker([
  1. DateTime? date,
  2. Duration duration = const Duration(milliseconds: 200),
  3. Curve curve = Curves.ease
])
inherited

Shows the month picker for the given date's year, or the current year if date is null.

If the month picker is already shown, its grid animates to the year; otherwise it is shown immediately.

Implementation

Future<void> animateToMonthPicker([
  DateTime? date,
  Duration duration = const Duration(milliseconds: 200),
  Curve curve = Curves.ease,
]) async {
  final target = _clamp(start, switch (date) {
    null => _currentMonth,
    final m => .utc(m.year, m.month),
  }, end);

  if (month.controller.hasClients) {
    await month.animateTo(target, duration: duration, curve: curve);
  } else {
    _reattach(month, .month, target);
  }
}