FGridSplitCalendarController class

A controller for a FCalendar with a split header whose month and year grid pickers are independently togglable.

Inheritance

Constructors

FGridSplitCalendarController({bool selectable(DateTime date) = defaultSelectable, DateTime? start, DateTime? today, DateTime? initial, DateTime? end})
Creates a FGridSplitCalendarController.

Properties

currentMonth DateTime
The current year and month that the day picker shows.
no setterinherited
day FCalendarDayPickerController
The day picker controller.
latefinalinherited
disposed bool
True if this notifier has been disposed.
no setterinherited
end DateTime
The end date, inclusive. Defaults to DateTime.utc(2100).
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
month FCalendarMonthPickerController
The month picker controller.
latefinalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start DateTime
The start date, inclusive. Defaults to DateTime.utc(1900).
finalinherited
today DateTime
Today's date. Defaults to DateTime.now.
finalinherited
type FCalendarPickerGridType
The currently shown grid's type.
no setterinherited
year FCalendarYearPickerController
The year picker controller.
latefinalinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
animateToDayPicker([DateTime? date, Duration duration = const Duration(milliseconds: 200), Curve curve = Curves.ease]) Future<void>
Shows the day picker on the given date's month, or the current month if date is null.
inherited
animateToMonthPicker([DateTime? date, Duration duration = const Duration(milliseconds: 200), Curve curve = Curves.ease]) Future<void>
Shows the month picker for the given date's year, or the current year if date is null.
inherited
animateToYearPicker([DateTime? date, Duration duration = const Duration(milliseconds: 200), Curve curve = Curves.ease]) Future<void>
Shows the year picker for the given date's year, or the current year if date is null.
inherited
dispose() → void
Discards any resources used by the object.
inherited
jumpToDayPicker([DateTime? date]) → void
Shows the day picker on the given date's month, or the current month if date is null.
inherited
jumpToMonthPicker([DateTime? date]) → void
Shows the month picker for the given date's year, or the current year if date is null.
inherited
jumpToYearPicker([DateTime? date]) → void
Shows the year picker for the given date's year, or the current year if date is null.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toggleMonthPicker() → void
Shows the month picker if not currently shown, and the day picker otherwise.
toggleYearPicker() → void
Shows the year picker if not currently shown, and the day picker otherwise.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited