FCard class

A card.

Cards are typically used to group related information together.

CLI

To generate a layout for this widget:

dart run forui snippet create card

See:

Inheritance

Constructors

FCard({FCardStyleDelta style = const .context(), Clip clipBehavior = .none, ValueWidgetBuilder<FCardStyle> builder = defaultBuilder, Widget? child, Key? key})
Creates a FCard.
const

Properties

builder → ValueWidgetBuilder<FCardStyle>
The builder for the card's content.
final
child → Widget?
The child.
final
clipBehavior → Clip
The clip behavior applied to the card's content.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → FCardStyleDelta
The style. Defaults to FThemeData.cardStyle.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

defaultBuilder(BuildContext _, FCardStyle _, Widget? child) → Widget
The default builder that returns child unchanged.