FCardContentStyleDelta.delta constructor
const
FCardContentStyleDelta.delta({
- double? imageSpacing,
- double? titleSpacing,
- double? subtitleSpacing,
- TextStyleDelta? titleTextStyle,
- TextStyleDelta? subtitleTextStyle,
- EdgeInsetsGeometryDelta? padding,
Creates a partial modification of a FCardContentStyle.
Parameters
- FCardContentStyle.imageSpacing - The spacing between the image and the title, subtitle, and child if any of them is provided.
- FCardContentStyle.titleSpacing - The spacing between the title and the subtitle.
- FCardContentStyle.subtitleSpacing - The spacing between the title/subtitle and the child.
- FCardContentStyle.titleTextStyle - The title's TextStyle.
- FCardContentStyle.subtitleTextStyle - The subtitle's TextStyle.
- FCardContentStyle.padding - The padding.
Implementation
const factory FCardContentStyleDelta.delta({
double? imageSpacing,
double? titleSpacing,
double? subtitleSpacing,
TextStyleDelta? titleTextStyle,
TextStyleDelta? subtitleTextStyle,
EdgeInsetsGeometryDelta? padding,
}) = _FCardContentStyleDelta;