FCardStyle class

FCard's style.

Implemented types
Mixed-in types
Available extensions

Constructors

FCardStyle({required Decoration decoration, required TextStyle titleTextStyle, required TextStyle subtitleTextStyle, EdgeInsetsGeometry padding = const .all(16)})
Creates a FCardStyle.
FCardStyle.inherit({required FColors colors, required FTypography typography, required FStyle style, required bool touch})
Creates a FCardStyle that inherits its properties.
factory

Properties

decoration → Decoration
The decoration.
final
hashCode → int
The hash code for this object.
no setterinherited
padding → EdgeInsetsGeometry
The padding. Defaults to EdgeInsets.all(16).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitleTextStyle → TextStyle
The subtitle's TextStyle.
final
titleTextStyle → TextStyle
The title's TextStyle.
final

Methods

call(covariant Object _) → FCardStyle
Returns itself.
inherited
copyWith({DecorationDelta? decoration, TextStyleDelta? titleTextStyle, TextStyleDelta? subtitleTextStyle, EdgeInsetsGeometryDelta? padding}) → FCardStyle

Available on FCardStyle, provided by the $FCardStyleTransformations extension

Returns a copy of this FCardStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FCardStyle other, double t) → FCardStyle

Available on FCardStyle, provided by the $FCardStyleTransformations extension

Linearly interpolate between this and another FCardStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited