leadingLabel property
Whether the label is positioned before the checkbox (leading) instead of after it (trailing). Defaults to false.
Implementation
final bool leadingLabel;
Whether the label is positioned before the checkbox (leading) instead of after it (trailing). Defaults to false.
final bool leadingLabel;