FCheckboxMotion class

The motion-related properties for a FCheckbox.

All motion is automatically disabled when FAccessibility.motion is FAccessibilityMotion.disabled.

Implemented types
Mixed-in types
Available extensions

Constructors

FCheckboxMotion({Duration fadeInDuration = const Duration(milliseconds: 100), Duration fadeOutDuration = const Duration(milliseconds: 100), Curve fadeInCurve = Curves.linear, Curve fadeOutCurve = Curves.linear})
Creates a FCheckboxMotion.
const

Properties

fadeInCurve → Curve
The curve of the fade in animation. Defaults to Curves.linear.
final
fadeInDuration → Duration
The duration of the fade in animation. Defaults to 100ms.
final
fadeOutCurve → Curve
The curve of the fade out animation. Defaults to Curves.linear.
final
fadeOutDuration → Duration
The duration of the fade out animation. Defaults to 100ms.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(covariant Object _) → FCheckboxMotion
Returns itself.
inherited
copyWith({Duration? fadeInDuration, Duration? fadeOutDuration, Curve? fadeInCurve, Curve? fadeOutCurve}) → FCheckboxMotion

Available on FCheckboxMotion, provided by the $FCheckboxMotionTransformations extension

Returns a copy of this FCheckboxMotion with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FCheckboxMotion other, double t) → FCheckboxMotion

Available on FCheckboxMotion, provided by the $FCheckboxMotionTransformations extension

Linearly interpolate between this and another FCheckboxMotion using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited