FCheckboxStyle class

A checkboxes style.

Implemented types
Mixed-in types
Available extensions

Constructors

FCheckboxStyle({required FTappableStyle tappableStyle, required FFocusedOutlineStyle focusedOutlineStyle, required FVariants<FFormFieldVariantConstraint, FFormFieldVariant, IconThemeData, IconThemeDataDelta> iconStyle, required FIcon icon, required FVariants<FCheckboxVariantConstraint, FCheckboxVariant, Decoration, DecorationDelta> decoration, required FLabelStyle leadingLabelStyle, required FLabelStyle trailingLabelStyle, double size = 16, FCheckboxMotion motion = const FCheckboxMotion()})
Creates a FCheckboxStyle.
const
FCheckboxStyle.inherit({required FColors colors, required FIcons icons, required FStyle style, required bool touch})
Creates a FCheckboxStyle that inherits its properties.
factory

Properties

decoration → FVariants<FCheckboxVariantConstraint, FCheckboxVariant, Decoration, DecorationDelta>
The box decoration.
final
focusedOutlineStyle → FFocusedOutlineStyle
The focused outline style.
final
hashCode → int
The hash code for this object.
no setterinherited
icon → FIcon
The check icon builder. Defaults to FIcons.check.
final
iconStyle → FVariants<FFormFieldVariantConstraint, FFormFieldVariant, IconThemeData, IconThemeDataDelta>
The icon style.
final
leadingLabelStyle → FLabelStyle
The label style when FCheckbox.leadingLabel is true.
final
motion → FCheckboxMotion
The motion-related properties. Defaults to FCheckboxMotion.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → double
The checkboxes size. Defaults to 16.
final
tappableStyle → FTappableStyle
The tappable style.
final
trailingLabelStyle → FLabelStyle
The label style when FCheckbox.leadingLabel is false (the default).
final

Methods

call(covariant Object _) → FCheckboxStyle
Returns itself.
inherited
copyWith({FTappableStyleDelta? tappableStyle, FFocusedOutlineStyleDelta? focusedOutlineStyle, FVariantsDelta<FFormFieldVariantConstraint, FFormFieldVariant, IconThemeData, IconThemeDataDelta>? iconStyle, FIcon? icon, FVariantsDelta<FCheckboxVariantConstraint, FCheckboxVariant, Decoration, DecorationDelta>? decoration, FLabelStyleDelta? leadingLabelStyle, FLabelStyleDelta? trailingLabelStyle, double? size, FCheckboxMotionDelta? motion}) → FCheckboxStyle

Available on FCheckboxStyle, provided by the $FCheckboxStyleTransformations extension

Returns a copy of this FCheckboxStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FCheckboxStyle other, double t) → FCheckboxStyle

Available on FCheckboxStyle, provided by the $FCheckboxStyleTransformations extension

Linearly interpolate between this and another FCheckboxStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited