FCheckboxStyleDelta class abstract

A delta that applies modifications to a FCheckboxStyle.

A FCheckboxStyle is itself a FCheckboxStyleDelta.

Mixed-in types
Implementers

Constructors

FCheckboxStyleDelta.context()
Creates a delta that returns the FCheckboxStyle in the current context.
const
factory
FCheckboxStyleDelta.delta({FTappableStyleDelta? tappableStyle, FFocusedOutlineStyleDelta? focusedOutlineStyle, double? size, FVariantsDelta<FFormFieldVariantConstraint, FFormFieldVariant, IconThemeData, IconThemeDataDelta>? iconStyle, FVariantsDelta<FCheckboxVariantConstraint, FCheckboxVariant, Decoration, DecorationDelta>? decoration, FCheckboxMotionDelta? motion, FLabelStyleDelta? leadingLabelStyle, FLabelStyleDelta? trailingLabelStyle})
Creates a partial modification of a FCheckboxStyle.
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(covariant FCheckboxStyle value) FCheckboxStyle
Applies this delta to the given value.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited