menuAnchor property
The anchor point on the menu used for positioning relative to the gesture point.
Defaults to Alignment.topLeft.
Implementation
final AlignmentGeometry menuAnchor;
The anchor point on the menu used for positioning relative to the gesture point.
Defaults to Alignment.topLeft.
final AlignmentGeometry menuAnchor;