secondaryPress property
Whether a secondary press (e.g. right-click) triggers the context menu.
Defaults to true on desktop platforms and false on touch.
Implementation
final bool? secondaryPress;
Whether a secondary press (e.g. right-click) triggers the context menu.
Defaults to true on desktop platforms and false on touch.
final bool? secondaryPress;