FDateFieldGridCalendarProperties class

A date field calendar that cycles through the day, month and year grid pickers. Mirrors FCalendar.grid.

Inheritance

Constructors

FDateFieldGridCalendarProperties({FGridCalendarControl control = const FGridCalendarControl(), ScrollPhysics? dayScrollPhysics, ScrollCacheExtent? dayScrollCacheExtent, ScrollBehavior? dayScrollBehavior, ScrollPhysics? monthScrollPhysics, ScrollCacheExtent? monthScrollCacheExtent, ScrollBehavior? monthScrollBehavior, ScrollPhysics? yearScrollPhysics, ScrollCacheExtent? yearScrollCacheExtent, ScrollBehavior? yearScrollBehavior, FCalendarHeaderBuilder<FGridCalendarController> headerBuilder = FCalendar.defaultHeaderBuilder, FCalendarFooterBuilder<FGridCalendarController> footerBuilder = FCalendar.defaultFooterBuilder, FCalendarDayBuilder dayBuilder = FCalendar.defaultDayBuilder, FCalendarMonthBuilder monthBuilder = FCalendar.defaultMonthBuilder, FCalendarYearBuilder yearBuilder = FCalendar.defaultYearBuilder, FutureOr<void> onDayPress(DateTime)?, FutureOr<void> onDayLongPress(DateTime)?, AlignmentGeometry anchor = .topLeft, AlignmentGeometry fieldAnchor = .bottomLeft, FPortalSpacing spacing = const .spacing(4), FPortalOverflow overflow = .flip, Offset offset = .zero, bool useViewPadding = true, bool useViewInsets = true, FPopoverHideRegion hideRegion = .excludeChild, Object? groupId, VoidCallback? onTapHide, bool cutout = true, void cutoutBuilder(Path path, Rect bounds) = FModalBarrier.defaultCutoutBuilder, FDateFieldPopoverBuilder popoverBuilder = FPopover.defaultPopoverBuilder, bool autoHide = true, bool fixedWeeks = false})
Creates a FDateFieldGridCalendarProperties.
const

Properties

anchor AlignmentGeometry
The alignment point on the calendar popover. Defaults to Alignment.topLeft.
finalinherited
autoHide bool
True if the calendar popover should be automatically hidden after a date is selected. Defaults to true.
finalinherited
control FGridCalendarControl
The control for the calendar's navigation.
final
cutout bool
Whether the barrier should exclude the builder/child's area using a non-interactive cutout.
finalinherited
cutoutBuilder → void Function(Path path, Rect bounds)
An optional callback that customizes the cutout shape.
finalinherited
dayBuilder FCalendarDayBuilder
Customizes the appearance of calendar days. Defaults to FCalendar.defaultDayBuilder.
final
dayScrollBehavior ScrollBehavior?
The day picker's scroll behavior.
final
dayScrollCacheExtent ScrollCacheExtent?
The scrollable area's cache extent.
final
dayScrollPhysics ScrollPhysics?
The day picker's scroll physics.
final
fieldAnchor AlignmentGeometry
The alignment point on the field. Defaults to Alignment.bottomLeft.
finalinherited
fixedWeeks bool
Whether the day grid always shows 6 week-rows instead of adapting its height to the month's 4-6 weeks. Defaults to false.
finalinherited
footerBuilder FCalendarFooterBuilder<FGridCalendarController>
Builds the calendar's footer.
final
groupId Object?
An optional group ID that groups TapRegions together so that they operate as one region. If a tap occurs outside of all group members, then group members that are shown will be hidden.
finalinherited
hashCode int
The hash code for this object.
no setteroverride
headerBuilder FCalendarHeaderBuilder<FGridCalendarController>
Builds the calendar's header.
final
hideRegion FPopoverHideRegion
The region that can be tapped to hide the popover.
finalinherited
monthBuilder FCalendarMonthBuilder
Customizes the appearance of calendar months. Defaults to FCalendar.defaultMonthBuilder.
final
monthScrollBehavior ScrollBehavior?
The month picker's scroll behavior.
final
monthScrollCacheExtent ScrollCacheExtent?
The scrollable area's cache extent.
final
monthScrollPhysics ScrollPhysics?
The month picker's scroll physics.
final
offset Offset
Additional translation to apply to the popover's position.
finalinherited
onDayLongPress FutureOr<void> Function(DateTime)?
A callback for when a date is long pressed.
final
onDayPress FutureOr<void> Function(DateTime)?
A callback for when a date is pressed.
final
onTapHide VoidCallback?
A callback that is called when the popover is hidden by tapping outside of it.
finalinherited
overflow FPortalOverflow
The callback used to shift a popover when it overflows out of the viewport.
finalinherited
popoverBuilder FDateFieldPopoverBuilder
The builder used to wrap the calendar popover content.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing FPortalSpacing
The spacing between the popover and child anchors.
finalinherited
useViewInsets bool
Whether to avoid the platform view's insets (the soft keyboard).
finalinherited
useViewPadding bool
Whether to avoid the platform view's padding (static safe areas like the notch and status bar).
finalinherited
yearBuilder FCalendarYearBuilder
Customizes the appearance of calendar years. Defaults to FCalendar.defaultYearBuilder.
final
yearScrollBehavior ScrollBehavior?
The year picker's scroll behavior.
final
yearScrollCacheExtent ScrollCacheExtent?
The scrollable area's cache extent.
final
yearScrollPhysics ScrollPhysics?
The year picker's scroll physics.
final

Methods

debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override