FDateFieldStyle class

A date field's style.

Implemented types
Mixed-in types
Available extensions

Constructors

FDateFieldStyle({required FTextFieldSizeStyles fieldStyles, required FPopoverStyle popoverStyle, required FCalendarStyle calendarStyle})
Creates a FDateFieldStyle.
FDateFieldStyle.inherit({required FColors colors, required FTypography typography, required FIcons icons, required FStyle style, required FHapticFeedback hapticFeedback, required bool touch})
Creates a FDateFieldStyle that inherits its properties.

Properties

calendarStyle FCalendarStyle
The date field's calendar style.
final
fieldStyles FTextFieldSizeStyles
The date field's text-field styles.
final
hashCode int
The hash code for this object.
no setterinherited
popoverStyle FPopoverStyle
The date field calendar's popover style.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(covariant Object _) FDateFieldStyle
Returns itself.
inherited
copyWith({FVariantsDelta<FTextFieldSizeVariantConstraint, FTextFieldSizeVariant, FTextFieldStyle, FTextFieldStyleDelta>? fieldStyles, FPopoverStyleDelta? popoverStyle, FCalendarStyleDelta? calendarStyle}) FDateFieldStyle

Available on FDateFieldStyle, provided by the $FDateFieldStyleTransformations extension

Returns a copy of this FDateFieldStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FDateFieldStyle other, double t) FDateFieldStyle

Available on FDateFieldStyle, provided by the $FDateFieldStyleTransformations extension

Linearly interpolate between this and another FDateFieldStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited