copyWith method
- @useResult
- int? dateFlex,
- int? hourFlex,
- int? minuteFlex,
- int? periodFlex,
- EdgeInsetsDirectionalDelta? padding,
- double? diameterRatio,
- double? squeeze,
- double? magnification,
- double? overAndUnderCenterOpacity,
- double? spacing,
- TextStyleDelta? textStyle,
- TextHeightBehavior? textHeightBehavior,
- double? selectionHeightAdjustment,
- DecorationDelta? selectionDecoration,
- FFocusedOutlineStyleDelta? focusedOutlineStyle,
- Future<
void> hapticFeedback()?,
Returns a copy of this FDateTimePickerStyle with the given properties replaced.
See customizing widget styles.
Parameters
- FDateTimePickerStyle.dateFlex - The date wheel's flex factor.
- FDateTimePickerStyle.hourFlex - The hour wheel's flex factor.
- FDateTimePickerStyle.minuteFlex - The minute wheel's flex factor.
- FDateTimePickerStyle.periodFlex - The period (AM/PM) wheel's flex factor.
- FDateTimePickerStyle.padding - The padding.
- FDateTimePickerStyle.diameterRatio - A ratio between the diameter of the cylinder and the viewport's size.
- FDateTimePickerStyle.squeeze - The angular compactness of the children on the wheel.
- FDateTimePickerStyle.magnification - The zoomed-in rate of the magnifier.
- FDateTimePickerStyle.overAndUnderCenterOpacity - The opacity value applied to the wheel above and below the magnifier.
- FDateTimePickerStyle.spacing - The spacing between the picker's wheels.
- FDateTimePickerStyle.textStyle - The picker's text style.
- FDateTimePickerStyle.textHeightBehavior - The picker's text height behavior.
- FDateTimePickerStyle.selectionHeightAdjustment - An amount to add to the height of the selection.
- FDateTimePickerStyle.selectionDecoration - The selection's decoration.
- FDateTimePickerStyle.focusedOutlineStyle - The focused outline style.
- FDateTimePickerStyle.hapticFeedback - The haptic feedback for when the picker snaps to an item.
Implementation
@useResult
FDateTimePickerStyle copyWith({
int? dateFlex,
int? hourFlex,
int? minuteFlex,
int? periodFlex,
EdgeInsetsDirectionalDelta? padding,
double? diameterRatio,
double? squeeze,
double? magnification,
double? overAndUnderCenterOpacity,
double? spacing,
TextStyleDelta? textStyle,
TextHeightBehavior? textHeightBehavior,
double? selectionHeightAdjustment,
DecorationDelta? selectionDecoration,
FFocusedOutlineStyleDelta? focusedOutlineStyle,
Future<void> Function()? hapticFeedback,
}) => .new(
dateFlex: dateFlex ?? this.dateFlex,
hourFlex: hourFlex ?? this.hourFlex,
minuteFlex: minuteFlex ?? this.minuteFlex,
periodFlex: periodFlex ?? this.periodFlex,
padding: padding?.call(this.padding) ?? this.padding,
diameterRatio: diameterRatio ?? this.diameterRatio,
squeeze: squeeze ?? this.squeeze,
magnification: magnification ?? this.magnification,
overAndUnderCenterOpacity: overAndUnderCenterOpacity ?? this.overAndUnderCenterOpacity,
spacing: spacing ?? this.spacing,
textStyle: textStyle?.call(this.textStyle) ?? this.textStyle,
textHeightBehavior: textHeightBehavior ?? this.textHeightBehavior,
selectionHeightAdjustment: selectionHeightAdjustment ?? this.selectionHeightAdjustment,
selectionDecoration: selectionDecoration?.call(this.selectionDecoration) ?? this.selectionDecoration,
focusedOutlineStyle: focusedOutlineStyle?.call(this.focusedOutlineStyle) ?? this.focusedOutlineStyle,
hapticFeedback: hapticFeedback ?? this.hapticFeedback,
);