FDateTimePicker class

A date and time picker that allows a date and time to be selected.

Recommended for touch devices.

The date time picker supports arrow key navigation:

  • Up/Down arrows: Increment/decrement selected value
  • Left/Right arrows: Move between wheels

See:

Inheritance

Constructors

FDateTimePicker({FDateTimePickerControl control = const .managed(), FDateTimePickerStyleDelta style = const .context(), bool? hour24, int dayInterval = 1, int hourInterval = 1, int minuteInterval = 1, Widget dateBuilder(BuildContext context, DateTime date, DateFormat format) = defaultDateBuilder, Key? key})
Creates a FDateTimePicker that uses a single wheel for the date.
const

Properties

control → FDateTimePickerControl
The control.
final
dateBuilder → Widget Function(BuildContext context, DateTime date, DateFormat format)
A builder that creates the date label for the date wheel.
final
dayInterval → int
The interval between days in the picker. Defaults to 1.
final
hashCode → int
The hash code for this object.
no setterinherited
hour24 → bool?
True if 24-hour format should be used.
final
hourInterval → int
The interval between hours in the picker. Defaults to 1.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
minuteInterval → int
The interval between minutes in the picker. Defaults to 1.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → FDateTimePickerStyleDelta
The style. If null, the default picker style will be used.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<FDateTimePicker>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

defaultDateBuilder(BuildContext context, DateTime date, DateFormat format) → Widget
The default date builder for FDateTimePicker.