FDateTimePickerControl.lifted constructor
const
FDateTimePickerControl.lifted({
- required DateTime dateTime,
- required ValueChanged<
DateTime> onChange, - Duration duration,
- Curve curve,
Creates a FDateTimePickerControl for controlling date time picker using lifted state.
It does not prevent the user from scrolling to invalid indexes. To animate back to the provided dateTime,
consider passing in onChange: (_) => setState(() {}).
The dateTime parameter contains the current selected date and time.
The onChange callback is invoked when the user selects a date and time.
The duration when animating to dateTime from an invalid/different value. Defaults to 200 milliseconds.
The curve when animating to dateTime from an invalid/different value. Defaults to Curves.easeOutCubic.
Implementation
const factory FDateTimePickerControl.lifted({
required DateTime dateTime,
required ValueChanged<DateTime> onChange,
Duration duration,
Curve curve,
}) = _Lifted;