FDateTimePickerController class final
A FDateTimePicker's controller.
- Inheritance
-
- Object
- ChangeNotifier
- ValueNotifier<
DateTime> - FDateTimePickerController
Constructors
- FDateTimePickerController({DateTime? dateTime})
- Creates a FDateTimePickerController.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- rawValue ↔ DateTime
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value ↔ DateTime
-
The current value stored in this notifier.
getter/setter pairinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
animateTo(
DateTime value, {Duration duration = const Duration(milliseconds: 300), Curve curve = Curves.easeOutCubic}) → Future< void> -
Animates the controller to the given
value.inherited -
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
rawAnimateTo(
DateTime value, Duration duration, Curve curve) → Future< void> -
Unconditionally animates the controller to the given
value.inherited -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited