rawAnimateTo method

  1. @protected
Future<void> rawAnimateTo(
  1. DateTime value,
  2. Duration duration,
  3. Curve curve
)
inherited

Unconditionally animates the controller to the given value.

Implementation

@protected
Future<void> rawAnimateTo(T value, Duration duration, Curve curve) async {
  try {
    mutating = true;
    await picker?.animateTo(encode(value), duration: duration, curve: curve);
    // The value does not need to be explicitly set as the picker will update it via a listener.
  } finally {
    mutating = false;
  }
}