FDateTimePickerManagedControl class

A FDateTimePickerManagedControl enables widgets to manage their own controller internally while exposing parameters for common configurations.

Subclass ManagedControl to create variants with different defaults or behaviors, e.g., FCalendarControl.date() vs FCalendarControl.range().

Inheritance
Mixed-in types

Constructors

FDateTimePickerManagedControl({FDateTimePickerController? controller, DateTime? initial, ValueChanged<DateTime>? onChange})
Creates a FDateTimePickerControl.
const

Properties

controller FDateTimePickerController?
The controller.
final
hashCode int
The hash code for this object.
no setterinherited
initial DateTime?
The initial date and time. Defaults to DateTime.now.
final
onChange ValueChanged<DateTime>?
Called when the date and time changes.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createController(DateFormat format, int dayInterval, int hourInterval, int minuteInterval) FDateTimePickerController
Creates a FDateTimePickerController.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited