FDateTimePickerStyleDelta class abstract
A delta that applies modifications to a FDateTimePickerStyle.
A FDateTimePickerStyle is itself a FDateTimePickerStyleDelta.
- Mixed-in types
- Implementers
Constructors
- FDateTimePickerStyleDelta.context()
-
Creates a delta that returns the FDateTimePickerStyle in the current context.
constfactory
-
FDateTimePickerStyleDelta.delta({int? dateFlex, int? hourFlex, int? minuteFlex, int? periodFlex, EdgeInsetsDirectionalDelta? padding, double? diameterRatio, double? squeeze, double? magnification, double? overAndUnderCenterOpacity, double? spacing, TextStyleDelta? textStyle, TextHeightBehavior? textHeightBehavior, double? selectionHeightAdjustment, DecorationDelta? selectionDecoration, FFocusedOutlineStyleDelta? focusedOutlineStyle, Future<
void> hapticFeedback()?}) -
Creates a partial modification of a FDateTimePickerStyle.
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
covariant FDateTimePickerStyle value) → FDateTimePickerStyle -
Applies this delta to the given value.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited