FDateTimePickerStyleDelta.delta constructor
const
FDateTimePickerStyleDelta.delta({
- int? dateFlex,
- int? hourFlex,
- int? minuteFlex,
- int? periodFlex,
- EdgeInsetsDirectionalDelta? padding,
- double? diameterRatio,
- double? squeeze,
- double? magnification,
- double? overAndUnderCenterOpacity,
- double? spacing,
- TextStyleDelta? textStyle,
- TextHeightBehavior? textHeightBehavior,
- double? selectionHeightAdjustment,
- DecorationDelta? selectionDecoration,
- FFocusedOutlineStyleDelta? focusedOutlineStyle,
- Future<
void> hapticFeedback()?,
Creates a partial modification of a FDateTimePickerStyle.
Parameters
- FDateTimePickerStyle.dateFlex - The date wheel's flex factor.
- FDateTimePickerStyle.hourFlex - The hour wheel's flex factor.
- FDateTimePickerStyle.minuteFlex - The minute wheel's flex factor.
- FDateTimePickerStyle.periodFlex - The period (AM/PM) wheel's flex factor.
- FDateTimePickerStyle.padding - The padding.
- FDateTimePickerStyle.diameterRatio - A ratio between the diameter of the cylinder and the viewport's size.
- FDateTimePickerStyle.squeeze - The angular compactness of the children on the wheel.
- FDateTimePickerStyle.magnification - The zoomed-in rate of the magnifier.
- FDateTimePickerStyle.overAndUnderCenterOpacity - The opacity value applied to the wheel above and below the magnifier.
- FDateTimePickerStyle.spacing - The spacing between the picker's wheels.
- FDateTimePickerStyle.textStyle - The picker's text style.
- FDateTimePickerStyle.textHeightBehavior - The picker's text height behavior.
- FDateTimePickerStyle.selectionHeightAdjustment - An amount to add to the height of the selection.
- FDateTimePickerStyle.selectionDecoration - The selection's decoration.
- FDateTimePickerStyle.focusedOutlineStyle - The focused outline style.
- FDateTimePickerStyle.hapticFeedback - The haptic feedback for when the picker snaps to an item.
Implementation
const factory FDateTimePickerStyleDelta.delta({
int? dateFlex,
int? hourFlex,
int? minuteFlex,
int? periodFlex,
EdgeInsetsDirectionalDelta? padding,
double? diameterRatio,
double? squeeze,
double? magnification,
double? overAndUnderCenterOpacity,
double? spacing,
TextStyleDelta? textStyle,
TextHeightBehavior? textHeightBehavior,
double? selectionHeightAdjustment,
DecorationDelta? selectionDecoration,
FFocusedOutlineStyleDelta? focusedOutlineStyle,
Future<void> Function()? hapticFeedback,
}) = _FDateTimePickerStyleDelta;