resizeToAvoidInsets property

bool resizeToAvoidInsets
final

Whether the dialog should avoid the system's view insets, typically the keyboard. Defaults to true.

Set this to false to avoid the dialog from becoming overly compressed on web & embedded platforms where the view insets comes from the surrounding host/browser environment.

Implementation

final bool resizeToAvoidInsets;