FDialogContentStyle class

FDialog content's style.

Implemented types
Mixed-in types
Available extensions

Constructors

FDialogContentStyle({required TextStyle titleTextStyle, required TextStyle bodyTextStyle, EdgeInsetsGeometry padding = const .only(left: 16, right: 16, top: 18, bottom: 18), EdgeInsetsGeometry titlePadding = const .symmetric(horizontal: 8), EdgeInsetsGeometry bodyPadding = const .symmetric(horizontal: 8), double imageSpacing = 9, double titleSpacing = 9, double contentSpacing = 20, double actionSpacing = 10, bool expandActions = true})
Creates a FDialogContentStyle.

Properties

actionSpacing double
The space between actions. Defaults to 10.
final
bodyPadding EdgeInsetsGeometry
The padding surrounding the body. Defaults to EdgeInsets.symmetric(horizontal: 8).
final
bodyTextStyle TextStyle
The body's TextStyle.
final
contentSpacing double
The spacing between the content (title/body) and the actions. Ignored if either is not provided. Defaults to 20.
final
expandActions bool
Whether each action expands to fill the available width. Defaults to true.
final
hashCode int
The hash code for this object.
no setterinherited
imageSpacing double
The spacing between the image and the title/body. Ignored if either is not provided. Defaults to 9.
final
padding EdgeInsetsGeometry
The padding surrounding the content. Defaults to EdgeInsets.only(left: 16, right: 16, top: 18, bottom: 18).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
titlePadding EdgeInsetsGeometry
The padding surrounding the title. Defaults to EdgeInsets.symmetric(horizontal: 8).
final
titleSpacing double
The spacing between the title and the body. Ignored if either is not provided. Defaults to 9.
final
titleTextStyle TextStyle
The title's TextStyle.
final

Methods

call(covariant Object _) FDialogContentStyle
Returns itself.
inherited
copyWith({TextStyleDelta? titleTextStyle, TextStyleDelta? bodyTextStyle, EdgeInsetsGeometryDelta? padding, EdgeInsetsGeometryDelta? titlePadding, EdgeInsetsGeometryDelta? bodyPadding, double? imageSpacing, double? titleSpacing, double? contentSpacing, double? actionSpacing, bool? expandActions}) FDialogContentStyle

Available on FDialogContentStyle, provided by the $FDialogContentStyleTransformations extension

Returns a copy of this FDialogContentStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FDialogContentStyle other, double t) FDialogContentStyle

Available on FDialogContentStyle, provided by the $FDialogContentStyleTransformations extension

Linearly interpolate between this and another FDialogContentStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited