FDialogContentStyles extension type

FDialog content's styles.

on
Implemented types

Constructors

FDialogContentStyles(FVariants<FDialogAxisVariantConstraint, FDialogAxisVariant, FDialogContentStyle, FDialogContentStyleDelta> _)
FDialogContentStyles.inherit({required FColors colors, required FTypography typography, required bool touch})
Creates a FDialogContentStyles that inherits its properties.
factory

Properties

base FDialogContentStyle
The base variant.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
horizontal FDialogContentStyle
The horizontal content style.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
variants Map<FDialogAxisVariantConstraint, FDialogContentStyle>
The variants.
finalinherited
vertical FDialogContentStyle
The vertical content style.
no setter

Methods

apply(List<FVariantOperation<FDialogAxisVariantConstraint, FDialogAxisVariant, FDialogContentStyle, FDialogContentStyleDelta>> operations) FVariants<FDialogAxisVariantConstraint, FDialogAxisVariant, FDialogContentStyle, FDialogContentStyleDelta>
Applies a sequence of delta-based operations to this FVariants.
inherited
applyValues(List<FVariantValueDeltaOperation<FDialogAxisVariantConstraint, FDialogAxisVariant, FDialogContentStyle, FDialogContentStyleDelta>> operations) FVariants<FDialogAxisVariantConstraint, FDialogAxisVariant, FDialogContentStyle, FDialogContentStyleDelta>
Applies a sequence of value-based operations to this FVariants.
inherited
call(covariant FVariants<FDialogAxisVariantConstraint, FDialogAxisVariant, FDialogContentStyle, FDialogContentStyleDelta> _) FVariants<FDialogAxisVariantConstraint, FDialogAxisVariant, FDialogContentStyle, FDialogContentStyleDelta>
Applies this delta to the given value.
inherited
cast<T1 extends FVariantConstraint, T2 extends FVariant>() FVariants<T1, T2, FDialogContentStyle, FDialogContentStyleDelta>
Returns a new FVariants with the variant type parameters cast to T1 and T2.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(Set<FVariant> variants) FDialogContentStyle
Returns most specific matching variant, or base if no constraints match.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited