insetCurve property

  1. @override
Curve insetCurve
final

The curve to use for the animation shown when the system keyboard intrudes into the space that the dialog is placed in. Defaults to Curves.decelerate.