FDialogRouteMotion class

Motion-related properties for FDialogRoute.

Implemented types
Mixed-in types
Available extensions

Constructors

FDialogRouteMotion({Duration entranceDuration = const Duration(milliseconds: 150), Duration exitDuration = const Duration(milliseconds: 150), Curve barrierCurve = Curves.ease})
Creates a FDialogRouteMotion.
const

Properties

barrierCurve → Curve
The curve used for the barrier's entrance and exit. Defaults to Curves.ease.
final
entranceDuration → Duration
The amount of time the entrance animation takes. Defaults to 150ms.
final
exitDuration → Duration
The amount of time the exit animation takes. Defaults to 150ms.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(covariant Object _) → FDialogRouteMotion
Returns itself.
inherited
copyWith({Duration? entranceDuration, Duration? exitDuration, Curve? barrierCurve}) → FDialogRouteMotion

Available on FDialogRouteMotion, provided by the $FDialogRouteMotionTransformations extension

Returns a copy of this FDialogRouteMotion with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FDialogRouteMotion other, double t) → FDialogRouteMotion

Available on FDialogRouteMotion, provided by the $FDialogRouteMotionTransformations extension

Linearly interpolate between this and another FDialogRouteMotion using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited