slidePressHapticFeedback property
The haptic feedback for when the user slides from one action to another when slideableActions is enabled.
Implementation
@override
final Future<void> Function() slidePressHapticFeedback;
The haptic feedback for when the user slides from one action to another when slideableActions is enabled.
@override
final Future<void> Function() slidePressHapticFeedback;