FDividerStyle class

The divider style.

The padding property can be used to indent the start and end of the separating line.

Implemented types
Mixed-in types
Available extensions

Constructors

FDividerStyle({required Color color, required EdgeInsetsGeometry padding, double width = 1})
Creates a FDividerStyle.

Properties

color → Color
The color of the separating line.
final
hashCode → int
The hash code for this object.
no setterinherited
padding → EdgeInsetsGeometry
The padding surrounding the separating line. Defaults to the appropriate padding in defaultPadding.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double
The width (thickness) of the separating line. Defaults to 1.
final

Methods

call(covariant Object _) → FDividerStyle
Returns itself.
inherited
copyWith({Color? color, EdgeInsetsGeometryDelta? padding, double? width}) → FDividerStyle

Available on FDividerStyle, provided by the $FDividerStyleTransformations extension

Returns a copy of this FDividerStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FDividerStyle other, double t) → FDividerStyle

Available on FDividerStyle, provided by the $FDividerStyleTransformations extension

Linearly interpolate between this and another FDividerStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultPadding → const ({EdgeInsets horizontalStyle, EdgeInsets verticalStyle})
The default padding for horizontal and vertical dividers.