FDividerStyles extension type

The FDivider styles.

on
Implemented types

Constructors

FDividerStyles(FVariants<FDividerAxisVariantConstraint, FDividerAxisVariant, FDividerStyle, FDividerStyleDelta> _)
FDividerStyles.inherit({required FColors colors, required FStyle style})
Creates a FDividerStyles that inherits its properties.

Properties

base → FDividerStyle
The base variant.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
horizontal → FDividerStyle
The horizontal divider style.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
variants → Map<FDividerAxisVariantConstraint, FDividerStyle>
The variants.
finalinherited
vertical → FDividerStyle
The vertical divider style.
no setter

Methods

apply(List<FVariantOperation<FDividerAxisVariantConstraint, FDividerAxisVariant, FDividerStyle, FDividerStyleDelta>> operations) → FVariants<FDividerAxisVariantConstraint, FDividerAxisVariant, FDividerStyle, FDividerStyleDelta>
Applies a sequence of delta-based operations to this FVariants.
inherited
applyValues(List<FVariantValueDeltaOperation<FDividerAxisVariantConstraint, FDividerAxisVariant, FDividerStyle, FDividerStyleDelta>> operations) → FVariants<FDividerAxisVariantConstraint, FDividerAxisVariant, FDividerStyle, FDividerStyleDelta>
Applies a sequence of value-based operations to this FVariants.
inherited
call(covariant FVariants<FDividerAxisVariantConstraint, FDividerAxisVariant, FDividerStyle, FDividerStyleDelta> _) → FVariants<FDividerAxisVariantConstraint, FDividerAxisVariant, FDividerStyle, FDividerStyleDelta>
Applies this delta to the given value.
inherited
cast<T1 extends FVariantConstraint, T2 extends FVariant>() → FVariants<T1, T2, FDividerStyle, FDividerStyleDelta>
Returns a new FVariants with the variant type parameters cast to T1 and T2.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(Set<FVariant> variants) → FDividerStyle
Returns most specific matching variant, or base if no constraints match.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited