FHeaderAction class

A FHeader action.

If the onPress and onLongPress callbacks are null, then this action will be disabled, it will not react to touch.

Inheritance

Constructors

FHeaderAction({required Widget icon, required VoidCallback? onPress, FHeaderActionStyleDelta style = const .context(), bool selected = false, String? semanticsLabel, String? semanticsTooltip, bool autofocus = false, FocusNode? focusNode, ValueChanged<bool>? onFocusChange, ValueChanged<bool>? onHoverChange, FTappableVariantChangeCallback? onVariantChange, VoidCallback? onLongPress, VoidCallback? onDoubleTap, VoidCallback? onSecondaryPress, VoidCallback? onSecondaryLongPress, Map<ShortcutActivator, Intent>? shortcuts, Map<Type, Action<Intent>>? actions, Key? key})
Creates a FHeaderAction from the given SVG icon.
const
FHeaderAction.back({required VoidCallback? onPress, FHeaderActionStyleDelta style = const .context(), String? semanticsLabel, String? semanticsTooltip, bool autofocus = false, FocusNode? focusNode, ValueChanged<bool>? onFocusChange, ValueChanged<bool>? onHoverChange, FTappableVariantChangeCallback? onVariantChange, VoidCallback? onLongPress, VoidCallback? onDoubleTap, VoidCallback? onSecondaryPress, VoidCallback? onSecondaryLongPress, Map<ShortcutActivator, Intent>? shortcuts, Map<Type, Action<Intent>>? actions, Key? key})
Creates a FHeaderAction with FIcons.arrowLeft.
factory
FHeaderAction.x({required VoidCallback? onPress, FHeaderActionStyleDelta style = const .context(), String? semanticsLabel, String? semanticsTooltip, bool autofocus = false, FocusNode? focusNode, ValueChanged<bool>? onFocusChange, ValueChanged<bool>? onHoverChange, FTappableVariantChangeCallback? onVariantChange, VoidCallback? onLongPress, VoidCallback? onDoubleTap, VoidCallback? onSecondaryPress, VoidCallback? onSecondaryLongPress, Map<ShortcutActivator, Intent>? shortcuts, Map<Type, Action<Intent>>? actions, Key? key})
Creates a FHeaderAction with FIcons.x.
factory

Properties

actions → Map<Type, Action<Intent>>?
The actions. Defaults to calling onPress when ActivateIntent is invoked and onPress is not null.
final
autofocus → bool
True if this widget will be selected as the initial focus when no other node in its scope is currently focused.
final
focusNode → FocusNode?
An optional focus node to use as the focus node for this widget.
final
hashCode → int
The hash code for this object.
no setterinherited
icon → Widget
The icon, wrapped in a IconThemeData.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onDoubleTap → VoidCallback?
A callback for when the widget is double tapped.
final
onFocusChange → ValueChanged<bool>?
Handler called when the focus changes.
final
onHoverChange → ValueChanged<bool>?
Handler called when the hover changes.
final
onLongPress → VoidCallback?
A callback for when the widget is long pressed.
final
onPress → VoidCallback?
A callback for when the widget is pressed.
final
onSecondaryLongPress → VoidCallback?
A callback for when the widget is pressed with a secondary button (usually right-click on desktop).
final
onSecondaryPress → VoidCallback?
A callback for when the widget is pressed with a secondary button (usually right-click on desktop).
final
onVariantChange → FTappableVariantChangeCallback?
Handler called when there are any changes to a tappable's FTappableVariants.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selected → bool
True if this action is currently selected. Defaults to false.
final
semanticsLabel → String?
The semantic label used by accessibility frameworks.
final
semanticsTooltip → String?
The tooltip announced by accessibility frameworks, in addition to the semantic label. Null if it has no tooltip.
final
shortcuts → Map<ShortcutActivator, Intent>?
The shortcuts. Defaults to calling ActivateIntent if onPress is not null.
final
style → FHeaderActionStyleDelta
The style.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited