onDoubleTap property

VoidCallback? onDoubleTap
final

A callback for when the widget is double tapped.

The widget will be disabled if the following are null:

Implementation

final VoidCallback? onDoubleTap;