FHeaderStyle class

A header's style.

Implemented types
Mixed-in types
Available extensions

Constructors

FHeaderStyle({required SystemUiOverlayStyle systemOverlayStyle, required EdgeInsetsGeometry padding, required TextStyle titleTextStyle, required FHeaderActionStyle actionStyle, BoxConstraints constraints = const BoxConstraints(), Decoration decoration = const BoxDecoration(), ImageFilter? backgroundFilter, double actionSpacing = 0, FVariants<FPlatformVariantConstraint, FPlatformVariant, bool, Delta> slidableActions = const .all(true)})
Creates a FHeaderStyle.
const

Properties

actionSpacing → double
The spacing between FHeaderActions. Defaults to 0.
final
actionStyle → FHeaderActionStyle
The FHeaderActions' style.
final
backgroundFilter → ImageFilter?
An optional background filter. This only takes effect if the decoration has a transparent or translucent background color.
final
constraints → BoxConstraints
The layout constraints applied to the header. Defaults to BoxConstraints().
final
decoration → Decoration
The decoration. Defaults to BoxDecoration().
final
hashCode → int
The hash code for this object.
no setterinherited
padding → EdgeInsetsGeometry
The padding.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slidableActions → FVariants<FPlatformVariantConstraint, FPlatformVariant, bool, Delta>
Whether the actions support pressing an action and sliding to another. Defaults to true.
final
systemOverlayStyle → SystemUiOverlayStyle
The system overlay style.
final
titleTextStyle → TextStyle
The title's TextStyle.
final

Methods

call(covariant Object _) → FHeaderStyle
Returns itself.
inherited
copyWith({SystemUiOverlayStyle? systemOverlayStyle, EdgeInsetsGeometryDelta? padding, TextStyleDelta? titleTextStyle, FHeaderActionStyleDelta? actionStyle, BoxConstraints? constraints, DecorationDelta? decoration, ImageFilter? backgroundFilter = Sentinels.imageFilter, double? actionSpacing, FVariantsValueDelta<FPlatformVariantConstraint, FPlatformVariant, bool, Delta>? slidableActions}) → FHeaderStyle

Available on FHeaderStyle, provided by the $FHeaderStyleTransformations extension

Returns a copy of this FHeaderStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FHeaderStyle other, double t) → FHeaderStyle

Available on FHeaderStyle, provided by the $FHeaderStyleTransformations extension

Linearly interpolate between this and another FHeaderStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited