slidableActions property
Whether the actions support pressing an action and sliding to another. Defaults to true.
Implementation
@override
final FVariants<FPlatformVariantConstraint, FPlatformVariant, bool, Delta> slidableActions;
Whether the actions support pressing an action and sliding to another. Defaults to true.
@override
final FVariants<FPlatformVariantConstraint, FPlatformVariant, bool, Delta> slidableActions;