semanticsTooltip property

String? semanticsTooltip
final

The tooltip announced by accessibility frameworks, in addition to the semantic label. Null if it has no tooltip.

Set this when wrapping this widget in an FTooltip, as a tooltip cannot annotate its child's semantics node.

Implementation

final String? semanticsTooltip;