FItemContentStyle class

An FItem content's style.

┌─────────────────────────────────────────────────────────────────────────────────────────────────────┐
│  ↕ suffixedPadding/unsuffixedPadding                                                                │
│  [prefix] ← prefixIconSpacing → [title] ← middleSpacing → [details] ← suffixIconSpacing → [suffix]  │
│                                 ↕ titleSpacing                                                      │
│                                 [subtitle]                                                          │
└─────────────────────────────────────────────────────────────────────────────────────────────────────┘
Implemented types
Mixed-in types
Implementers
Available extensions

Constructors

FItemContentStyle({required FVariants<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta> prefixIconStyle, required FVariants<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta> titleTextStyle, required FVariants<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta> subtitleTextStyle, required FVariants<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta> detailsTextStyle, required FVariants<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta> suffixIconStyle, required EdgeInsetsGeometry suffixedPadding, required EdgeInsetsGeometry unsuffixedPadding, double prefixIconSpacing = 8, double titleSpacing = 4, double middleSpacing = 4, double suffixIconSpacing = 8})
Creates a FItemContentStyle.
FItemContentStyle.inherit({required FColors colors, required FTypography typography, required Color prefix, required Color foreground, required Color mutedForeground, required bool touch})
Creates a FItemContentStyle that inherits its properties.
factory

Properties

detailsTextStyle → FVariants<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta>
The details text style.
final
hashCode → int
The hash code for this object.
no setterinherited
middleSpacing → double
The minimum horizontal spacing between the title, subtitle, combined, and the details. Defaults to 4.
final
prefixIconSpacing → double
The horizontal spacing between the prefix icon and title and the subtitle. Defaults to 8.
final
prefixIconStyle → FVariants<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta>
The prefix icon style.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitleTextStyle → FVariants<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta>
The subtitle's text style.
final
suffixedPadding → EdgeInsetsGeometry
The content's padding when a suffix is present.
final
suffixIconSpacing → double
The horizontal spacing between the details and suffix icon. Defaults to 8.
final
suffixIconStyle → FVariants<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta>
The suffix icon style.
final
titleSpacing → double
The vertical spacing between the title and the subtitle. Defaults to 4.
final
titleTextStyle → FVariants<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta>
The title's text style.
final
unsuffixedPadding → EdgeInsetsGeometry
The content's padding when no suffix is present.
final

Methods

call(covariant Object _) → FItemContentStyle
Returns itself.
inherited
copyWith({FVariantsDelta<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta>? prefixIconStyle, FVariantsDelta<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta>? titleTextStyle, FVariantsDelta<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta>? subtitleTextStyle, FVariantsDelta<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta>? detailsTextStyle, FVariantsDelta<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta>? suffixIconStyle, EdgeInsetsGeometryDelta? suffixedPadding, EdgeInsetsGeometryDelta? unsuffixedPadding, double? prefixIconSpacing, double? titleSpacing, double? middleSpacing, double? suffixIconSpacing}) → FItemContentStyle

Available on FItemContentStyle, provided by the $FItemContentStyleTransformations extension

Returns a copy of this FItemContentStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FItemContentStyle other, double t) → FItemContentStyle

Available on FItemContentStyle, provided by the $FItemContentStyleTransformations extension

Linearly interpolate between this and another FItemContentStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited