suffixIconSpacing property
The horizontal spacing between the details and suffix icon. Defaults to 8.
Contract
Throws AssertionError if suffixIconSpacing is negative.
Implementation
@override
final double suffixIconSpacing;
The horizontal spacing between the details and suffix icon. Defaults to 8.
Throws AssertionError if suffixIconSpacing is negative.
@override
final double suffixIconSpacing;