FItemData class final

The item's data.

Mixed-in types

Constructors

FItemData({FVariants<FItemVariantConstraint, FItemVariant, FItemStyle, FItemStyleDelta>? styles, double spacing = 0, FVariants<FItemGroupVariantConstraint, FItemGroupVariant, Color, Delta> dividerColor = const .all(Colors.transparent), double dividerWidth = 0, FItemDivider divider = FItemDivider.none, bool enabled = true, int index = 0, bool last = true, bool globalLast = true, bool intrinsicWidth = false})
Creates a new FItemData.
const

Properties

divider → FItemDivider
The divider used to visually separate the different items.
final
dividerColor → FVariants<FItemGroupVariantConstraint, FItemGroupVariant, Color, Delta>
The divider's style.
final
dividerWidth → double
The divider's width.
final
enabled → bool
True if enabled.
final
globalLast → bool
True if the item is the last item across all levels.
final
hashCode → int
The hash code for this object.
no setteroverride
index → int
The item's index in the current nesting level.
final
intrinsicWidth → bool
True if the group should intrinsically size to the widest child.
final
last → bool
True if the item is the last item in the current nesting level.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spacing → double
The vertical spacing at the top and bottom of each level.
final
styles → FVariants<FItemVariantConstraint, FItemVariant, FItemStyle, FItemStyleDelta>?
The item's styles.
final

Methods

debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override