FItemMixin mixin
A marker interface which denotes that mixed-in widgets is an item.
- Superclass constraints
- Mixin applications
Properties
Methods
-
createElement(
) → Element -
Inflates this configuration to a concrete instance.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
item(
{required Widget title, FItemVariant variant = .primary, FItemStyleDelta style = const .context(), bool? enabled, bool selected = false, String? semanticsLabel, bool autofocus = false, FocusNode? focusNode, ValueChanged< bool> ? onFocusChange, ValueChanged<bool> ? onHoverChange, FTappableVariantChangeCallback? onVariantChange, VoidCallback? onPress, VoidCallback? onLongPress, VoidCallback? onDoubleTap, VoidCallback? onSecondaryPress, VoidCallback? onSecondaryLongPress, Map<ShortcutActivator, Intent> ? shortcuts, Map<Type, Action< ? actions, Widget? prefix, Widget? subtitle, Widget? details, Widget? suffix, Key? key}) → FItemIntent> > - Creates a FItem.
-
raw(
{required Widget child, FItemVariant variant = .primary, FItemStyleDelta style = const .context(), bool? enabled, bool selected = false, String? semanticsLabel, bool autofocus = false, FocusNode? focusNode, ValueChanged< bool> ? onFocusChange, ValueChanged<bool> ? onHoverChange, FTappableVariantChangeCallback? onVariantChange, VoidCallback? onPress, VoidCallback? onLongPress, VoidCallback? onDoubleTap, VoidCallback? onSecondaryPress, VoidCallback? onSecondaryLongPress, Map<ShortcutActivator, Intent> ? shortcuts, Map<Type, Action< ? actions, Widget? prefix, Key? key}) → FItemIntent> > - Creates a FItem without custom layout behavior.
- Creates a FSubmenuItem.