FRawItemContentStyle class

An FItem raw content's style.

Implemented types
Mixed-in types
Implementers
Available extensions

Constructors

FRawItemContentStyle({required FVariants<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta> prefixIconStyle, required FVariants<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta> childTextStyle, required EdgeInsetsGeometry padding, double prefixIconSpacing = 8})
Creates a FRawItemContentStyle.
FRawItemContentStyle.inherit({required FColors colors, required FTypography typography, required Color prefix, required Color color, required bool touch})
Creates a FRawItemContentStyle that inherits its properties.

Properties

childTextStyle → FVariants<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta>
The child's text style.
final
hashCode → int
The hash code for this object.
no setterinherited
padding → EdgeInsetsGeometry
The content's padding.
final
prefixIconSpacing → double
The horizontal spacing between the prefix icon and child. Defaults to 8.
final
prefixIconStyle → FVariants<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta>
The prefix icon style.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(covariant Object _) → FRawItemContentStyle
Returns itself.
inherited
copyWith({FVariantsDelta<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta>? prefixIconStyle, FVariantsDelta<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta>? childTextStyle, EdgeInsetsGeometryDelta? padding, double? prefixIconSpacing}) → FRawItemContentStyle

Available on FRawItemContentStyle, provided by the $FRawItemContentStyleTransformations extension

Returns a copy of this FRawItemContentStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FRawItemContentStyle other, double t) → FRawItemContentStyle

Available on FRawItemContentStyle, provided by the $FRawItemContentStyleTransformations extension

Linearly interpolate between this and another FRawItemContentStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited