FLabel class

A component that describes a form field with a label, description, and error message (if any).

Error transition caveats

Error transitions require either a label or description to function. In the rare case where only an error is needed, set label or description to an empty widget, e.g. SizedBox.shrink.

See:

Inheritance

Constructors

FLabel({required FLabelLayout layout, required Widget child, FLabelStyleDelta style = const .context(), Widget? label, Widget? description, Widget? error, bool expands = false, Set<FFormFieldVariant> variants = const {}, Key? key})
Creates a FLabel.
const

Properties

child → Widget
The child.
final
description → Widget?
The description that elaborates on the label.
final
error → Widget?
The error message.
final
expands → bool
Whether the child should expand to fill the available space. Defaults to false.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label → Widget?
The label that describes the form field.
final
layout → FLabelLayout
The layout.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → FLabelStyleDelta
The label's style. Defaults to the appropriate style in FThemeData.labelStyles.
final
variants → Set<FFormFieldVariant>
The label's variants.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited