FLabelMotion class

Motion-related properties for FLabel animations.

All motion is automatically disabled when FAccessibility.motion is not FAccessibilityMotion.all.

Implemented types
Mixed-in types
Available extensions

Constructors

FLabelMotion({Duration textStyleTransitionDuration = const Duration(milliseconds: 100), Curve textStyleTransitionCurve = Curves.linear, Duration errorExpandDuration = const Duration(milliseconds: 100), Duration errorCollapseDuration = const Duration(milliseconds: 100), Curve errorExpandCurve = Curves.easeOut, Curve errorCollapseCurve = Curves.easeOut, Duration errorFadeInDuration = const Duration(milliseconds: 100), Duration errorFadeOutDuration = const Duration(milliseconds: 100), Curve errorFadeInCurve = Curves.linear, Curve errorFadeOutCurve = Curves.linear, Animatable<double> errorFadeTween = defaultErrorFadeTween})
Creates a FLabelMotion.
const

Properties

errorCollapseCurve → Curve
The error collapse curve. Defaults to Curves.easeOut.
final
errorCollapseDuration → Duration
The error collapse duration. Defaults to 100ms.
final
errorExpandCurve → Curve
The error expansion curve. Defaults to Curves.easeOut.
final
errorExpandDuration → Duration
The error expansion duration. Defaults to 100ms.
final
errorFadeInCurve → Curve
The error fade in curve. Defaults to Curves.linear.
final
errorFadeInDuration → Duration
The error fade in duration. Defaults to 100ms.
final
errorFadeOutCurve → Curve
The error fade out curve. Defaults to Curves.linear.
final
errorFadeOutDuration → Duration
The error fade out duration. Defaults to 100ms.
final
errorFadeTween → Animatable<double>
The error fade tween. Defaults to defaultErrorFadeTween.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textStyleTransitionCurve → Curve
The text style transition curve. Defaults to Curves.linear.
final
textStyleTransitionDuration → Duration
The text style transition duration. Defaults to 100ms.
final

Methods

call(covariant Object _) → FLabelMotion
Returns itself.
inherited
copyWith({Duration? textStyleTransitionDuration, Curve? textStyleTransitionCurve, Duration? errorExpandDuration, Duration? errorCollapseDuration, Curve? errorExpandCurve, Curve? errorCollapseCurve, Duration? errorFadeInDuration, Duration? errorFadeOutDuration, Curve? errorFadeInCurve, Curve? errorFadeOutCurve, Animatable<double>? errorFadeTween}) → FLabelMotion

Available on FLabelMotion, provided by the $FLabelMotionTransformations extension

Returns a copy of this FLabelMotion with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FLabelMotion other, double t) → FLabelMotion

Available on FLabelMotion, provided by the $FLabelMotionTransformations extension

Linearly interpolate between this and another FLabelMotion using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultErrorFadeTween → const FImmutableTween<double>
The default error fade tween.
noErrorFadeTween → const FImmutableTween<double>
A tween that does not fade the error.
none → const FLabelMotion
A FLabelMotion with no motion effects.