FLabelStyle class

The FLabel's style.

Inheritance
Implemented types
Implementers
Available extensions

Constructors

FLabelStyle({required FVariants<FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta> labelTextStyle, required FVariants<FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta> descriptionTextStyle, required FVariants<FFormFieldErrorVariantConstraint, FFormFieldErrorVariant, TextStyle, TextStyleDelta> errorTextStyle, EdgeInsetsGeometry labelPadding = .zero, EdgeInsetsGeometry descriptionPadding = .zero, EdgeInsetsGeometry errorPadding = .zero, EdgeInsetsGeometry childPadding = .zero, FLabelMotion labelMotion = const FLabelMotion()})
Creates a FLabelStyle.
const
FLabelStyle.inherit({required FStyle style, EdgeInsetsGeometry labelPadding = .zero, EdgeInsetsGeometry descriptionPadding = .zero, EdgeInsetsGeometry errorPadding = .zero, EdgeInsetsGeometry childPadding = .zero, FLabelMotion labelMotion = const FLabelMotion()})
Creates a FLabelStyle.

Properties

childPadding EdgeInsetsGeometry
The child's padding. Defaults to EdgeInsets.zero.
final
descriptionPadding EdgeInsetsGeometry
The description's padding. Defaults to EdgeInsets.zero.
final
descriptionTextStyle FVariants<FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta>
no setterinherited
errorPadding EdgeInsetsGeometry
The error's padding. Defaults to EdgeInsets.zero.
final
errorTextStyle FVariants<FFormFieldErrorVariantConstraint, FFormFieldErrorVariant, TextStyle, TextStyleDelta>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
labelMotion FLabelMotion
The motion properties for error animations. Defaults to FLabelMotion.
final
labelPadding EdgeInsetsGeometry
The label's padding. Defaults to EdgeInsets.zero.
final
labelTextStyle FVariants<FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(covariant Object _) FLabelStyle
Returns itself.
inherited
copyWith({FVariantsDelta<FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta>? labelTextStyle, FVariantsDelta<FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta>? descriptionTextStyle, FVariantsDelta<FFormFieldErrorVariantConstraint, FFormFieldErrorVariant, TextStyle, TextStyleDelta>? errorTextStyle}) FFormFieldStyle

Available on FFormFieldStyle, provided by the $FFormFieldStyleTransformations extension

Returns a copy of this FFormFieldStyle with the given properties replaced.
copyWith({EdgeInsetsGeometryDelta? labelPadding, EdgeInsetsGeometryDelta? descriptionPadding, EdgeInsetsGeometryDelta? errorPadding, EdgeInsetsGeometryDelta? childPadding, FLabelMotionDelta? labelMotion, FVariantsDelta<FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta>? labelTextStyle, FVariantsDelta<FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta>? descriptionTextStyle, FVariantsDelta<FFormFieldErrorVariantConstraint, FFormFieldErrorVariant, TextStyle, TextStyleDelta>? errorTextStyle}) FLabelStyle

Available on FLabelStyle, provided by the $FLabelStyleTransformations extension

Returns a copy of this FLabelStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FFormFieldStyle other, double t) FFormFieldStyle

Available on FFormFieldStyle, provided by the $FFormFieldStyleTransformations extension

Linearly interpolate between this and another FFormFieldStyle using the given factor t.
lerp(FLabelStyle other, double t) FLabelStyle

Available on FLabelStyle, provided by the $FLabelStyleTransformations extension

Linearly interpolate between this and another FLabelStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited