FLabelStyles class

The FLabel's styles.

Implemented types
Mixed-in types
Available extensions

Constructors

FLabelStyles({required FLabelStyle horizontalLeadingStyle, required FLabelStyle horizontalTrailingStyle, required FLabelStyle verticalStyle})
Creates a FLabelStyles.
const
FLabelStyles.inherit({required FStyle style})
Creates a FLabelStyles that inherits its properties.

Properties

hashCode → int
The hash code for this object.
no setterinherited
horizontalLeadingStyle → FLabelStyle
The FLabelLayout.horizontalLeading style.
final
horizontalTrailingStyle → FLabelStyle
The FLabelLayout.horizontalTrailing style.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
verticalStyle → FLabelStyle
The FLabelLayout.vertical style.
final

Methods

call(covariant Object _) → FLabelStyles
Returns itself.
inherited
copyWith({FLabelStyleDelta? horizontalLeadingStyle, FLabelStyleDelta? horizontalTrailingStyle, FLabelStyleDelta? verticalStyle}) → FLabelStyles

Available on FLabelStyles, provided by the $FLabelStylesTransformations extension

Returns a copy of this FLabelStyles with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FLabelStyles other, double t) → FLabelStyles

Available on FLabelStyles, provided by the $FLabelStylesTransformations extension

Linearly interpolate between this and another FLabelStyles using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited