copyWith method
- @useResult
- double? itemSpacing,
- double? contentEdgeSpacing,
- double? contentSpacing,
- FVariantsDelta<
FLineCalendarItemVariantConstraint, FLineCalendarItemVariant, Decoration, DecorationDelta> ? decoration, - FVariantsValueDelta<
FLineCalendarItemVariantConstraint, FLineCalendarItemVariant, Color, Delta> ? todayIndicatorColor, - FVariantsDelta<
FLineCalendarItemVariantConstraint, FLineCalendarItemVariant, TextStyle, TextStyleDelta> ? dateTextStyle, - FVariantsDelta<
FLineCalendarItemVariantConstraint, FLineCalendarItemVariant, TextStyle, TextStyleDelta> ? weekdayTextStyle, - FTappableStyleDelta? tappableStyle,
Returns a copy of this FLineCalendarStyle with the given properties replaced.
See customizing widget styles.
Parameters
- FLineCalendarStyle.itemSpacing - The horizontal spacing between each calendar item.
- FLineCalendarStyle.contentEdgeSpacing - The vertical height between the content and the edges.
- FLineCalendarStyle.contentSpacing - The vertical height between the date and weekday.
- FLineCalendarStyle.decoration - The decoration.
- FLineCalendarStyle.todayIndicatorColor - The color of the today indicator.
- FLineCalendarStyle.dateTextStyle - The text style for the date.
- FLineCalendarStyle.weekdayTextStyle - The text style for the day of the week.
- FLineCalendarStyle.tappableStyle - The tappable style.
Implementation
@useResult
FLineCalendarStyle copyWith({
double? itemSpacing,
double? contentEdgeSpacing,
double? contentSpacing,
FVariantsDelta<FLineCalendarItemVariantConstraint, FLineCalendarItemVariant, Decoration, DecorationDelta>?
decoration,
FVariantsValueDelta<FLineCalendarItemVariantConstraint, FLineCalendarItemVariant, Color, Delta>?
todayIndicatorColor,
FVariantsDelta<FLineCalendarItemVariantConstraint, FLineCalendarItemVariant, TextStyle, TextStyleDelta>?
dateTextStyle,
FVariantsDelta<FLineCalendarItemVariantConstraint, FLineCalendarItemVariant, TextStyle, TextStyleDelta>?
weekdayTextStyle,
FTappableStyleDelta? tappableStyle,
}) => .new(
itemSpacing: itemSpacing ?? this.itemSpacing,
contentEdgeSpacing: contentEdgeSpacing ?? this.contentEdgeSpacing,
contentSpacing: contentSpacing ?? this.contentSpacing,
decoration: decoration?.call(this.decoration) ?? this.decoration,
todayIndicatorColor: todayIndicatorColor?.call(this.todayIndicatorColor) ?? this.todayIndicatorColor,
dateTextStyle: dateTextStyle?.call(this.dateTextStyle) ?? this.dateTextStyle,
weekdayTextStyle: weekdayTextStyle?.call(this.weekdayTextStyle) ?? this.weekdayTextStyle,
tappableStyle: tappableStyle?.call(this.tappableStyle) ?? this.tappableStyle,
);