FLineCalendarControl.lifted constructor

const FLineCalendarControl.lifted({
  1. required DateTime? date,
  2. required ValueChanged<DateTime?> onChange,
  3. Predicate<DateTime> selectable,
})

Creates lifted state control.

The date parameter contains the current selected date. The onChange callback is invoked when the user selects a date. The selectable predicate determines whether a date can be selected. Defaults to always returning true.

Implementation

const factory FLineCalendarControl.lifted({
  required DateTime? date,
  required ValueChanged<DateTime?> onChange,
  Predicate<DateTime> selectable,
}) = _Lifted;