initialAlignment property
The alignment to which the initially scrolled date will be aligned. Defaults to Alignment.center.
Implementation
@override
final AlignmentDirectional? initialAlignment;
The alignment to which the initially scrolled date will be aligned. Defaults to Alignment.center.
@override
final AlignmentDirectional? initialAlignment;