FLineCalendarStyle class

FLineCalendar's style.

Implemented types
Mixed-in types
Available extensions

Constructors

FLineCalendarStyle({required FVariants<FLineCalendarItemVariantConstraint, FLineCalendarItemVariant, Decoration, DecorationDelta> decoration, required FVariants<FLineCalendarItemVariantConstraint, FLineCalendarItemVariant, Color, Delta> todayIndicatorColor, required FVariants<FLineCalendarItemVariantConstraint, FLineCalendarItemVariant, TextStyle, TextStyleDelta> dateTextStyle, required FVariants<FLineCalendarItemVariantConstraint, FLineCalendarItemVariant, TextStyle, TextStyleDelta> weekdayTextStyle, required FTappableStyle tappableStyle, double itemSpacing = 10, double contentEdgeSpacing = 13, double contentSpacing = 4})
Creates a FLineCalendarStyle.
FLineCalendarStyle.inherit({required FColors colors, required FTypography typography, required FStyle style})
Creates a FLineCalendarStyle that inherits its properties.
factory

Properties

contentEdgeSpacing double
The vertical height between the content and the edges. Defaults to 13.
final
contentSpacing double
The vertical height between the date and weekday. Defaults to 4.
final
dateTextStyle FVariants<FLineCalendarItemVariantConstraint, FLineCalendarItemVariant, TextStyle, TextStyleDelta>
The text style for the date.
final
decoration FVariants<FLineCalendarItemVariantConstraint, FLineCalendarItemVariant, Decoration, DecorationDelta>
The decoration.
final
hashCode int
The hash code for this object.
no setterinherited
itemSpacing double
The horizontal spacing between each calendar item. Defaults to 10.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tappableStyle FTappableStyle
The tappable style.
final
todayIndicatorColor FVariants<FLineCalendarItemVariantConstraint, FLineCalendarItemVariant, Color, Delta>
The color of the today indicator.
final
weekdayTextStyle FVariants<FLineCalendarItemVariantConstraint, FLineCalendarItemVariant, TextStyle, TextStyleDelta>
The text style for the day of the week.
final

Methods

call(covariant Object _) FLineCalendarStyle
Returns itself.
inherited
copyWith({double? itemSpacing, double? contentEdgeSpacing, double? contentSpacing, FVariantsDelta<FLineCalendarItemVariantConstraint, FLineCalendarItemVariant, Decoration, DecorationDelta>? decoration, FVariantsValueDelta<FLineCalendarItemVariantConstraint, FLineCalendarItemVariant, Color, Delta>? todayIndicatorColor, FVariantsDelta<FLineCalendarItemVariantConstraint, FLineCalendarItemVariant, TextStyle, TextStyleDelta>? dateTextStyle, FVariantsDelta<FLineCalendarItemVariantConstraint, FLineCalendarItemVariant, TextStyle, TextStyleDelta>? weekdayTextStyle, FTappableStyleDelta? tappableStyle}) FLineCalendarStyle

Available on FLineCalendarStyle, provided by the $FLineCalendarStyleTransformations extension

Returns a copy of this FLineCalendarStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FLineCalendarStyle other, double t) FLineCalendarStyle

Available on FLineCalendarStyle, provided by the $FLineCalendarStyleTransformations extension

Linearly interpolate between this and another FLineCalendarStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited