FLineCalendarStyleDelta class abstract
A delta that applies modifications to a FLineCalendarStyle.
A FLineCalendarStyle is itself a FLineCalendarStyleDelta.
- Mixed-in types
- Implementers
Constructors
- FLineCalendarStyleDelta.context()
-
Creates a delta that returns the FLineCalendarStyle in the current context.
constfactory
-
FLineCalendarStyleDelta.delta({double? itemSpacing, double? contentEdgeSpacing, double? contentSpacing, FVariantsDelta<
FLineCalendarItemVariantConstraint, FLineCalendarItemVariant, Decoration, DecorationDelta> ? decoration, FVariantsValueDelta<FLineCalendarItemVariantConstraint, FLineCalendarItemVariant, Color, Delta> ? todayIndicatorColor, FVariantsDelta<FLineCalendarItemVariantConstraint, FLineCalendarItemVariant, TextStyle, TextStyleDelta> ? dateTextStyle, FVariantsDelta<FLineCalendarItemVariantConstraint, FLineCalendarItemVariant, TextStyle, TextStyleDelta> ? weekdayTextStyle, FTappableStyleDelta? tappableStyle}) -
Creates a partial modification of a FLineCalendarStyle.
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
covariant FLineCalendarStyle value) → FLineCalendarStyle -
Applies this delta to the given value.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited