widgets/otp_field library Widgets

A one-time password input field.

See https://forui.dev/docs/form/otp-field for working examples.

Classes

FOtpController
A controller that manages the state of an FOtpField.
FOtpDivider
A divider between groups of items in an FOtpField.
FOtpField
A one-time password input field.
FOtpFieldControl
A FOtpFieldControl defines how a FOtpField is controlled.
FOtpFieldItemStyle
The style of an individual item in an FOtpField.
FOtpFieldItemStyleDelta
A delta that applies modifications to a FOtpFieldItemStyle.
FOtpFieldManagedControl
A FOtpFieldManagedControl enables widgets to manage their own controller internally while exposing parameters for common configurations.
FOtpFieldScope
Provides the FOtpFieldStyle to descendants.
FOtpFieldStyle
The FOtpField's style.
FOtpFieldStyleDelta
A delta that applies modifications to a FOtpFieldStyle.
FOtpItem
An item in an FOtpField.
FOtpItemScope
Provides the state of an individual item in an FOtpField to its descendants.

Mixins

FOtpItemMixin
A marker interface which denotes that mixed-in widgets are items in an OTP field.

Extension Types

FOtpFieldItemStyles
The FOtpFieldItemStyles for each variant.
FOtpFieldItemVariant
Represents a variant.
FOtpFieldItemVariantConstraint
Represents a combination of variants.