FOtpController class

A controller that manages the state of an FOtpField.

This controller does not handle formatting internally. Use TextInputFormatters on FOtpField to restrict input.

Inheritance

Constructors

FOtpController({List<Widget> children = const [FOtpItem(), FOtpItem(), FOtpItem(), FOtpItem(), FOtpItem(), FOtpItem()], TextEditingValue value = .empty})
Creates a FOtpController.

Properties

children → List<Widget>
The children, which should be FOtpItemMixins or FOtpDividers. Defaults to six FOtpItems.
final
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selection ↔ TextSelection
The currently selected range within text.
getter/setter pairinherited
text ↔ String
The current string the user is editing.
getter/setter pairinherited
value ↔ TextEditingValue
The current value stored in this notifier.
getter/setter pairinherited-getteroverride-setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
buildTextSpan({required BuildContext context, required bool withComposing, TextStyle? style}) → TextSpan
Builds TextSpan from current editing value.
override
clear() → void
Set the value to empty.
inherited
clearComposing() → void
Set the composing region to an empty range.
inherited
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() → String
A string representation of this object.
inherited
traverse({required bool forward}) → void
Handles the traversal of the OTP items when the user presses the left or right arrow key.

Operators

operator ==(Object other) → bool
The equality operator.
inherited