FOtpFieldItemStyle class

The style of an individual item in an FOtpField.

Implemented types
Mixed-in types
Available extensions

Constructors

FOtpFieldItemStyle({required Decoration decoration, required TextStyle contentTextStyle})
Creates a FOtpFieldItemStyle.
const

Properties

contentTextStyle TextStyle
The content's TextStyle.
final
decoration Decoration
The decoration.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(covariant Object _) FOtpFieldItemStyle
Returns itself.
inherited
copyWith({DecorationDelta? decoration, TextStyleDelta? contentTextStyle}) FOtpFieldItemStyle

Available on FOtpFieldItemStyle, provided by the $FOtpFieldItemStyleTransformations extension

Returns a copy of this FOtpFieldItemStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FOtpFieldItemStyle other, double t) FOtpFieldItemStyle

Available on FOtpFieldItemStyle, provided by the $FOtpFieldItemStyleTransformations extension

Linearly interpolate between this and another FOtpFieldItemStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited