FOtpFieldItemStyleDelta class abstract

A delta that applies modifications to a FOtpFieldItemStyle.

A FOtpFieldItemStyle is itself a FOtpFieldItemStyleDelta.

Mixed-in types
Implementers

Constructors

FOtpFieldItemStyleDelta.context()
Creates a delta that returns the FOtpFieldItemStyle in the current context.
const
factory
FOtpFieldItemStyleDelta.delta({DecorationDelta? decoration, TextStyleDelta? contentTextStyle})
Creates a partial modification of a FOtpFieldItemStyle.
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(covariant FOtpFieldItemStyle value) FOtpFieldItemStyle
Applies this delta to the given value.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited