end constant
FOtpFieldItemVariant
const end
The variant for the last item in a group (e.g. the last item or the last item before a divider).
Implementation
static const end = FOtpFieldItemVariant._(.new(1, 'end'));