FOtpItemScope class

Provides the state of an individual item in an FOtpField to its descendants.

Inheritance

Constructors

FOtpItemScope({required String? character, required bool focused, required bool start, required bool end, required Widget child, Key? key})
Creates an FOtpItemScope.
const

Properties

character → String?
The character to display, or null if the item is empty.
final
child → Widget
The widget below this widget in the tree.
finalinherited
end → bool
Whether this item is the last in its group (e.g. the last item or the last item before a divider).
final
focused → bool
Whether this item is focused (i.e. the caret should be shown).
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → bool
Whether this item is the first in its group (e.g. the first item or the first item after a divider).
final

Methods

createElement() → InheritedElement
Inflates this configuration to a concrete instance.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
updateShouldNotify(covariant FOtpItemScope old) → bool
Whether the framework should notify widgets that inherit from this widget.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

of(BuildContext context) → FOtpItemScope
Returns the FOtpItemScope from the enclosing FOtpField.