end property
Whether this item is the last in its group (e.g. the last item or the last item before a divider).
Implementation
final bool end;
Whether this item is the last in its group (e.g. the last item or the last item before a divider).
final bool end;