start property
Whether this item is the first in its group (e.g. the first item or the first item after a divider).
Implementation
final bool start;
Whether this item is the first in its group (e.g. the first item or the first item after a divider).
final bool start;