FPaginationController class

A controller that controls which page is selected.

Inheritance

Constructors

FPaginationController({required int pages, int page = 0, int siblings = 1, bool showEdges = true})
Creates a FPaginationController.

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
pages int
The total number of pages.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showEdges bool
Whether to show the first and last pages in the pagination. Defaults to true.
getter/setter pair
siblingRange → (int, int)
The start and end pages to display around the current page.
no setter
siblings int
The number of sibling pages displayed beside the current page number. Defaults to 1.
getter/setter pair
value int
The current value stored in this notifier.
getter/setter pairinherited-getteroverride-setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
next() → void
Moves to the next page if the current page is less than the total number of pages.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
previous() → void
Moves to the previous page if the current page is greater than 1.
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited