FPaginationStyle class

The FPagination styles.

Implemented types
Mixed-in types
Available extensions

Constructors

FPaginationStyle({required FVariants<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta> itemIconStyle, required FVariants<FTappableVariantConstraint, FTappableVariant, Decoration, DecorationDelta> itemDecoration, required FVariants<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta> itemTextStyle, required TextStyle ellipsisTextStyle, required FTappableStyle actionTappableStyle, required FTappableStyle pageTappableStyle, required FFocusedOutlineStyle focusedOutlineStyle, required BoxConstraints itemConstraints, EdgeInsets itemPadding = const .symmetric(horizontal: 2)})
Creates a FPaginationStyle.
FPaginationStyle.inherit({required FColors colors, required FTypography typography, required FStyle style, required bool touch})
Creates a FPaginationStyle that inherits its properties.

Properties

actionTappableStyle → FTappableStyle
The action's tappable style.
final
ellipsisTextStyle → TextStyle
The ellipsis's text style.
final
focusedOutlineStyle → FFocusedOutlineStyle
The pagination item's focused outline style.
final
hashCode → int
The hash code for this object.
no setterinherited
itemConstraints → BoxConstraints
The item's constraints.
final
itemDecoration → FVariants<FTappableVariantConstraint, FTappableVariant, Decoration, DecorationDelta>
The decoration applied to the pagination item.
final
itemIconStyle → FVariants<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta>
The icon's style.
final
itemPadding → EdgeInsets
The padding around each item. Defaults to EdgeInsets.symmetric(horizontal: 2)`.
final
itemTextStyle → FVariants<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta>
The default text style applied to the pagination item.
final
pageTappableStyle → FTappableStyle
The pagination item's tappable style.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(covariant Object _) → FPaginationStyle
Returns itself.
inherited
copyWith({FVariantsDelta<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta>? itemIconStyle, FVariantsDelta<FTappableVariantConstraint, FTappableVariant, Decoration, DecorationDelta>? itemDecoration, FVariantsDelta<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta>? itemTextStyle, TextStyleDelta? ellipsisTextStyle, FTappableStyleDelta? actionTappableStyle, FTappableStyleDelta? pageTappableStyle, FFocusedOutlineStyleDelta? focusedOutlineStyle, BoxConstraints? itemConstraints, EdgeInsetsDelta? itemPadding}) → FPaginationStyle

Available on FPaginationStyle, provided by the $FPaginationStyleTransformations extension

Returns a copy of this FPaginationStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FPaginationStyle other, double t) → FPaginationStyle

Available on FPaginationStyle, provided by the $FPaginationStyleTransformations extension

Linearly interpolate between this and another FPaginationStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited