copyWith method
- @useResult
- double? diameterRatio,
- double? squeeze,
- double? magnification,
- double? overAndUnderCenterOpacity,
- double? spacing,
- TextStyleDelta? textStyle,
- TextHeightBehavior? textHeightBehavior,
- double? selectionHeightAdjustment,
- DecorationDelta? selectionDecoration,
- FFocusedOutlineStyleDelta? focusedOutlineStyle,
Returns a copy of this FPickerStyle with the given properties replaced.
See customizing widget styles.
Parameters
- FPickerStyle.diameterRatio - A ratio between the diameter of the cylinder and the viewport's size.
- FPickerStyle.squeeze - The angular compactness of the children on the wheel.
- FPickerStyle.magnification - The zoomed-in rate of the magnifier.
- FPickerStyle.overAndUnderCenterOpacity - The opacity value applied to the wheel above and below the magnifier.
- FPickerStyle.spacing - The spacing between the picker's wheels.
- FPickerStyle.textStyle - The picker's text style.
- FPickerStyle.textHeightBehavior - The picker's text height behavior.
- FPickerStyle.selectionHeightAdjustment - An amount to add to the height of the selection.
- FPickerStyle.selectionDecoration - The selection's decoration.
- FPickerStyle.focusedOutlineStyle - The focused outline style.
Implementation
@useResult
FPickerStyle copyWith({
double? diameterRatio,
double? squeeze,
double? magnification,
double? overAndUnderCenterOpacity,
double? spacing,
TextStyleDelta? textStyle,
TextHeightBehavior? textHeightBehavior,
double? selectionHeightAdjustment,
DecorationDelta? selectionDecoration,
FFocusedOutlineStyleDelta? focusedOutlineStyle,
}) => .new(
diameterRatio: diameterRatio ?? this.diameterRatio,
squeeze: squeeze ?? this.squeeze,
magnification: magnification ?? this.magnification,
overAndUnderCenterOpacity: overAndUnderCenterOpacity ?? this.overAndUnderCenterOpacity,
spacing: spacing ?? this.spacing,
textStyle: textStyle?.call(this.textStyle) ?? this.textStyle,
textHeightBehavior: textHeightBehavior ?? this.textHeightBehavior,
selectionHeightAdjustment: selectionHeightAdjustment ?? this.selectionHeightAdjustment,
selectionDecoration: selectionDecoration?.call(this.selectionDecoration) ?? this.selectionDecoration,
focusedOutlineStyle: focusedOutlineStyle?.call(this.focusedOutlineStyle) ?? this.focusedOutlineStyle,
);