FPickerWheel class abstract

A picker wheel that displays a list of items that can be scrolled vertically.

It should only be used in a FPicker.

Inheritance
Mixed-in types

Constructors

FPickerWheel({required List<Widget> children, bool loop, int flex, double? itemExtent, String? semanticsLabel, String semanticsValueBuilder(int index)?, bool autofocus, FocusNode? focusNode, ValueChanged<bool>? onFocusChange, Key? key})
Creates a picker wheel with the given children.
const
factory
FPickerWheel.builder({required IndexedWidgetBuilder builder, int flex, double? itemExtent, String? semanticsLabel, String semanticsValueBuilder(int index)?, bool autofocus, FocusNode? focusNode, ValueChanged<bool>? onFocusChange, Key? key})
Creates a picker wheel with the given builder.
const
factory

Properties

autofocus → bool
True if this widget will be selected as the initial focus when no other node in its scope is currently focused.
final
flex → int
The flex factor to use for this child.
final
focusNode → FocusNode?
An optional focus node to use as the focus node for this widget.
final
hashCode → int
The hash code for this object.
no setterinherited
itemExtent → double?
The extent of each item in the picker. Defaults to the height of the picker's text style, scaled by the current TextScaler.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onFocusChange → ValueChanged<bool>?
Handler called when the focus changes.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticsLabel → String?
The semantic label used by accessibility frameworks.
final
semanticsValueBuilder → String Function(int index)?
Builds the value announced by screen readers for the item at the given index, e.g. "3".
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

estimateExtent(FPickerStyle style, BuildContext context) → double
Estimates the extent of each item in the picker based on the given style and context.