copyWith method
- @useResult
- DecorationDelta? decoration,
- ImageFilter barrierFilter()? = Sentinels.imageFilterFunction,
- ImageFilter backgroundFilter()? = Sentinels.imageFilterFunction,
- EdgeInsetsGeometryDelta? popoverPadding,
Returns a copy of this FPopoverStyle with the given properties replaced.
See customizing widget styles.
Parameters
- FPopoverStyle.decoration - The popover's decoration.
- FPopoverStyle.barrierFilter - An optional callback that takes the current animation transition value (0.0 to 1.0) and returns an ImageFilter that is used as the barrier.
- FPopoverStyle.backgroundFilter - An optional callback that takes the current animation transition value (0.0 to 1.0) and returns an ImageFilter that is used as the background.
- FPopoverStyle.popoverPadding - The additional padding between the edges of the view and the edges of the popover.
Implementation
@useResult
FPopoverStyle copyWith({
DecorationDelta? decoration,
ImageFilter Function(double)? barrierFilter = Sentinels.imageFilterFunction,
ImageFilter Function(double)? backgroundFilter = Sentinels.imageFilterFunction,
EdgeInsetsGeometryDelta? popoverPadding,
}) => .new(
decoration: decoration?.call(this.decoration) ?? this.decoration,
barrierFilter: barrierFilter == Sentinels.imageFilterFunction ? this.barrierFilter : barrierFilter,
backgroundFilter: backgroundFilter == Sentinels.imageFilterFunction ? this.backgroundFilter : backgroundFilter,
popoverPadding: popoverPadding?.call(this.popoverPadding) ?? this.popoverPadding,
);