childAnchor property

AlignmentGeometry? childAnchor
final

The anchor point on the child used for positioning relative to the popover's anchor.

For example, with childAnchor: .bottomCenter and popoverAnchor: .topCenter, the child's bottom edge will align with the popover's top edge.

Defaults to Alignment.topCenter on Android and iOS, and Alignment.bottomCenter on all other platforms. To change the platform variant, update the enclosing FTheme.platform/FAdaptiveScope.platform.

Implementation

final AlignmentGeometry? childAnchor;