popoverAnchor property

AlignmentGeometry? popoverAnchor
final

The anchor point on the popover used for positioning relative to the childAnchor.

For example, with popoverAnchor: Alignment.topCenter and childAnchor: Alignment.bottomCenter, the popover's top edge will align with the child's bottom edge.

Defaults to Alignment.bottomCenter on Android, iOS and Fuchsia, and Alignment.topCenter on all other platforms. To change the platform variant, update the enclosing FTheme.platform/FAdaptiveScope.platform.

Implementation

final AlignmentGeometry? popoverAnchor;