FPopoverController class

A controller that controls whether a FPopover is shown or hidden.

Contract

Each controller should generally be used with a single FPopover. Sharing a controller between multiple popovers is undefined behavior.

Inheritance

Constructors

FPopoverController({required TickerProvider vsync, bool shown = false})
Creates a FPopoverController with the given vsync and shown.

Properties

disposed → bool
True if this notifier has been disposed.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → AnimationStatus
The current status.
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
override
hide({bool animated = true}) → Future<void>
Hides the popover.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
show({bool animated = true}) → Future<void>
Shows the popover.
toggle({bool animated = true}) → Future<void>
Convenience method for showing/hiding the popover.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited