FPopoverMotion class

Motion-related properties for FPopover.

When FAccessibility.motion is:

Implemented types
Mixed-in types
Available extensions

Constructors

FPopoverMotion({Duration entranceDuration = const Duration(milliseconds: 100), Duration exitDuration = const Duration(milliseconds: 100), Curve expandCurve = Curves.easeOutCubic, Curve collapseCurve = Curves.easeInCubic, Curve fadeInCurve = Curves.linear, Curve fadeOutCurve = Curves.linear, Animatable<double> scaleTween = const FImmutableTween(begin: 0.93, end: 1), Animatable<double> fadeTween = const FImmutableTween(begin: 0, end: 1)})
Creates a FPopoverMotion.
const

Properties

collapseCurve → Curve
The curve used for the popover's collapse animation when exiting. Defaults to Curves.easeInCubic.
final
entranceDuration → Duration
The popover's entrance duration. Defaults to 100ms.
final
exitDuration → Duration
The popover's exit duration. Defaults to 100ms.
final
expandCurve → Curve
The curve used for the popover's expansion animation when entering. Defaults to Curves.easeOutCubic.
final
fadeInCurve → Curve
The curve used for the popover's fade-in animation when entering. Defaults to Curves.linear.
final
fadeOutCurve → Curve
The curve used for the popover's fade-out animation when exiting. Defaults to Curves.linear.
final
fadeTween → Animatable<double>
The popover's fade tween. Defaults to a tween from 0 to 1.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaleTween → Animatable<double>
The popover's scale tween. Defaults to a tween from 0.93 to 1.
final

Methods

call(covariant Object _) → FPopoverMotion
Returns itself.
inherited
copyWith({Duration? entranceDuration, Duration? exitDuration, Curve? expandCurve, Curve? collapseCurve, Curve? fadeInCurve, Curve? fadeOutCurve, Animatable<double>? scaleTween, Animatable<double>? fadeTween}) → FPopoverMotion

Available on FPopoverMotion, provided by the $FPopoverMotionTransformations extension

Returns a copy of this FPopoverMotion with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FPopoverMotion other, double t) → FPopoverMotion

Available on FPopoverMotion, provided by the $FPopoverMotionTransformations extension

Linearly interpolate between this and another FPopoverMotion using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

none → const FPopoverMotion
A FPopoverMotion with no motion effects.