FPopoverStyleDelta.delta constructor
const
FPopoverStyleDelta.delta({
- DecorationDelta? decoration,
- ImageFilter barrierFilter()?,
- ImageFilter backgroundFilter()?,
- EdgeInsetsGeometryDelta? popoverPadding,
- FPopoverMotionDelta? motion,
Creates a partial modification of a FPopoverStyle.
Parameters
- FPopoverStyle.decoration - The popover's decoration.
- FPopoverStyle.barrierFilter - An optional callback that takes the current animation transition value (0.0 to 1.0) and returns an ImageFilter that is used as the barrier.
- FPopoverStyle.backgroundFilter - An optional callback that takes the current animation transition value (0.0 to 1.0) and returns an ImageFilter that is used as the background.
- FPopoverStyle.popoverPadding - The additional padding between the edges of the view and the edges of the popover.
- FPopoverStyle.motion - The popover's motion configuration.
Implementation
const factory FPopoverStyleDelta.delta({
DecorationDelta? decoration,
ImageFilter Function(double)? barrierFilter,
ImageFilter Function(double)? backgroundFilter,
EdgeInsetsGeometryDelta? popoverPadding,
FPopoverMotionDelta? motion,
}) = _FPopoverStyleDelta;