widgets/popover_menu library Widgets

A popover menu displays a menu in a portal aligned to a child.

See https://forui.dev/docs/overlay/popover-menu for working examples.

Classes

FPopoverMenu
A popover menu displays a menu in a portal aligned to a child.
FPopoverMenuMotion
Motion-related properties for the submenu fade effect in FPopoverMenu.
FPopoverMenuMotionDelta
A delta that applies modifications to a FPopoverMenuMotion.
FPopoverMenuStyle
A FPopoverMenuStyle's style.
FPopoverMenuStyleDelta
A delta that applies modifications to a FPopoverMenuStyle.
FSubmenuItem
An item that opens a nested popover menu.
FSubmenuTile
A tile that opens a nested popover menu to the side on tap.