copyWith method
- @useResult
- FItemGroupStyleDelta? itemGroupStyle,
- FTileGroupStyleDelta? tileGroupStyle,
- double? minWidth,
- double? maxWidth,
- Duration? hoverEnterDuration,
- Future<
void> hapticFeedback()?, - DecorationDelta? decoration,
- ImageFilter Function(double)? barrierFilter()?,
- ImageFilter Function(double)? backgroundFilter()?,
- EdgeInsetsGeometryDelta? popoverPadding,
- FPopoverMotionDelta? motion,
Returns a copy of this FPopoverMenuStyle with the given properties replaced.
See customizing widget styles.
Parameters
- FPopoverMenuStyle.itemGroupStyle - The item group's style.
- FPopoverMenuStyle.tileGroupStyle - The tile group's style.
- FPopoverMenuStyle.minWidth - The menu's min width.
- FPopoverMenuStyle.maxWidth - The menu's max width.
- FPopoverMenuStyle.hoverEnterDuration - The delay before showing a submenu when the pointer enters an item.
- FPopoverMenuStyle.menuMotion - The popover menu's motion configuration.
- FPopoverMenuStyle.hapticFeedback - The haptic feedback for when a submenu is shown via long press.
- FPopoverMenuStyle.decoration - The popover's decoration.
- FPopoverMenuStyle.barrierFilter - An optional callback that takes the current animation transition value (0.0 to 1.0) and returns an ImageFilter that is used as the barrier.
- FPopoverMenuStyle.backgroundFilter - An optional callback that takes the current animation transition value (0.0 to 1.0) and returns an ImageFilter that is used as the background.
- FPopoverMenuStyle.popoverPadding - The additional padding between the edges of the view and the edges of the popover.
- FPopoverMenuStyle.motion - The popover's motion configuration.
Implementation
@useResult
FPopoverMenuStyle copyWith({
FItemGroupStyleDelta? itemGroupStyle,
FTileGroupStyleDelta? tileGroupStyle,
double? minWidth,
double? maxWidth,
Duration? hoverEnterDuration,
FPopoverMenuMotionDelta? menuMotion,
Future<void> Function()? hapticFeedback,
DecorationDelta? decoration,
ImageFilter Function(double)? Function()? barrierFilter,
ImageFilter Function(double)? Function()? backgroundFilter,
EdgeInsetsGeometryDelta? popoverPadding,
FPopoverMotionDelta? motion,
}) => .new(
itemGroupStyle: itemGroupStyle?.call(this.itemGroupStyle) ?? this.itemGroupStyle,
tileGroupStyle: tileGroupStyle?.call(this.tileGroupStyle) ?? this.tileGroupStyle,
minWidth: minWidth ?? this.minWidth,
maxWidth: maxWidth ?? this.maxWidth,
hoverEnterDuration: hoverEnterDuration ?? this.hoverEnterDuration,
menuMotion: menuMotion?.call(this.menuMotion) ?? this.menuMotion,
hapticFeedback: hapticFeedback ?? this.hapticFeedback,
decoration: decoration?.call(this.decoration) ?? this.decoration,
barrierFilter: barrierFilter == null ? this.barrierFilter : barrierFilter(),
backgroundFilter: backgroundFilter == null ? this.backgroundFilter : backgroundFilter(),
popoverPadding: popoverPadding?.call(this.popoverPadding) ?? this.popoverPadding,
motion: motion?.call(this.motion) ?? this.motion,
);