faded property
Whether the parent menu fades when a submenu is active.
Defaults to true on touch platforms and false on desktop.
Implementation
final bool? faded;
Whether the parent menu fades when a submenu is active.
Defaults to true on touch platforms and false on desktop.
final bool? faded;