intrinsicWidth property
Whether the menu should intrinsically size to the widest child. Defaults to true.
Implementation
final bool intrinsicWidth;
Whether the menu should intrinsically size to the widest child. Defaults to true.
final bool intrinsicWidth;