spacing property

FPortalSpacing spacing
final

The spacing between the popover and child anchors.

Applied before overflow.

It is recommended that the spacing be at least FPortalArrowStyle.height to prevent the arrow overlapping with the anchor when an arrow is set.

Implementation

final FPortalSpacing spacing;