FPopoverMenuMotion class

Motion-related properties for the submenu fade effect in FPopoverMenu.

Implemented types
Mixed-in types
Available extensions

Constructors

FPopoverMenuMotion({double fade = 0.4, Duration fadeDuration = const Duration(milliseconds: 100), Curve fadeCurve = Curves.linear})
Creates a FPopoverMenuMotion.
const

Properties

fade → double
The fade applied to the parent menu when a submenu is active. Defaults to 0.4.
final
fadeCurve → Curve
The fade curve. Defaults to Curves.linear.
final
fadeDuration → Duration
The fade duration. Defaults to 100ms.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(covariant Object _) → FPopoverMenuMotion
Returns itself.
inherited
copyWith({double? fade, Duration? fadeDuration, Curve? fadeCurve}) → FPopoverMenuMotion

Available on FPopoverMenuMotion, provided by the $FPopoverMenuMotionTransformations extension

Returns a copy of this FPopoverMenuMotion with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FPopoverMenuMotion other, double t) → FPopoverMenuMotion

Available on FPopoverMenuMotion, provided by the $FPopoverMenuMotionTransformations extension

Linearly interpolate between this and another FPopoverMenuMotion using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

none → const FPopoverMenuMotion
A FPopoverMenuMotion with no motion effects.