FPopoverMenuStyle class

A FPopoverMenuStyle's style.

Inheritance
Implemented types
Available extensions

Constructors

FPopoverMenuStyle({required FItemGroupStyle itemGroupStyle, required FTileGroupStyle tileGroupStyle, required Decoration decoration, required Future<void> hapticFeedback(), double minWidth = 150, double maxWidth = 250, Duration hoverEnterDuration = const Duration(milliseconds: 150), FPopoverMenuMotion menuMotion = const FPopoverMenuMotion(), ImageFilter barrierFilter(BuildContext context, double animation)?, ImageFilter backgroundFilter(BuildContext context, double animation)?, EdgeInsetsGeometry popoverPadding = const .all(5), FPortalArrowStyle arrowStyle = const FPortalArrowStyle(), FPopoverMotion motion = const FPopoverMotion()})
Creates a FPopoverMenuStyle.
const
FPopoverMenuStyle.inherit({required FColors colors, required FStyle style, required FTypography typography, required FHapticFeedback hapticFeedback, required bool touch})
Creates a FPopoverMenuStyle that inherits its properties.

Properties

arrowStyle → FPortalArrowStyle
no setterinherited
backgroundFilter → ImageFilter Function(BuildContext context, double animation)?
no setterinherited
barrierFilter → ImageFilter Function(BuildContext context, double animation)?
no setterinherited
decoration → Decoration
no setterinherited
hapticFeedback → Future<void> Function()
The haptic feedback for when a submenu is shown via long press.
final
hashCode → int
The hash code for this object.
no setterinherited
hoverEnterDuration → Duration
The delay before showing a submenu when the pointer enters an item. Defaults to 150ms.
final
itemGroupStyle → FItemGroupStyle
The item group's style.
final
maxWidth → double
The menu's max width. Defaults to 250.
final
The popover menu's motion configuration. Defaults to FPopoverMenuMotion.
final
minWidth → double
The menu's min width. Defaults to 150.
final
motion → FPopoverMotion
no setterinherited
popoverPadding → EdgeInsetsGeometry
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tileGroupStyle → FTileGroupStyle
The tile group's style.
final

Methods

call(covariant Object _) → FPopoverMenuStyle
Returns itself.
inherited
copyWith({FItemGroupStyleDelta? itemGroupStyle, FTileGroupStyleDelta? tileGroupStyle, Future<void> hapticFeedback()?, double? minWidth, double? maxWidth, Duration? hoverEnterDuration, FPopoverMenuMotionDelta? menuMotion, DecorationDelta? decoration, ImageFilter Function(BuildContext context, double animation)? barrierFilter()?, ImageFilter Function(BuildContext context, double animation)? backgroundFilter()?, EdgeInsetsGeometryDelta? popoverPadding, FPortalArrowStyleDelta? arrowStyle, FPopoverMotionDelta? motion}) → FPopoverMenuStyle

Available on FPopoverMenuStyle, provided by the $FPopoverMenuStyleTransformations extension

Returns a copy of this FPopoverMenuStyle with the given properties replaced.
copyWith({DecorationDelta? decoration, ImageFilter barrierFilter(BuildContext context, double animation)? = Sentinels.imageFilterFunction, ImageFilter backgroundFilter(BuildContext context, double animation)? = Sentinels.imageFilterFunction, EdgeInsetsGeometryDelta? popoverPadding, FPortalArrowStyleDelta? arrowStyle, FPopoverMotionDelta? motion}) → FPopoverStyle

Available on FPopoverStyle, provided by the $FPopoverStyleTransformations extension

Returns a copy of this FPopoverStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FPopoverMenuStyle other, double t) → FPopoverMenuStyle

Available on FPopoverMenuStyle, provided by the $FPopoverMenuStyleTransformations extension

Linearly interpolate between this and another FPopoverMenuStyle using the given factor t.
lerp(FPopoverStyle other, double t) → FPopoverStyle

Available on FPopoverStyle, provided by the $FPopoverStyleTransformations extension

Linearly interpolate between this and another FPopoverStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited