FPopoverMenuStyleDelta.delta constructor
const
FPopoverMenuStyleDelta.delta({
- FItemGroupStyleDelta? itemGroupStyle,
- FTileGroupStyleDelta? tileGroupStyle,
- double? minWidth,
- double? maxWidth,
- Duration? hoverEnterDuration,
- Future<
void> hapticFeedback()?, - DecorationDelta? decoration,
- ImageFilter Function(double)? barrierFilter()?,
- ImageFilter Function(double)? backgroundFilter()?,
- EdgeInsetsGeometryDelta? popoverPadding,
- FPopoverMotionDelta? motion,
Creates a partial modification of a FPopoverMenuStyle.
Parameters
- FPopoverMenuStyle.itemGroupStyle - The item group's style.
- FPopoverMenuStyle.tileGroupStyle - The tile group's style.
- FPopoverMenuStyle.minWidth - The menu's min width.
- FPopoverMenuStyle.maxWidth - The menu's max width.
- FPopoverMenuStyle.hoverEnterDuration - The delay before showing a submenu when the pointer enters an item.
- FPopoverMenuStyle.menuMotion - The popover menu's motion configuration.
- FPopoverMenuStyle.hapticFeedback - The haptic feedback for when a submenu is shown via long press.
- FPopoverMenuStyle.decoration - The popover's decoration.
- FPopoverMenuStyle.barrierFilter - An optional callback that takes the current animation transition value (0.0 to 1.0) and returns an ImageFilter that is used as the barrier.
- FPopoverMenuStyle.backgroundFilter - An optional callback that takes the current animation transition value (0.0 to 1.0) and returns an ImageFilter that is used as the background.
- FPopoverMenuStyle.popoverPadding - The additional padding between the edges of the view and the edges of the popover.
- FPopoverMenuStyle.motion - The popover's motion configuration.
Implementation
const factory FPopoverMenuStyleDelta.delta({
FItemGroupStyleDelta? itemGroupStyle,
FTileGroupStyleDelta? tileGroupStyle,
double? minWidth,
double? maxWidth,
Duration? hoverEnterDuration,
FPopoverMenuMotionDelta? menuMotion,
Future<void> Function()? hapticFeedback,
DecorationDelta? decoration,
ImageFilter Function(double)? Function()? barrierFilter,
ImageFilter Function(double)? Function()? backgroundFilter,
EdgeInsetsGeometryDelta? popoverPadding,
FPopoverMotionDelta? motion,
}) = _FPopoverMenuStyleDelta;