itemAnchor property
The anchor point on the trigger item used for positioning.
Defaults to AlignmentGeometry.topEnd on desktop platforms and Alignment.topCenter on touch platforms.
Implementation
final AlignmentGeometry? itemAnchor;
The anchor point on the trigger item used for positioning.
Defaults to AlignmentGeometry.topEnd on desktop platforms and Alignment.topCenter on touch platforms.
final AlignmentGeometry? itemAnchor;