onVariantChange property
Called when the variant state of the trigger item changes.
Implementation
final FTappableVariantChangeCallback? onVariantChange;
Called when the variant state of the trigger item changes.
final FTappableVariantChangeCallback? onVariantChange;