submenuAnchor property
The anchor point on the submenu used for positioning.
Defaults to AlignmentGeometry.topStart on desktop platforms and Alignment.bottomCenter on touch platforms.
Implementation
final AlignmentGeometry? submenuAnchor;
The anchor point on the submenu used for positioning.
Defaults to AlignmentGeometry.topStart on desktop platforms and Alignment.bottomCenter on touch platforms.
final AlignmentGeometry? submenuAnchor;