submenuIntrinsicWidth property
Whether the submenu should size itself to the intrinsic width of its children.
Implementation
final bool? submenuIntrinsicWidth;
Whether the submenu should size itself to the intrinsic width of its children.
final bool? submenuIntrinsicWidth;