submenuSpacing property
The spacing between the submenu and the trigger tile.
Defaults to FPortalSpacing.zero.
Implementation
final FPortalSpacing submenuSpacing;
The spacing between the submenu and the trigger tile.
Defaults to FPortalSpacing.zero.
final FPortalSpacing submenuSpacing;