FCircularProgressMotion class

Motion-related properties for FCircularProgress.

All motion is automatically disabled when FAccessibility.motion is FAccessibilityMotion.disabled.

Implemented types
Mixed-in types
Available extensions

Constructors

FCircularProgressMotion({Duration duration = const Duration(seconds: 1), Curve curve = Curves.linear, Animatable<double> tween = const FImmutableTween(begin: 0.0, end: 1.0)})
Creates a FCircularProgressMotion.
const

Properties

curve → Curve
The animation curve. Defaults to Curves.linear.
final
duration → Duration
The duration of one full rotation. Defaults to 1s.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tween → Animatable<double>
The rotation's tween. Defaults to FImmutableTween(begin: 0.0, end: 1.0). Reverse to rotate counter-clockwise.
final

Methods

call(covariant Object _) → FCircularProgressMotion
Returns itself.
inherited
copyWith({Duration? duration, Curve? curve, Animatable<double>? tween}) → FCircularProgressMotion

Available on FCircularProgressMotion, provided by the $FCircularProgressMotionTransformations extension

Returns a copy of this FCircularProgressMotion with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FCircularProgressMotion other, double t) → FCircularProgressMotion

Available on FCircularProgressMotion, provided by the $FCircularProgressMotionTransformations extension

Linearly interpolate between this and another FCircularProgressMotion using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited