FDeterminateProgressMotion class

Motion-related properties for a FDeterminateProgress.

Implemented types
Mixed-in types
Available extensions

Constructors

FDeterminateProgressMotion({Duration duration = const Duration(milliseconds: 1000), Curve curve = Curves.linear})
Creates a FDeterminateProgressMotion.
const

Properties

curve Curve
The animation curve. Defaults to Curves.linear.
final
duration Duration
The animation's duration. Defaults to 1s.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(covariant Object _) FDeterminateProgressMotion
Returns itself.
inherited
copyWith({Duration? duration, Curve? curve}) FDeterminateProgressMotion

Available on FDeterminateProgressMotion, provided by the $FDeterminateProgressMotionTransformations extension

Returns a copy of this FDeterminateProgressMotion with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FDeterminateProgressMotion other, double t) FDeterminateProgressMotion

Available on FDeterminateProgressMotion, provided by the $FDeterminateProgressMotionTransformations extension

Linearly interpolate between this and another FDeterminateProgressMotion using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited