FProgressMotion class

Motion-related properties for an indeterminate FProgress.

All motion is automatically disabled when FAccessibility.motion is FAccessibilityMotion.disabled.

Implemented types
Mixed-in types
Available extensions

Constructors

FProgressMotion({Duration period = const Duration(milliseconds: 1000), Duration interval = const Duration(milliseconds: 500), Curve curve = Curves.ease, double value = 0.4})
Creates a FProgressMotion.
const

Properties

curve → Curve
The animation curve. Defaults to Curves.ease.
final
hashCode → int
The hash code for this object.
no setterinherited
interval → Duration
The interval between animations. Defaults to 500ms.
final
period → Duration
The animation's period. Defaults to 1s.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → double
The percentage of the filled progress. Defaults to 0.4.
final

Methods

call(covariant Object _) → FProgressMotion
Returns itself.
inherited
copyWith({Duration? period, Duration? interval, Curve? curve, double? value}) → FProgressMotion

Available on FProgressMotion, provided by the $FProgressMotionTransformations extension

Returns a copy of this FProgressMotion with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FProgressMotion other, double t) → FProgressMotion

Available on FProgressMotion, provided by the $FProgressMotionTransformations extension

Linearly interpolate between this and another FProgressMotion using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited