FProgressMotionDelta class abstract

A delta that applies modifications to a FProgressMotion.

A FProgressMotion is itself a FProgressMotionDelta.

Mixed-in types
Implementers

Constructors

FProgressMotionDelta.context()
Creates a delta that returns the FProgressMotion in the current context.
const
factory
FProgressMotionDelta.delta({Duration? period, Duration? interval, Curve? curve, double? value})
Creates a partial modification of a FProgressMotion.
const
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(covariant FProgressMotion value) → FProgressMotion
Applies this delta to the given value.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited