FRadio class

A radio button that typically allows the user to choose only one of a predefined set of options.

It is recommended to use FSelectGroup in conjunction with FSelectGroupItemMixin.radio to create a group of radio buttons.

Error transition caveats

Error transitions require either a label or description to function. In the rare case where only an error is needed, set label or description to an empty widget, e.g. SizedBox.shrink.

See:

Inheritance

Constructors

FRadio({FRadioStyleDelta style = const .context(), bool leadingLabel = false, Widget? label, Widget? description, Widget? error, String? semanticsLabel, bool value = false, ValueChanged<bool>? onChange, bool enabled = true, bool autofocus = false, FocusNode? focusNode, ValueChanged<bool>? onFocusChange, Key? key})
Creates a FRadio.
const

Properties

autofocus → bool
True if this widget will be selected as the initial focus when no other node in its scope is currently focused.
final
description → Widget?
The description displayed below the label.
final
enabled → bool
Whether this radio is enabled. Defaults to true.
final
error → Widget?
The error displayed below the description.
final
focusNode → FocusNode?
An optional focus node to use as the focus node for this widget.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label → Widget?
The label displayed next to the radio.
final
leadingLabel → bool
Whether the label is positioned before the radio (leading) instead of after it (trailing). Defaults to false.
final
onChange → ValueChanged<bool>?
Called when the user initiates a change to the FRadio's value: when they have checked or unchecked this box.
final
onFocusChange → ValueChanged<bool>?
Handler called when the focus changes.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticsLabel → String?
The semantic label used by accessibility frameworks.
final
style → FRadioStyleDelta
The style. Defaults to FThemeData.radioStyle.
final
value → bool
The current value of the radio.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited