FRadioMotion class

The motion-related properties for a FRadio.

All motion is automatically disabled when FAccessibility.motion is FAccessibilityMotion.disabled.

Implemented types
Mixed-in types
Available extensions

Constructors

FRadioMotion({Duration transitionDuration = const Duration(milliseconds: 100), Curve transitionCurve = Curves.linear, Duration selectDuration = const Duration(milliseconds: 100), Duration unselectDuration = const Duration(milliseconds: 100), Curve selectCurve = Curves.easeOutCirc})
Creates a FRadioMotion.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectCurve → Curve
The curve of the select & unselect animation. Defaults to Curves.easeOutCirc.
final
selectDuration → Duration
The duration of the animation when selected. Defaults to 100ms.
final
transitionCurve → Curve
The curve of the transition between states. Defaults to Curves.linear.
final
transitionDuration → Duration
The duration of the transition between states. Defaults to 100ms.
final
unselectDuration → Duration
The duration of the animation when unselected. Defaults to 100ms.
final

Methods

call(covariant Object _) → FRadioMotion
Returns itself.
inherited
copyWith({Duration? transitionDuration, Curve? transitionCurve, Duration? selectDuration, Duration? unselectDuration, Curve? selectCurve}) → FRadioMotion

Available on FRadioMotion, provided by the $FRadioMotionTransformations extension

Returns a copy of this FRadioMotion with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FRadioMotion other, double t) → FRadioMotion

Available on FRadioMotion, provided by the $FRadioMotionTransformations extension

Linearly interpolate between this and another FRadioMotion using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited