FRadioStyle class

A FRadio's style.

Implemented types
Mixed-in types
Available extensions

Constructors

FRadioStyle({required FTappableStyle tappableStyle, required FFocusedOutlineStyle focusedOutlineStyle, required EdgeInsetsGeometry padding, required FVariants<FRadioVariantConstraint, FRadioVariant, Color, Delta> borderColor, required double borderWidth, required FVariants<FRadioVariantConstraint, FRadioVariant, Color, Delta> backgroundColor, required FVariants<FRadioVariantConstraint, FRadioVariant, Color, Delta> indicatorColor, required double indicatorSize, required FLabelStyle leadingLabelStyle, required FLabelStyle trailingLabelStyle, FRadioMotion motion = const FRadioMotion()})
Creates a FRadioStyle.
const
FRadioStyle.inherit({required FColors colors, required FStyle style, required bool touch})
Creates a FRadioStyle that inherits its properties.
factory

Properties

backgroundColor → FVariants<FRadioVariantConstraint, FRadioVariant, Color, Delta>
The FRadio's background color.
final
borderColor → FVariants<FRadioVariantConstraint, FRadioVariant, Color, Delta>
The FRadio's border color.
final
borderWidth → double
The border width.
final
focusedOutlineStyle → FFocusedOutlineStyle
The focused outline style.
final
hashCode → int
The hash code for this object.
no setterinherited
indicatorColor → FVariants<FRadioVariantConstraint, FRadioVariant, Color, Delta>
The FRadio's indicator color.
final
indicatorSize → double
The inner indicator's size.
final
leadingLabelStyle → FLabelStyle
The label style when FRadio.leadingLabel is true.
final
motion → FRadioMotion
The motion-related properties. Defaults to FRadioMotion.
final
padding → EdgeInsetsGeometry
The padding between the border and indicator circles.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tappableStyle → FTappableStyle
The tappable style.
final
trailingLabelStyle → FLabelStyle
The label style when FRadio.leadingLabel is false (the default).
final

Methods

call(covariant Object _) → FRadioStyle
Returns itself.
inherited
copyWith({FTappableStyleDelta? tappableStyle, FFocusedOutlineStyleDelta? focusedOutlineStyle, EdgeInsetsGeometryDelta? padding, FVariantsValueDelta<FRadioVariantConstraint, FRadioVariant, Color, Delta>? borderColor, double? borderWidth, FVariantsValueDelta<FRadioVariantConstraint, FRadioVariant, Color, Delta>? backgroundColor, FVariantsValueDelta<FRadioVariantConstraint, FRadioVariant, Color, Delta>? indicatorColor, double? indicatorSize, FLabelStyleDelta? leadingLabelStyle, FLabelStyleDelta? trailingLabelStyle, FRadioMotionDelta? motion}) → FRadioStyle

Available on FRadioStyle, provided by the $FRadioStyleTransformations extension

Returns a copy of this FRadioStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FRadioStyle other, double t) → FRadioStyle

Available on FRadioStyle, provided by the $FRadioStyleTransformations extension

Linearly interpolate between this and another FRadioStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited