FResizableController class abstract interface

A controller that manages the resizing of regions in a FResizable.

Inheritance

Constructors

FResizableController({void onResizeUpdate(List<FResizableRegionData> resized)?, void onResizeEnd(List<FResizableRegionData> resized)?, double hapticFeedbackVelocity})
Creates a FResizableController.
factory
FResizableController.cascade({void onResizeUpdate(List<FResizableRegionData> resized)?, void onResizeEnd(UnmodifiableListView<FResizableRegionData> all)?, double hapticFeedbackVelocity})
Creates a FResizableController that cascades shrinking of a region below its minimum extent to its neighbours.
factory

Properties

disposed → bool
True if this notifier has been disposed.
no setterinherited
hapticFeedbackVelocity → double
The minimum absolute per-frame delta, in pixels, required for haptic feedback to fire on a collision between neighbouring regions.
final
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
regions → List<FResizableRegionData>
The resizable regions. The regions are ordered from top to bottom, or left to right, depending on the resizable axis.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
end(int left, int right) → void
Notifies the region at the indexes that they and their neighbours have been resized.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
resize(int left, int right, double delta) → List<FResizableRegionData>
Returns the regions resized by delta.
toString() → String
A string representation of this object.
inherited
update(int left, int right, double delta) → bool
Updates the regions at the given indexes in addition to their neighbours. Returns true if haptic feedback should be performed.

Operators

operator ==(Object other) → bool
The equality operator.
inherited