FResizableDividerThumbStyle class

The style of the dividers' thumbs between FResizableRegions.

Implemented types
Mixed-in types
Available extensions

Constructors

FResizableDividerThumbStyle({required Decoration decoration, required Color foregroundColor, required FIconBuilder icon, required double height, required double width})
Creates a FResizableDividerThumbStyle.

Properties

decoration Decoration
The background color.
final
foregroundColor Color
The foreground color.
final
hashCode int
The hash code for this object.
no setterinherited
height double
The height.
final
icon FIconBuilder
The thumb icon builder. Defaults to FIcons.gripVertical (horizontal axis) or FIcons.gripHorizontal (vertical axis).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double
The width.
final

Methods

call(covariant Object _) FResizableDividerThumbStyle
Returns itself.
inherited
copyWith({DecorationDelta? decoration, Color? foregroundColor, Widget icon(BuildContext, {String? semanticsLabel})?, double? height, double? width}) FResizableDividerThumbStyle

Available on FResizableDividerThumbStyle, provided by the $FResizableDividerThumbStyleTransformations extension

Returns a copy of this FResizableDividerThumbStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FResizableDividerThumbStyle other, double t) FResizableDividerThumbStyle

Available on FResizableDividerThumbStyle, provided by the $FResizableDividerThumbStyleTransformations extension

Linearly interpolate between this and another FResizableDividerThumbStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited