FResizableRegion class sealed

A resizable region that can be resized along the parent FResizable's axis. It should always be in a FResizable.

See https://forui.dev/docs/widgets/layout/resizable for working examples.

Inheritance

Constructors

FResizableRegion.fixed({required double extent, required ValueWidgetBuilder<FResizableRegionData> builder, double? minExtent, Widget? child, Key? key})
Creates a FResizableRegion with a concrete initial extent in logical pixels.
factory
FResizableRegion.flex({required ValueWidgetBuilder<FResizableRegionData> builder, int flex, int? minFlex, Widget? child, Key? key})
Creates a FResizableRegion that is sized proportionally from the remaining space.
const
factory

Properties

builder → ValueWidgetBuilder<FResizableRegionData>
The builder used to create a child to display in this region.
final
child → Widget?
A height/width-independent widget which is passed back to the builder.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited