FScaffoldStyle class

The scaffold style.

Implemented types
Mixed-in types
Available extensions

Constructors

FScaffoldStyle({required SystemUiOverlayStyle systemOverlayStyle, required Color backgroundColor, required Color sidebarBackgroundColor, required EdgeInsetsGeometry childPadding, required Decoration footerDecoration, Decoration headerDecoration = const BoxDecoration()})
Creates a FScaffoldStyle.
FScaffoldStyle.inherit({required FColors colors, required FStyle style})
Creates a FScaffoldStyle that inherits its properties.

Properties

backgroundColor → Color
The background color.
final
childPadding → EdgeInsetsGeometry
The child padding. Only used when FScaffold.childPad is true.
final
footerDecoration → Decoration
The footer decoration.
final
hashCode → int
The hash code for this object.
no setterinherited
headerDecoration → Decoration
The header decoration. Defaults to BoxDecoration().
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sidebarBackgroundColor → Color
The sidebar background color.
final
systemOverlayStyle → SystemUiOverlayStyle
The fallback system overlay style.
final

Methods

call(covariant Object _) → FScaffoldStyle
Returns itself.
inherited
copyWith({SystemUiOverlayStyle? systemOverlayStyle, Color? backgroundColor, Color? sidebarBackgroundColor, EdgeInsetsGeometryDelta? childPadding, DecorationDelta? footerDecoration, DecorationDelta? headerDecoration}) → FScaffoldStyle

Available on FScaffoldStyle, provided by the $FScaffoldStyleTransformations extension

Returns a copy of this FScaffoldStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FScaffoldStyle other, double t) → FScaffoldStyle

Available on FScaffoldStyle, provided by the $FScaffoldStyleTransformations extension

Linearly interpolate between this and another FScaffoldStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited