systemOverlayStyle property
The fallback system overlay style.
This is used as a fallback when no other widgets override AnnotatedRegion<SystemUiOverlayStyle>. Typically, the SystemUiOverlayStyle property is overridden by FHeader.
The fallback system overlay style.
This is used as a fallback when no other widgets override AnnotatedRegion<SystemUiOverlayStyle>. Typically, the SystemUiOverlayStyle property is overridden by FHeader.