copyWith method
- @useResult
- FSelectSectionStyleDelta? sectionStyle,
- FSelectScrollHandleStyleDelta? scrollHandleStyle,
- EdgeInsetsGeometryDelta? padding,
- DecorationDelta? decoration,
- ImageFilter Function(double)? barrierFilter()?,
- ImageFilter Function(double)? backgroundFilter()?,
- EdgeInsetsGeometryDelta? popoverPadding,
Returns a copy of this FSelectContentStyle with the given properties replaced.
See customizing widget styles.
Parameters
- FSelectContentStyle.sectionStyle - A section's style.
- FSelectContentStyle.scrollHandleStyle - A scroll handle's style.
- FSelectContentStyle.padding - The padding surrounding the content.
- FSelectContentStyle.decoration - The popover's decoration.
- FSelectContentStyle.barrierFilter - An optional callback that takes the current animation transition value (0.0 to 1.0) and returns an ImageFilter that is used as the barrier.
- FSelectContentStyle.backgroundFilter - An optional callback that takes the current animation transition value (0.0 to 1.0) and returns an ImageFilter that is used as the background.
- FSelectContentStyle.popoverPadding - The additional padding between the edges of the view and the edges of the popover.
Implementation
@useResult
FSelectContentStyle copyWith({
FSelectSectionStyleDelta? sectionStyle,
FSelectScrollHandleStyleDelta? scrollHandleStyle,
EdgeInsetsGeometryDelta? padding,
DecorationDelta? decoration,
ImageFilter Function(double)? Function()? barrierFilter,
ImageFilter Function(double)? Function()? backgroundFilter,
EdgeInsetsGeometryDelta? popoverPadding,
}) => .new(
sectionStyle: sectionStyle?.call(this.sectionStyle) ?? this.sectionStyle,
scrollHandleStyle: scrollHandleStyle?.call(this.scrollHandleStyle) ?? this.scrollHandleStyle,
padding: padding?.call(this.padding) ?? this.padding,
decoration: decoration?.call(this.decoration) ?? this.decoration,
barrierFilter: barrierFilter == null ? this.barrierFilter : barrierFilter(),
backgroundFilter: backgroundFilter == null ? this.backgroundFilter : backgroundFilter(),
popoverPadding: popoverPadding?.call(this.popoverPadding) ?? this.popoverPadding,
);