contentUseViewInsets property

bool contentUseViewInsets
final

Whether to avoid the platform view's insets (the soft keyboard).

Note

The inset is read from MediaQuery, and the portal rebuilds on view metric changes so it still avoids the keyboard even when a parent widget (e.g. Material Scaffold) has consumed the MediaQuery inset.

Defaults to true.

Implementation

final bool contentUseViewInsets;