popoverBuilder property
A builder that wraps the entire popover content with arbitrary widgets.
Defaults to returning the content as-is.
Implementation
final FMultiSelectPopoverBuilder<T> popoverBuilder;
A builder that wraps the entire popover content with arbitrary widgets.
Defaults to returning the content as-is.
final FMultiSelectPopoverBuilder<T> popoverBuilder;