prefixBuilder property

Builds a widget at the start of the select that can be pressed to toggle the popover. Defaults to no icon.

Implementation

final FFieldIconBuilder<FMultiSelectFieldStyle>? prefixBuilder;