FMultiSelectStyleDelta class abstract
A delta that applies modifications to a FMultiSelectStyle.
A FMultiSelectStyle is itself a FMultiSelectStyleDelta.
- Mixed-in types
- Implementers
Constructors
- FMultiSelectStyleDelta.context()
-
Creates a delta that returns the FMultiSelectStyle in the current context.
constfactory
-
FMultiSelectStyleDelta.delta({FVariantsDelta<
FTextFieldSizeVariantConstraint, FTextFieldSizeVariant, FMultiSelectFieldStyle, FMultiSelectFieldStyleDelta> ? fieldStyles, FSelectSearchStyleDelta? searchStyle, FSelectContentStyleDelta? contentStyle, TextStyleDelta? emptyTextStyle}) -
Creates a partial modification of a FMultiSelectStyle.
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
covariant FMultiSelectStyle value) → FMultiSelectStyle -
Applies this delta to the given value.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited