popoverBuilder property
A builder that wraps the entire popover content with arbitrary widgets. Defaults to returning the content as-is.
Implementation
final FSelectPopoverBuilder<T> popoverBuilder;
A builder that wraps the entire popover content with arbitrary widgets. Defaults to returning the content as-is.
final FSelectPopoverBuilder<T> popoverBuilder;