retainFocus property
Whether the field should retain focus after an item is selected.
Defaults to true on desktop and false on touch.
Implementation
final bool? retainFocus;
Whether the field should retain focus after an item is selected.
Defaults to true on desktop and false on touch.
final bool? retainFocus;