suffixBuilder property

FFieldIconBuilder<FTextFieldStyle>? suffixBuilder
final

Builds a widget at the end of the select that can be pressed to toggle the popover. Defaults to defaultIconBuilder.

Implementation

final FFieldIconBuilder<FTextFieldStyle>? suffixBuilder;