FSelectContentStyle class

An FSelect's contents style.

Inheritance
Implemented types
Mixed-in types
Available extensions

Constructors

FSelectContentStyle({required FSelectSectionStyle sectionStyle, required FSelectScrollHandleStyle scrollHandleStyle, required Decoration decoration, EdgeInsetsGeometry padding = const .symmetric(vertical: 6), ImageFilter barrierFilter(BuildContext context, double animation)?, ImageFilter backgroundFilter(BuildContext context, double animation)?, EdgeInsetsGeometry popoverPadding = const .all(5), FPortalArrowStyle arrowStyle = const FPortalArrowStyle(), FPopoverMotion motion = const FPopoverMotion()})
Creates a FSelectContentStyle.
FSelectContentStyle.inherit({required FColors colors, required FStyle style, required FIcons icons, required FTypography typography, required bool touch})
Creates a FSelectContentStyle that inherits its properties.

Properties

arrowStyle → FPortalArrowStyle
no setterinherited
backgroundFilter → ImageFilter Function(BuildContext context, double animation)?
no setterinherited
barrierFilter → ImageFilter Function(BuildContext context, double animation)?
no setterinherited
decoration → Decoration
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
motion → FPopoverMotion
no setterinherited
padding → EdgeInsetsGeometry
The padding surrounding the content. Defaults to EdgeInsets.symmetric(vertical: 6).
final
popoverPadding → EdgeInsetsGeometry
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollHandleStyle → FSelectScrollHandleStyle
A scroll handle's style.
final
sectionStyle → FSelectSectionStyle
A section's style.
final

Methods

call(covariant Object _) → FSelectContentStyle
Returns itself.
inherited
copyWith({DecorationDelta? decoration, ImageFilter barrierFilter(BuildContext context, double animation)? = Sentinels.imageFilterFunction, ImageFilter backgroundFilter(BuildContext context, double animation)? = Sentinels.imageFilterFunction, EdgeInsetsGeometryDelta? popoverPadding, FPortalArrowStyleDelta? arrowStyle, FPopoverMotionDelta? motion}) → FPopoverStyle

Available on FPopoverStyle, provided by the $FPopoverStyleTransformations extension

Returns a copy of this FPopoverStyle with the given properties replaced.
copyWith({FSelectSectionStyleDelta? sectionStyle, FSelectScrollHandleStyleDelta? scrollHandleStyle, EdgeInsetsGeometryDelta? padding, DecorationDelta? decoration, ImageFilter Function(BuildContext context, double animation)? barrierFilter()?, ImageFilter Function(BuildContext context, double animation)? backgroundFilter()?, EdgeInsetsGeometryDelta? popoverPadding, FPortalArrowStyleDelta? arrowStyle, FPopoverMotionDelta? motion}) → FSelectContentStyle

Available on FSelectContentStyle, provided by the $FSelectContentStyleTransformations extension

Returns a copy of this FSelectContentStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FPopoverStyle other, double t) → FPopoverStyle

Available on FPopoverStyle, provided by the $FPopoverStyleTransformations extension

Linearly interpolate between this and another FPopoverStyle using the given factor t.
lerp(FSelectContentStyle other, double t) → FSelectContentStyle

Available on FSelectContentStyle, provided by the $FSelectContentStyleTransformations extension

Linearly interpolate between this and another FSelectContentStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited