FSelectContentStyleDelta.delta constructor
const
FSelectContentStyleDelta.delta({
- FSelectSectionStyleDelta? sectionStyle,
- FSelectScrollHandleStyleDelta? scrollHandleStyle,
- EdgeInsetsGeometryDelta? padding,
- DecorationDelta? decoration,
- ImageFilter Function(double)? barrierFilter()?,
- ImageFilter Function(double)? backgroundFilter()?,
- EdgeInsetsGeometryDelta? popoverPadding,
Creates a partial modification of a FSelectContentStyle.
Parameters
- FSelectContentStyle.sectionStyle - A section's style.
- FSelectContentStyle.scrollHandleStyle - A scroll handle's style.
- FSelectContentStyle.padding - The padding surrounding the content.
- FSelectContentStyle.decoration - The popover's decoration.
- FSelectContentStyle.barrierFilter - An optional callback that takes the current animation transition value (0.0 to 1.0) and returns an ImageFilter that is used as the barrier.
- FSelectContentStyle.backgroundFilter - An optional callback that takes the current animation transition value (0.0 to 1.0) and returns an ImageFilter that is used as the background.
- FSelectContentStyle.popoverPadding - The additional padding between the edges of the view and the edges of the popover.
Implementation
const factory FSelectContentStyleDelta.delta({
FSelectSectionStyleDelta? sectionStyle,
FSelectScrollHandleStyleDelta? scrollHandleStyle,
EdgeInsetsGeometryDelta? padding,
DecorationDelta? decoration,
ImageFilter Function(double)? Function()? barrierFilter,
ImageFilter Function(double)? Function()? backgroundFilter,
EdgeInsetsGeometryDelta? popoverPadding,
}) = _FSelectContentStyleDelta;