FSelectSearchStyle class

A FSelect's search field style.

Implemented types
Mixed-in types
Available extensions

Constructors

FSelectSearchStyle({required FTextFieldSizeStyles fieldStyles, required FDividerStyle dividerStyle, required FCircularProgressStyle progressStyle})
Creates a FSelectSearchStyle.
FSelectSearchStyle.inherit({required FColors colors, required FTypography typography, required FStyle style, required bool touch})
Creates a FSelectSearchStyle that inherits its properties.
factory

Properties

dividerStyle → FDividerStyle
The style of the divider between the search field and results.
final
fieldStyles → FTextFieldSizeStyles
The search field's size styles.
final
hashCode → int
The hash code for this object.
no setterinherited
progressStyle → FCircularProgressStyle
The loading progress's style.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(covariant Object _) → FSelectSearchStyle
Returns itself.
inherited
copyWith({FVariantsDelta<FTextFieldSizeVariantConstraint, FTextFieldSizeVariant, FTextFieldStyle, FTextFieldStyleDelta>? fieldStyles, FDividerStyleDelta? dividerStyle, FCircularProgressStyleDelta? progressStyle}) → FSelectSearchStyle

Available on FSelectSearchStyle, provided by the $FSelectSearchStyleTransformations extension

Returns a copy of this FSelectSearchStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FSelectSearchStyle other, double t) → FSelectSearchStyle

Available on FSelectSearchStyle, provided by the $FSelectSearchStyleTransformations extension

Linearly interpolate between this and another FSelectSearchStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited