FSelectSectionStyle class
A FSelectSection's style.
- Implemented types
- Mixed-in types
- Available extensions
Constructors
-
FSelectSectionStyle({required FVariants<
FSelectSectionVariantConstraint, FSelectSectionVariant, TextStyle, TextStyleDelta> labelTextStyle, required FVariants<FSelectSectionVariantConstraint, FSelectSectionVariant, Color, Delta> dividerColor, required double dividerWidth, required FItemStyle itemStyle, EdgeInsetsGeometry labelPadding = const .directional(start: 14, top: 6, bottom: 6, end: 10), double spacing = 4}) - Creates a FSelectSectionStyle.
- FSelectSectionStyle.inherit({required FColors colors, required FStyle style, required FTypography typography, required bool touch})
-
Creates a FSelectSectionStyle that inherits its properties.
factory
Properties
-
dividerColor
→ FVariants<
FSelectSectionVariantConstraint, FSelectSectionVariant, Color, Delta> -
The color of the divider between items in this section.
final
- dividerWidth → double
-
The width of the divider between items in this section.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemStyle → FItemStyle
-
The section's items' style.
final
- labelPadding → EdgeInsetsGeometry
-
The padding around the label. Defaults to
EdgeInsetsDirectional.only(start: 14, top: 6, bottom: 6, end: 10).final -
labelTextStyle
→ FVariants<
FSelectSectionVariantConstraint, FSelectSectionVariant, TextStyle, TextStyleDelta> -
The label's text style.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spacing → double
-
The spacing below the section. Defaults to 4.
final
Methods
-
call(
covariant Object _) → FSelectSectionStyle -
Returns itself.
inherited
-
copyWith(
{FVariantsDelta< FSelectSectionVariantConstraint, FSelectSectionVariant, TextStyle, TextStyleDelta> ? labelTextStyle, EdgeInsetsGeometryDelta? labelPadding, FVariantsValueDelta<FSelectSectionVariantConstraint, FSelectSectionVariant, Color, Delta> ? dividerColor, double? dividerWidth, FItemStyleDelta? itemStyle, double? spacing}) → FSelectSectionStyle -
Available on FSelectSectionStyle, provided by the $FSelectSectionStyleTransformations extension
Returns a copy of this FSelectSectionStyle with the given properties replaced. -
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
lerp(
FSelectSectionStyle other, double t) → FSelectSectionStyle -
Available on FSelectSectionStyle, provided by the $FSelectSectionStyleTransformations extension
Linearly interpolate between this and another FSelectSectionStyle using the given factort. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited