dividerColor property
The color of the divider between items in this section.
Implementation
@override
final FVariants<FSelectSectionVariantConstraint, FSelectSectionVariant, Color, Delta> dividerColor;
The color of the divider between items in this section.
@override
final FVariants<FSelectSectionVariantConstraint, FSelectSectionVariant, Color, Delta> dividerColor;