FSelectSectionStyleDelta.delta constructor
const
FSelectSectionStyleDelta.delta({
- FVariantsDelta<
FSelectSectionVariantConstraint, FSelectSectionVariant, TextStyle, TextStyleDelta> ? labelTextStyle, - EdgeInsetsGeometryDelta? labelPadding,
- FVariantsValueDelta<
FSelectSectionVariantConstraint, FSelectSectionVariant, Color, Delta> ? dividerColor, - double? dividerWidth,
- FItemStyleDelta? itemStyle,
- double? spacing,
Creates a partial modification of a FSelectSectionStyle.
Parameters
- FSelectSectionStyle.labelTextStyle - The label's text style.
- FSelectSectionStyle.labelPadding - The padding around the label.
- FSelectSectionStyle.dividerColor - The color of the divider between items in this section.
- FSelectSectionStyle.dividerWidth - The width of the divider between items in this section.
- FSelectSectionStyle.itemStyle - The section's items' style.
- FSelectSectionStyle.spacing - The spacing below the section.
Implementation
const factory FSelectSectionStyleDelta.delta({
FVariantsDelta<FSelectSectionVariantConstraint, FSelectSectionVariant, TextStyle, TextStyleDelta>? labelTextStyle,
EdgeInsetsGeometryDelta? labelPadding,
FVariantsValueDelta<FSelectSectionVariantConstraint, FSelectSectionVariant, Color, Delta>? dividerColor,
double? dividerWidth,
FItemStyleDelta? itemStyle,
double? spacing,
}) = _FSelectSectionStyleDelta;