FSelectGroup<T> class

A set of items that are treated as a single selection.

Typically used to group multiple FSelectGroupItemMixins.

For touch devices, a FSelectTileGroup is generally recommended over this.

Error transition caveats

Error transitions require either a label or description to function. In the rare case where only an error is needed, set label or description to an empty widget, e.g. SizedBox.shrink.

See:

Inheritance
Mixed-in types

Constructors

FSelectGroup({required List<FSelectGroupItemMixin<T>> children, FMultiValueControl<T>? control, FSelectGroupStyleDelta style = const .context(), Widget? label, Widget? description, Widget errorBuilder(BuildContext context, String message) = FFormFieldProperties.defaultErrorBuilder, FormFieldSetter<Set<T>>? onSaved, VoidCallback? onReset, FormFieldValidator<Set<T>>? validator, String? forceErrorText, bool enabled = true, AutovalidateMode autovalidateMode = .disabled, Key? formFieldKey, Key? key})
Creates a FSelectGroup.
const

Properties

autovalidateMode → AutovalidateMode
If AutovalidateMode.onUserInteraction, this FormField will only auto-validate after its content changes. If AutovalidateMode.always, it will auto-validate even without user interaction. If AutovalidateMode.disabled, auto-validation will be disabled.
final
children → List<FSelectGroupItemMixin<T>>
The items.
final
control → FMultiValueControl<T>?
Defines how the select group's value is controlled.
final
description → Widget?
The description.
final
enabled → bool
Whether the form field is enabled. Defaults to true.
final
errorBuilder → Widget Function(BuildContext context, String message)
The builder for errors displayed below the description. Defaults to displaying the error message.
final
forceErrorText → String?
An optional property that forces the FormFieldState into an error state by directly setting the FormFieldState.errorText property without running the validator function.
final
formFieldKey → Key?
The key to use for the internal FormField.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label → Widget?
The label.
final
onReset → VoidCallback?
An optional method to call when the form field is reset via FormFieldState.reset.
final
onSaved → FormFieldSetter<Set<T>>?
An optional method to call with the final value when the form is saved via FormState.save.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → FSelectGroupStyleDelta
The style. Defaults to FThemeData.selectGroupStyle.
final
validator → FormFieldValidator<Set<T>>?
An optional method that validates an input. Returns an error string to display if the input is invalid, or null otherwise.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<FSelectGroup<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited