FSelectGroupItemData<T> class

A FSelectGroup's item data. Useful for creating your own FSelectGroupItemMixin.

Inheritance

Constructors

FSelectGroupItemData({required FMultiValueNotifier<T> controller, required FSelectGroupStyle style, required bool enabled, required bool selected, required bool error, required Widget child, Key? key})
The FSelectGroup's item data.
const

Properties

child → Widget
The widget below this widget in the tree.
finalinherited
controller → FMultiValueNotifier<T>
The controller.
final
enabled → bool
True if the FSelectGroup is enabled.
final
error → bool
True if the FSelectGroup is in an error state.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selected → bool
True if the item is selected.
final
style → FSelectGroupStyle
The style.
final

Methods

createElement() → InheritedElement
Inflates this configuration to a concrete instance.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
updateShouldNotify(covariant FSelectGroupItemData<T> old) → bool
Whether the framework should notify widgets that inherit from this widget.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

of<T>(BuildContext context) → FSelectGroupItemData<T>
Return the FSelectGroup's item data.