formFieldKey property
The key to use for the internal FormField.
This can be used to obtain the FormFieldState using a GlobalKey to externally validate or access the form field's state.
Implementation
final Key? formFieldKey;
The key to use for the internal FormField.
This can be used to obtain the FormFieldState using a GlobalKey to externally validate or access the form field's state.
final Key? formFieldKey;