menuUseViewInsets property

bool menuUseViewInsets
final

Whether to avoid the platform view's insets (the soft keyboard).

Note

Values are read directly from the View rather than MediaQuery to ensure unconsumed inset values are used, even when a parent widget (e.g. Material Scaffold) has already consumed the MediaQuery values.

Defaults to true.

Implementation

final bool menuUseViewInsets;