menuUseViewPadding property

bool menuUseViewPadding
final

Whether to avoid the platform view's padding (static safe areas like the notch and status bar).

Note

Values are read directly from the View rather than MediaQuery to ensure unconsumed safe area padding is used, even when a parent widget (e.g. Material Scaffold) has already consumed the MediaQuery values.

Defaults to true.

Implementation

final bool menuUseViewPadding;