FModalSheetMotion class

The motion-related properties for a modal sheet.

Inheritance
Implemented types
Mixed-in types
Available extensions

Constructors

FModalSheetMotion({Curve barrierCurve = Curves.easeOutCubic, Duration expandDuration = const Duration(milliseconds: 200), Duration collapseDuration = const Duration(milliseconds: 200), Curve curve = Curves.easeOutCubic})
Creates a FModalSheetMotion.
const

Properties

barrierCurve → Curve
The barrier's curve. Defaults to Curves.easeOutCubic.
final
collapseDuration → Duration
no setterinherited
curve → Curve
no setterinherited
expandDuration → Duration
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(covariant Object _) → FModalSheetMotion
Returns itself.
inherited
copyWith({Curve? barrierCurve, Duration? expandDuration, Duration? collapseDuration, Curve? curve}) → FModalSheetMotion

Available on FModalSheetMotion, provided by the $FModalSheetMotionTransformations extension

Returns a copy of this FModalSheetMotion with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FModalSheetMotion other, double t) → FModalSheetMotion

Available on FModalSheetMotion, provided by the $FModalSheetMotionTransformations extension

Linearly interpolate between this and another FModalSheetMotion using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited