FModalSheetStyle class

A modal sheet's style.

Inheritance
Implemented types
Mixed-in types
Available extensions

Constructors

FModalSheetStyle({ImageFilter barrierFilter(BuildContext context, double animation)?, FModalSheetMotion motion = const FModalSheetMotion(), double flingVelocity = 700, double closeProgressThreshold = 0.5})
Creates a FSheetStyle.
const
FModalSheetStyle.inherit()
Creates a FSheetStyle that inherits its properties.

Properties

barrierFilter → ImageFilter Function(BuildContext context, double animation)?
An optional callback that takes a BuildContext and the current animation transition value (0.0 to 1.0), and returns an ImageFilter that is used as the barrier. Defaults to null.
final
closeProgressThreshold → double
no setterinherited
flingVelocity → double
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
motion → FModalSheetMotion
The motion-related properties for a modal sheet. Defaults to FModalSheetMotion.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(covariant Object _) → FModalSheetStyle
Returns itself.
inherited
copyWith({ImageFilter barrierFilter(BuildContext context, double animation)? = Sentinels.imageFilterFunction, FModalSheetMotionDelta? motion, double? flingVelocity, double? closeProgressThreshold}) → FModalSheetStyle

Available on FModalSheetStyle, provided by the $FModalSheetStyleTransformations extension

Returns a copy of this FModalSheetStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FModalSheetStyle other, double t) → FModalSheetStyle

Available on FModalSheetStyle, provided by the $FModalSheetStyleTransformations extension

Linearly interpolate between this and another FModalSheetStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

defaultBarrierFilter(BuildContext context, double animation) → ImageFilter
The default barrierFilter. Tints the content behind the barrier.