FPersistentSheetStyle class

A persistent sheet's style.

Inheritance
Implemented types
Mixed-in types
Available extensions

Constructors

FPersistentSheetStyle({FPersistentSheetMotion motion = const FPersistentSheetMotion(), double flingVelocity = 700, double closeProgressThreshold = 0.5})
Creates a FSheetStyle.
const
FPersistentSheetStyle.inherit()
Creates a FPersistentSheetStyle that inherits its properties from the given arguments.

Properties

closeProgressThreshold double
no setterinherited
flingVelocity double
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
motion FPersistentSheetMotion
The motion-related properties for a persistent sheet.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(covariant Object _) FPersistentSheetStyle
Returns itself.
inherited
copyWith({FPersistentSheetMotionDelta? motion, double? flingVelocity, double? closeProgressThreshold}) FPersistentSheetStyle

Available on FPersistentSheetStyle, provided by the $FPersistentSheetStyleTransformations extension

Returns a copy of this FPersistentSheetStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FPersistentSheetStyle other, double t) FPersistentSheetStyle

Available on FPersistentSheetStyle, provided by the $FPersistentSheetStyleTransformations extension

Linearly interpolate between this and another FPersistentSheetStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited