FSheetMotion class abstract

The motion-related properties for a sheet.

When FAccessibility.motion is:

Implementers

Constructors

FSheetMotion({Duration expandDuration = const Duration(milliseconds: 200), Duration collapseDuration = const Duration(milliseconds: 200), Curve curve = Curves.easeOutCubic})
Creates a FSheetMotion.
const

Properties

collapseDuration → Duration
The duration of the sheet's collapsing animation. Defaults to 200ms.
final
curve → Curve
The curve of the sheet's expansion and collapse. Defaults to Curves.easeOutCubic.
final
expandDuration → Duration
The duration of the sheet's expansion animation. Defaults to 200ms.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited