FSheetStyle class abstract

A sheet's style.

Implementers

Constructors

FSheetStyle({double flingVelocity = 700, double closeProgressThreshold = 0.5})
Creates a FSheetStyle.
const

Properties

closeProgressThreshold → double
The threshold for determining whether the sheet is closing. Defaults to 0.5.
final
flingVelocity → double
The minimum velocity to initiate a fling. Defaults to 700.
final
hashCode → int
The hash code for this object.
no setterinherited
motion → FSheetMotion
The motion-related properties for a sheet.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited