FSidebarGroup class

A group of FSidebarItems.

The FSidebarGroup widget is useful for organizing sidebar items into logical sections with an optional label and action. The label is typically used to describe the group, while the action can be used for group-level operations.

See:

Inheritance

Constructors

FSidebarGroup({required List<Widget> children, FSidebarGroupStyleDelta style = const .context(), Widget? label, Widget? action, ValueChanged<bool>? onActionHoverChange, FTappableVariantChangeCallback? onActionVariantChange, VoidCallback? onActionPress, VoidCallback? onActionLongPress, Key? key})
Creates a FSidebarGroup.
const

Properties

action → Widget?
An optional action widget to display after the label.
final
children → List<Widget>
The children of the group.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label → Widget?
The label of the group.
final
onActionHoverChange → ValueChanged<bool>?
Called when the action's hover state changes.
final
onActionLongPress → VoidCallback?
Called when the action is long pressed.
final
onActionPress → VoidCallback?
Called when the action is pressed.
final
onActionVariantChange → FTappableVariantChangeCallback?
Called when the action's variant changes.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → FSidebarGroupStyleDelta
The sidebar group's style.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited