FSidebarGroupStyle class

The style for a FSidebarGroup.

Implemented types
Mixed-in types
Available extensions

Constructors

FSidebarGroupStyle({required TextStyle labelStyle, required FVariants<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta> actionStyle, required FTappableStyle tappableStyle, required FFocusedOutlineStyle focusedOutlineStyle, required FSidebarItemStyle itemStyle, EdgeInsets padding = const .symmetric(horizontal: 16), double headerSpacing = 8, EdgeInsetsGeometry headerPadding = const .fromLTRB(8, 0, 8, 2), double childrenSpacing = 4, EdgeInsetsGeometry childrenPadding = const .fromLTRB(0, 0, 0, 16)})
Creates a FSidebarGroupStyle.
const
FSidebarGroupStyle.inherit({required FColors colors, required FTypography typography, required FIcons icons, required FStyle style, required bool touch})
Creates a FSidebarGroupStyle that inherits its properties.

Properties

actionStyle → FVariants<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta>
The action's style.
final
childrenPadding → EdgeInsetsGeometry
The padding around the children. Defaults to EdgeInsets.fromLTRB(0, 0, 0, 16).
final
childrenSpacing → double
The spacing between children. Defaults to 4.
final
focusedOutlineStyle → FFocusedOutlineStyle
The focused outline style.
final
hashCode → int
The hash code for this object.
no setterinherited
headerPadding → EdgeInsetsGeometry
The padding around the header. Defaults to EdgeInsets.fromLTRB(8, 0, 8, 2).
final
headerSpacing → double
The spacing between the label and action in the header. Defaults to 8.
final
itemStyle → FSidebarItemStyle
The item's style.
final
labelStyle → TextStyle
The label's text style.
final
padding → EdgeInsets
The padding. Defaults to EdgeInsets.symmetric(horizontal: 16).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tappableStyle → FTappableStyle
The tappable action's style.
final

Methods

call(covariant Object _) → FSidebarGroupStyle
Returns itself.
inherited
copyWith({TextStyleDelta? labelStyle, FVariantsDelta<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta>? actionStyle, FTappableStyleDelta? tappableStyle, FFocusedOutlineStyleDelta? focusedOutlineStyle, FSidebarItemStyleDelta? itemStyle, EdgeInsetsDelta? padding, double? headerSpacing, EdgeInsetsGeometryDelta? headerPadding, double? childrenSpacing, EdgeInsetsGeometryDelta? childrenPadding}) → FSidebarGroupStyle

Available on FSidebarGroupStyle, provided by the $FSidebarGroupStyleTransformations extension

Returns a copy of this FSidebarGroupStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FSidebarGroupStyle other, double t) → FSidebarGroupStyle

Available on FSidebarGroupStyle, provided by the $FSidebarGroupStyleTransformations extension

Linearly interpolate between this and another FSidebarGroupStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited