FSidebarItem class

A sidebar item.

The FSidebarItem widget is useful for creating interactive items in a sidebar. It can display an icon, label, and optional action, with support for selected and enabled states.

See:

Inheritance

Constructors

FSidebarItem({FSidebarItemStyleDelta style = const .context(), Widget? icon, Widget? label, bool selected = false, bool initiallyExpanded = false, bool autofocus = false, FocusNode? focusNode, VoidCallback? onPress, VoidCallback? onLongPress, ValueChanged<bool>? onHoverChange, FTappableVariantChangeCallback? onVariantChange, List<Widget> children = const [], Key? key})
Creates a FSidebarItem.
const

Properties

autofocus → bool
True if this widget will be selected as the initial focus when no other node in its scope is currently focused.
final
children → List<Widget>
The sidebar item's children.
final
focusNode → FocusNode?
An optional focus node to use as the focus node for this widget.
final
hashCode → int
The hash code for this object.
no setterinherited
icon → Widget?
The icon to display before the label.
final
initiallyExpanded → bool
Whether this item is initially expanded.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label → Widget?
The main content of the item.
final
onHoverChange → ValueChanged<bool>?
Called when the hover state changes.
final
onLongPress → VoidCallback?
Called when the item is long pressed.
final
onPress → VoidCallback?
Called when the item is pressed.
final
onVariantChange → FTappableVariantChangeCallback?
Called when the variant changes.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selected → bool
Whether this item is currently selected.
final
style → FSidebarItemStyleDelta
The sidebar item's style.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<FSidebarItem>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited