FSidebarItemMotion class

The motion-related properties for a FSidebarItem.

Implemented types
Mixed-in types
Available extensions

Constructors

FSidebarItemMotion({Duration expandDuration = const Duration(milliseconds: 200), Duration collapseDuration = const Duration(milliseconds: 150), Curve expandCurve = Curves.easeOutCubic, Curve collapseCurve = Curves.easeInCubic, Curve fadeInCurve = Curves.linear, Curve fadeOutCurve = Curves.linear, Curve iconExpandCurve = Curves.easeOut, Curve iconCollapseCurve = Curves.easeOut, Animatable<double> revealTween = const FImmutableTween(begin: 0.0, end: 1.0), Animatable<double> fadeTween = const FImmutableTween(begin: 0.0, end: 1.0), Animatable<double> iconTween = const FImmutableTween(begin: 0.0, end: 0.25)})
Creates a FSidebarItemMotion.
const

Properties

collapseCurve → Curve
The collapse animation's curve. Defaults to Curves.easeInCubic.
final
collapseDuration → Duration
The collapse animation's duration. Defaults to 150ms.
final
expandCurve → Curve
The expand animation's curve. Defaults to Curves.easeOutCubic.
final
expandDuration → Duration
The expand animation's duration. Defaults to 200ms.
final
fadeInCurve → Curve
The fade-in animation's curve. Defaults to Curves.linear.
final
fadeOutCurve → Curve
The fade-out animation's curve. Defaults to Curves.linear.
final
fadeTween → Animatable<double>
The fade animation's tween. Defaults to FImmutableTween(begin: 0.0, end: 1.0).
final
hashCode → int
The hash code for this object.
no setterinherited
iconCollapseCurve → Curve
The icon's animation curve when collapsing. Defaults to Curves.easeOut.
final
iconExpandCurve → Curve
The icon's animation curve when expanding. Defaults to Curves.easeOut.
final
iconTween → Animatable<double>
The icon animation's tween. Defaults to FImmutableTween(begin: 0.0, end: 0.25).
final
revealTween → Animatable<double>
The reveal animation's tween. Defaults to FImmutableTween(begin: 0.0, end: 1.0).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(covariant Object _) → FSidebarItemMotion
Returns itself.
inherited
copyWith({Duration? expandDuration, Duration? collapseDuration, Curve? expandCurve, Curve? collapseCurve, Curve? fadeInCurve, Curve? fadeOutCurve, Curve? iconExpandCurve, Curve? iconCollapseCurve, Animatable<double>? revealTween, Animatable<double>? fadeTween, Animatable<double>? iconTween}) → FSidebarItemMotion

Available on FSidebarItemMotion, provided by the $FSidebarItemMotionTransformations extension

Returns a copy of this FSidebarItemMotion with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FSidebarItemMotion other, double t) → FSidebarItemMotion

Available on FSidebarItemMotion, provided by the $FSidebarItemMotionTransformations extension

Linearly interpolate between this and another FSidebarItemMotion using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited