FSidebarItemStyle class

The style for a FSidebarItem.

Implemented types
Mixed-in types
Available extensions

Constructors

FSidebarItemStyle({required FVariants<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta> textStyle, required FVariants<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta> iconStyle, required FVariants<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta> collapsibleIconStyle, required FIcon collapsibleIcon, required FVariants<FTappableVariantConstraint, FTappableVariant, Color, Delta> backgroundColor, required EdgeInsetsGeometry padding, required BorderRadius borderRadius, required FTappableStyle tappableStyle, required FFocusedOutlineStyle focusedOutlineStyle, double iconSpacing = 8, double collapsibleIconSpacing = 8, double childrenSpacing = 4, EdgeInsetsGeometry childrenPadding = const .only(left: 26, top: 2), FSidebarItemMotion motion = const FSidebarItemMotion()})
Creates a FSidebarItemStyle.
const
FSidebarItemStyle.inherit({required FColors colors, required FTypography typography, required FIcons icons, required FStyle style, required bool touch})
Creates a FSidebarItemStyle that inherits its properties.
factory

Properties

backgroundColor → FVariants<FTappableVariantConstraint, FTappableVariant, Color, Delta>
The background color.
final
borderRadius → BorderRadius
The item's border radius.
final
childrenPadding → EdgeInsetsGeometry
The padding around the children container. Defaults to EdgeInsets.only(left: 26, top: 2).
final
childrenSpacing → double
The spacing between child items. Defaults to 4.
final
collapsibleIcon → FIcon
The collapsible icon builder. Defaults to FIcons.chevronRight.
final
collapsibleIconSpacing → double
The spacing between the label and collapsible widget. Defaults to 8.
final
collapsibleIconStyle → FVariants<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta>
The collapsible icon's style.
final
focusedOutlineStyle → FFocusedOutlineStyle
The focused outline style.
final
hashCode → int
The hash code for this object.
no setterinherited
iconSpacing → double
The spacing between the icon and label. Defaults to 8.
final
iconStyle → FVariants<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta>
The icon's style.
final
motion → FSidebarItemMotion
The motion-related properties. Defaults to FSidebarItemMotion.
final
padding → EdgeInsetsGeometry
The padding around the content. Defaults to EdgeInsets.all(8).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tappableStyle → FTappableStyle
The tappable's style.
final
textStyle → FVariants<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta>
The label's text style.
final

Methods

call(covariant Object _) → FSidebarItemStyle
Returns itself.
inherited
copyWith({FVariantsDelta<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta>? textStyle, FVariantsDelta<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta>? iconStyle, FVariantsDelta<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta>? collapsibleIconStyle, FIcon? collapsibleIcon, FVariantsValueDelta<FTappableVariantConstraint, FTappableVariant, Color, Delta>? backgroundColor, EdgeInsetsGeometryDelta? padding, BorderRadius? borderRadius, FTappableStyleDelta? tappableStyle, FFocusedOutlineStyleDelta? focusedOutlineStyle, double? iconSpacing, double? collapsibleIconSpacing, double? childrenSpacing, EdgeInsetsGeometryDelta? childrenPadding, FSidebarItemMotionDelta? motion}) → FSidebarItemStyle

Available on FSidebarItemStyle, provided by the $FSidebarItemStyleTransformations extension

Returns a copy of this FSidebarItemStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FSidebarItemStyle other, double t) → FSidebarItemStyle

Available on FSidebarItemStyle, provided by the $FSidebarItemStyleTransformations extension

Linearly interpolate between this and another FSidebarItemStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited