FSidebarStyle class

A FSidebar's style.

Implemented types
Mixed-in types
Available extensions

Constructors

FSidebarStyle({required Decoration decoration, required FSidebarGroupStyle groupStyle, BoxConstraints constraints = const .tightFor(width: 256), ImageFilter? backgroundFilter, EdgeInsetsGeometry headerPadding = const .fromLTRB(0, 8, 0, 0), EdgeInsetsGeometry contentPadding = const .symmetric(vertical: 8), EdgeInsetsGeometry footerPadding = const .fromLTRB(0, 0, 0, 8)})
Creates a FSidebarStyle.
const
FSidebarStyle.inherit({required FColors colors, required FTypography typography, required FIcons icons, required FStyle style, required bool touch})
Creates a FSidebarStyle that inherits its properties.

Properties

backgroundFilter → ImageFilter?
An optional background filter applied to the sidebar.
final
constraints → BoxConstraints
The sidebar's width. Defaults to BoxConstraints.tightFor(width: 256).
final
contentPadding → EdgeInsetsGeometry
The padding for the content section. Defaults to EdgeInsets.symmetric(vertical: 8).
final
decoration → Decoration
The decoration.
final
footerPadding → EdgeInsetsGeometry
The padding for the footer section. Defaults to EdgeInsets.fromLTRB(0, 0, 0, 8).
final
groupStyle → FSidebarGroupStyle
The group's style.
final
hashCode → int
The hash code for this object.
no setterinherited
headerPadding → EdgeInsetsGeometry
The padding for the header section. Defaults to EdgeInsets.fromLTRB(0, 8, 0, 0).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(covariant Object _) → FSidebarStyle
Returns itself.
inherited
copyWith({DecorationDelta? decoration, FSidebarGroupStyleDelta? groupStyle, BoxConstraints? constraints, ImageFilter? backgroundFilter = Sentinels.imageFilter, EdgeInsetsGeometryDelta? headerPadding, EdgeInsetsGeometryDelta? contentPadding, EdgeInsetsGeometryDelta? footerPadding}) → FSidebarStyle

Available on FSidebarStyle, provided by the $FSidebarStyleTransformations extension

Returns a copy of this FSidebarStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FSidebarStyle other, double t) → FSidebarStyle

Available on FSidebarStyle, provided by the $FSidebarStyleTransformations extension

Linearly interpolate between this and another FSidebarStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited