backgroundFilter property
An optional background filter applied to the sidebar.
This is typically combined with a translucent background in decoration to create a glassmorphic effect.
An optional background filter applied to the sidebar.
This is typically combined with a translucent background in decoration to create a glassmorphic effect.