footerPadding property
The padding for the footer section. Defaults to EdgeInsets.fromLTRB(0, 0, 0, 8).
It is recommended to set the horizontal padding to 0. This ensures that the elements such as the scrollbar is not overlapped by the content.
The padding for the footer section. Defaults to EdgeInsets.fromLTRB(0, 0, 0, 8).
It is recommended to set the horizontal padding to 0. This ensures that the elements such as the scrollbar is not overlapped by the content.