defaultTooltipBuilder static method
The default tooltip builder that displays the value as a percentage.
Implementation
static Widget defaultTooltipBuilder(FTooltipController _, double value) =>
Text('${(value * 100).toStringAsFixed(0)}%');
The default tooltip builder that displays the value as a percentage.
static Widget defaultTooltipBuilder(FTooltipController _, double value) =>
Text('${(value * 100).toStringAsFixed(0)}%');