FSliderController class abstract

A controller that manages a slider's active track.

This class should be extended to customize value. By default, the following controllers are provided:

Inheritance
Implementers

Constructors

FSliderController({required FSliderValue value, FSliderInteraction interaction = .tapAndSlideThumb, double hapticFeedbackVelocity = 6.5, FSliderActiveThumb thumb = .max})
Creates a FSliderController for selecting a single value.
FSliderController.range({required FSliderValue value, double hapticFeedbackVelocity = 6.5})
Creates a FSliderController for selecting a range.

Properties

active → ({bool max, bool min})
Whether the active track is expandable at the min and max edges.
final
disposed bool
True if this notifier has been disposed.
no setterinherited
hapticFeedbackVelocity double
The minimum absolute per-frame drag delta, in pixels, required for FSliderHaptic.collision to fire when an active edge collides with the track's limit, the other thumb, or a minimum range extent.
final
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
interaction FSliderInteraction
The allowed ways to interaction with the slider. Defaults to FSliderInteraction.tapAndSlideThumb.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value FSliderValue
The slider's active track/value.
getter/setter pair

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
attach(double extent, List<FSliderMark> marks) → void
Registers the controller to a slider with the given extent and marks.
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
reset() → void
Resets the controller to its initial state.
slide(double offset, {required bool min, double velocity = 0}) FSliderHaptic?
Slides the active track to the given offset on the min edge, in logical pixels.
step({required bool min, required bool expand}) bool
Moves the active track on the min edge to the previous/next step.
tap(double offset) → ({bool haptic, FSliderActiveThumb? thumb})
Taps the slider at given offset, in logical pixels, along the track.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited