FSliderMarkStyle class

A FSlider mark's style.

Implemented types
Mixed-in types
Available extensions

Constructors

FSliderMarkStyle({required FVariants<FSliderVariantConstraint, FSliderVariant, Color, Delta> tickColor, required FVariants<FSliderVariantConstraint, FSliderVariant, TextStyle, TextStyleDelta> labelTextStyle, required AlignmentGeometry labelAnchor, required double labelOffset, double tickSize = 3})
Creates a FSliderMarkStyle.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
labelAnchor → AlignmentGeometry
The label's anchor to which the labelOffset is applied.
final
labelOffset → double
The label's offset from the slider, along its cross axis, in logical pixels. The top-left corner is always the origin, regardless of the layout.
final
labelTextStyle → FVariants<FSliderVariantConstraint, FSliderVariant, TextStyle, TextStyleDelta>
The label's default text style.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tickColor → FVariants<FSliderVariantConstraint, FSliderVariant, Color, Delta>
The tick's color.
final
tickSize → double
The tick's size. Defaults to 3.
final

Methods

call(covariant Object _) → FSliderMarkStyle
Returns itself.
inherited
copyWith({FVariantsValueDelta<FSliderVariantConstraint, FSliderVariant, Color, Delta>? tickColor, FVariantsDelta<FSliderVariantConstraint, FSliderVariant, TextStyle, TextStyleDelta>? labelTextStyle, AlignmentGeometry? labelAnchor, double? labelOffset, double? tickSize}) → FSliderMarkStyle

Available on FSliderMarkStyle, provided by the $FSliderMarkStyleTransformations extension

Returns a copy of this FSliderMarkStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FSliderMarkStyle other, double t) → FSliderMarkStyle

Available on FSliderMarkStyle, provided by the $FSliderMarkStyleTransformations extension

Linearly interpolate between this and another FSliderMarkStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited