FSliderStyle class

A slider's style.

Inheritance
Implemented types
Available extensions

Constructors

FSliderStyle({required FVariants<FSliderVariantConstraint, FSliderVariant, Color, Delta> activeColor, required FVariants<FSliderVariantConstraint, FSliderVariant, Color, Delta> inactiveColor, required FSliderThumbStyle thumbStyle, required FSliderMarkStyle markStyle, required FTooltipStyle tooltipStyle, required Future<void> collisionHapticFeedback(), required Future<void> tickHapticFeedback(), required FVariants<FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta> labelTextStyle, required FVariants<FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta> descriptionTextStyle, required FVariants<FFormFieldErrorVariantConstraint, FFormFieldErrorVariant, TextStyle, TextStyleDelta> errorTextStyle, BorderRadius borderRadius = const .all(.circular(4)), double crossAxisExtent = 6, double thumbSize = 16, AlignmentGeometry tooltipTipAnchor = .bottomCenter, AlignmentGeometry tooltipThumbAnchor = .topCenter, EdgeInsetsGeometry labelPadding = const .only(bottom: 15), EdgeInsetsGeometry descriptionPadding = .zero, EdgeInsetsGeometry errorPadding = const .only(top: 5), EdgeInsetsGeometry childPadding = .zero, FLabelMotion labelMotion = const FLabelMotion()})
Creates a FSliderStyle.
const
FSliderStyle.inherit({required FColors colors, required FTypography typography, required FStyle style, required FHapticFeedback hapticFeedback, required AlignmentGeometry labelAnchor, required double labelOffset, required EdgeInsetsGeometry descriptionPadding, EdgeInsetsGeometry childPadding = .zero, AlignmentGeometry tooltipTipAnchor = .bottomCenter, AlignmentGeometry tooltipThumbAnchor = .topCenter})
Creates a FSliderStyle that inherits its properties.

Properties

activeColor → FVariants<FSliderVariantConstraint, FSliderVariant, Color, Delta>
The slider's active track colors.
final
borderRadius → BorderRadius
The slider's border radius. Defaults to BorderRadius.all(Radius.circular(4)).
final
childPadding → EdgeInsetsGeometry
no setterinherited
collisionHapticFeedback → Future<void> Function()
The haptic feedback when the active edge collides with the track's limit, the other thumb, or a configured min range extent.
final
crossAxisExtent → double
The slider's cross-axis extent. Defaults to 6.
final
descriptionPadding → EdgeInsetsGeometry
no setterinherited
descriptionTextStyle → FVariants<FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta>
no setterinherited
errorPadding → EdgeInsetsGeometry
no setterinherited
errorTextStyle → FVariants<FFormFieldErrorVariantConstraint, FFormFieldErrorVariant, TextStyle, TextStyleDelta>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
inactiveColor → FVariants<FSliderVariantConstraint, FSliderVariant, Color, Delta>
The slider's inactive track colors.
final
labelMotion → FLabelMotion
no setterinherited
labelPadding → EdgeInsetsGeometry
no setterinherited
labelTextStyle → FVariants<FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta>
no setterinherited
markStyle → FSliderMarkStyle
The slider marks' style.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbSize → double
The thumb's size. Defaults to 25 on primarily touch devices and 16 on non-primarily touch devices.
final
thumbStyle → FSliderThumbStyle
The slider thumb's style.
final
tickHapticFeedback → Future<void> Function()
The haptic feedback when the active edge lands on a new discrete tick.
final
tooltipStyle → FTooltipStyle
The tooltip's style.
final
tooltipThumbAnchor → AlignmentGeometry
The anchor of the thumb to which the tooltipTipAnchor is aligned.
final
tooltipTipAnchor → AlignmentGeometry
The anchor of the tooltip to which the tooltipThumbAnchor is aligned.
final

Methods

call(covariant Object _) → FSliderStyle
Returns itself.
inherited
copyWith({FVariantsDelta<FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta>? labelTextStyle, FVariantsDelta<FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta>? descriptionTextStyle, FVariantsDelta<FFormFieldErrorVariantConstraint, FFormFieldErrorVariant, TextStyle, TextStyleDelta>? errorTextStyle}) → FFormFieldStyle

Available on FFormFieldStyle, provided by the $FFormFieldStyleTransformations extension

Returns a copy of this FFormFieldStyle with the given properties replaced.
copyWith({EdgeInsetsGeometryDelta? labelPadding, EdgeInsetsGeometryDelta? descriptionPadding, EdgeInsetsGeometryDelta? errorPadding, EdgeInsetsGeometryDelta? childPadding, FLabelMotionDelta? labelMotion, FVariantsDelta<FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta>? labelTextStyle, FVariantsDelta<FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta>? descriptionTextStyle, FVariantsDelta<FFormFieldErrorVariantConstraint, FFormFieldErrorVariant, TextStyle, TextStyleDelta>? errorTextStyle}) → FLabelStyle

Available on FLabelStyle, provided by the $FLabelStyleTransformations extension

Returns a copy of this FLabelStyle with the given properties replaced.
copyWith({FVariantsValueDelta<FSliderVariantConstraint, FSliderVariant, Color, Delta>? activeColor, FVariantsValueDelta<FSliderVariantConstraint, FSliderVariant, Color, Delta>? inactiveColor, FSliderThumbStyleDelta? thumbStyle, FSliderMarkStyleDelta? markStyle, FTooltipStyleDelta? tooltipStyle, Future<void> collisionHapticFeedback()?, Future<void> tickHapticFeedback()?, BorderRadius? borderRadius, double? crossAxisExtent, double? thumbSize, AlignmentGeometry? tooltipTipAnchor, AlignmentGeometry? tooltipThumbAnchor, EdgeInsetsGeometryDelta? labelPadding, EdgeInsetsGeometryDelta? descriptionPadding, EdgeInsetsGeometryDelta? errorPadding, EdgeInsetsGeometryDelta? childPadding, FLabelMotionDelta? labelMotion, FVariantsDelta<FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta>? labelTextStyle, FVariantsDelta<FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta>? descriptionTextStyle, FVariantsDelta<FFormFieldErrorVariantConstraint, FFormFieldErrorVariant, TextStyle, TextStyleDelta>? errorTextStyle}) → FSliderStyle

Available on FSliderStyle, provided by the $FSliderStyleTransformations extension

Returns a copy of this FSliderStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FFormFieldStyle other, double t) → FFormFieldStyle

Available on FFormFieldStyle, provided by the $FFormFieldStyleTransformations extension

Linearly interpolate between this and another FFormFieldStyle using the given factor t.
lerp(FLabelStyle other, double t) → FLabelStyle

Available on FLabelStyle, provided by the $FLabelStyleTransformations extension

Linearly interpolate between this and another FLabelStyle using the given factor t.
lerp(FSliderStyle other, double t) → FSliderStyle

Available on FSliderStyle, provided by the $FSliderStyleTransformations extension

Linearly interpolate between this and another FSliderStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited