FSliderValue class sealed

A FSlider's active track/value.

Mixed-in types

Constructors

FSliderValue({required double max, double min, ({double max, double min}) constraints})
Creates a FSliderValue.
factory

Properties

constraints → ({double max, double min})
The value's minimum and maximum constraints along the slider's track, in percentage.
final
hashCode → int
The hash code for this object.
no setterinherited
max → double
The value's current maximum value along the slider's track, in percentage.
final
min → double
The value's current minimum value along the slider's track, in percentage.
final
pixelConstraints → ({double extent, double max, double min})
The value's minimum and maximum constraints along the slider's track, in logical pixels.
final
pixels → ({double max, double min})
The value's current minimum and maximum offset along the slider's track, in logical pixels.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
move({required bool min, required double to}) → FSliderValue
Returns a FSliderValue which min edge is moved to to.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
step({required bool min, required bool expand}) → FSliderValue
Returns a FSliderValue which min edge is increased/decreased to the next/previous step.
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited