FSwitch class

A control that allows the user to toggle between checked and unchecked.

Typically used to toggle the on/off state of a single setting.

See:

Inheritance

Constructors

FSwitch({FSwitchStyleDelta style = const .context(), bool leadingLabel = false, Widget? label, Widget? description, Widget? error, String? semanticsLabel, bool value = false, ValueChanged<bool>? onChange, bool enabled = true, bool autofocus = false, FocusNode? focusNode, ValueChanged<bool>? onFocusChange, DragStartBehavior dragStartBehavior = .start, Key? key})
Creates a FSwitch.
const

Properties

autofocus → bool
True if this widget will be selected as the initial focus when no other node in its scope is currently focused.
final
description → Widget?
The description displayed below the label.
final
dragStartBehavior → DragStartBehavior
Determines the way that drag start behavior is handled.
final
enabled → bool
Whether this switch is enabled. Defaults to true.
final
error → Widget?
The error displayed below the description.
final
focusNode → FocusNode?
An optional focus node to use as the focus node for this widget.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label → Widget?
The label displayed next to the switch.
final
leadingLabel → bool
Whether the label is positioned before the switch (leading) instead of after it (trailing). Defaults to false.
final
onChange → ValueChanged<bool>?
Called when the user toggles the switch on or off.
final
onFocusChange → ValueChanged<bool>?
Handler called when the focus changes.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticsLabel → String?
The semantic label used by accessibility frameworks.
final
style → FSwitchStyleDelta
The style. Defaults to FThemeData.switchStyle.
final
value → bool
The current value of the switch.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<FSwitch>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited