FTabMotion class

Motion-related properties for FTabs.

All motion is automatically disabled when FAccessibility.motion is not FAccessibilityMotion.all.

Implemented types
Mixed-in types
Available extensions

Constructors

FTabMotion({Duration duration = const Duration(milliseconds: 300), Curve curve = Curves.easeOutCubic})
Creates a FTabMotion.
const

Properties

curve → Curve
The curve of the tab change animation. Defaults to Curves.easeOutCubic.
final
duration → Duration
The duration of the tab change animation. Defaults to 300 ms.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(covariant Object _) → FTabMotion
Returns itself.
inherited
copyWith({Duration? duration, Curve? curve}) → FTabMotion

Available on FTabMotion, provided by the $FTabMotionTransformations extension

Returns a copy of this FTabMotion with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FTabMotion other, double t) → FTabMotion

Available on FTabMotion, provided by the $FTabMotionTransformations extension

Linearly interpolate between this and another FTabMotion using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited