FTabs class
Allows switching between widgets through tabs.
See:
- https://forui.dev/docs/navigation/tabs for working examples.
- FTabsStyle for customizing tabs' appearance.
- Inheritance
Constructors
-
FTabs({required List<
FTabEntry> children, FTabControl control = const .managed(), bool scrollable = false, ScrollPhysics? physics, ScrollPhysics contentPhysics = const BouncingScrollPhysics(), FTabsStyleDelta style = const .context(), ValueChanged<int> ? onPress, MouseCursor mouseCursor = .defer, bool expands = false, Key? key}) - Creates a FTabs.
Properties
-
children
→ List<
FTabEntry> -
The tabs.
final
- contentPhysics → ScrollPhysics
-
The physics for swipe gestures between tab content areas on touch devices, and scroll wheel navigation on desktop.
Use NeverScrollableScrollPhysics to disable the interaction. Ignored if expands is false. Defaults to
BouncingScrollPhysics.
final
- control → FTabControl
-
Controls the tab value.
final
- expands → bool
-
Whether the tab content should expand to fill the remaining available space. Defaults to false.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- mouseCursor → MouseCursor
-
The mouse cursor. Defaults to MouseCursor.defer.
final
-
onPress
→ ValueChanged<
int> ? -
A callback that is triggered when a tab is pressed. It is called before the tab switching animation begins
and the controller is updated.
final
- physics → ScrollPhysics?
-
How the tab should respond to user input.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollable → bool
-
Whether this tab bar can be scrolled horizontally. Defaults to false.
final
- style → FTabsStyleDelta
-
The style.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< FTabs> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited