contentPhysics property

ScrollPhysics contentPhysics
final

The physics for scrolling between tab content areas horizontally using a scroll wheel on desktop and swipe gestures on touch devices. Ignored if expands is false. Defaults to BouncingScrollPhysics.

Implementation

final ScrollPhysics contentPhysics;