FTabsStyle class

FTabs's style.

Implemented types
Mixed-in types
Available extensions

Constructors

FTabsStyle({required Decoration decoration, required FVariants<FTabVariantConstraint, FTabVariant, TextStyle, TextStyleDelta> labelTextStyle, required Decoration indicatorDecoration, required FFocusedOutlineStyle focusedOutlineStyle, EdgeInsetsGeometry padding = const .all(4), FTabBarIndicatorSize indicatorSize = .tab, double minHeight = 36, double spacing = 10})
Creates a FTabsStyle.
FTabsStyle.inherit({required FColors colors, required FTypography typography, required FStyle style})
Creates a FTabsStyle that inherits its properties.

Properties

decoration → Decoration
The decoration.
final
focusedOutlineStyle → FFocusedOutlineStyle
The focused outline style.
final
hashCode → int
The hash code for this object.
no setterinherited
indicatorDecoration → Decoration
The indicator.
final
indicatorSize → FTabBarIndicatorSize
The indicator size. Defaults to FTabBarIndicatorSize.tab.
final
labelTextStyle → FVariants<FTabVariantConstraint, FTabVariant, TextStyle, TextStyleDelta>
The label's TextStyle.
final
minHeight → double
The minimum height of each tab. Tabs grow to fit taller labels.
final
padding → EdgeInsetsGeometry
The padding. Defaults to EdgeInsets.all(4).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spacing → double
The spacing between the tab bar and the views. Defaults to 10.
final

Methods

call(covariant Object _) → FTabsStyle
Returns itself.
inherited
copyWith({DecorationDelta? decoration, FVariantsDelta<FTabVariantConstraint, FTabVariant, TextStyle, TextStyleDelta>? labelTextStyle, DecorationDelta? indicatorDecoration, FFocusedOutlineStyleDelta? focusedOutlineStyle, EdgeInsetsGeometryDelta? padding, FTabBarIndicatorSize? indicatorSize, double? minHeight, double? spacing}) → FTabsStyle

Available on FTabsStyle, provided by the $FTabsStyleTransformations extension

Returns a copy of this FTabsStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FTabsStyle other, double t) → FTabsStyle

Available on FTabsStyle, provided by the $FTabsStyleTransformations extension

Linearly interpolate between this and another FTabsStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited