FTextFieldSizeStyles extension type

FTextFieldStyle's size styles.

on
Implemented types

Constructors

FTextFieldSizeStyles(FVariants<FTextFieldSizeVariantConstraint, FTextFieldSizeVariant, FTextFieldStyle, FTextFieldStyleDelta> _)
FTextFieldSizeStyles.inherit({required FColors colors, required FTypography typography, required FStyle style, required bool touch})
Creates a FTextFieldSizeStyles that inherits its properties.
factory

Properties

base FTextFieldStyle
The base variant.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
lg FTextFieldStyle
The large text field style.
no setter
md FTextFieldStyle
The medium (default) text field style.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sm FTextFieldStyle
The small text field style.
no setter
variants Map<FTextFieldSizeVariantConstraint, FTextFieldStyle>
The variants.
finalinherited

Methods

apply(List<FVariantOperation<FTextFieldSizeVariantConstraint, FTextFieldSizeVariant, FTextFieldStyle, FTextFieldStyleDelta>> operations) FVariants<FTextFieldSizeVariantConstraint, FTextFieldSizeVariant, FTextFieldStyle, FTextFieldStyleDelta>
Applies a sequence of delta-based operations to this FVariants.
inherited
applyValues(List<FVariantValueDeltaOperation<FTextFieldSizeVariantConstraint, FTextFieldSizeVariant, FTextFieldStyle, FTextFieldStyleDelta>> operations) FVariants<FTextFieldSizeVariantConstraint, FTextFieldSizeVariant, FTextFieldStyle, FTextFieldStyleDelta>
Applies a sequence of value-based operations to this FVariants.
inherited
call(covariant FVariants<FTextFieldSizeVariantConstraint, FTextFieldSizeVariant, FTextFieldStyle, FTextFieldStyleDelta> _) FVariants<FTextFieldSizeVariantConstraint, FTextFieldSizeVariant, FTextFieldStyle, FTextFieldStyleDelta>
Applies this delta to the given value.
inherited
cast<T1 extends FVariantConstraint, T2 extends FVariant>() FVariants<T1, T2, FTextFieldStyle, FTextFieldStyleDelta>
Returns a new FVariants with the variant type parameters cast to T1 and T2.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(Set<FVariant> variants) FTextFieldStyle
Returns most specific matching variant, or base if no constraints match.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited