FTextFieldSizeVariantConstraint extension type

Represents a combination of variants.

See also:

on
Implemented types
Implementers

Constructors

FTextFieldSizeVariantConstraint.not(FTextFieldSizeVariant variant)
Creates a FTextFieldSizeVariantConstraint that negates variant.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

and(FTextFieldSizeVariantConstraint other) FTextFieldSizeVariantConstraint
Combines this with other using a logical AND operation.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
satisfiedBy(Set<FVariant> variants) bool
Returns true if all variants in this constraint are present in variants.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

android → const FTextFieldSizeVariant
The Android platform variant.
desktop → const FTextFieldSizeVariant
A platform variant that matches all desktop-based platforms, windows, macOS and linux.
fuchsia → const FTextFieldSizeVariant
The Fuchsia platform variant.
iOS → const FTextFieldSizeVariant
The iOS platform variant.
lg → const FTextFieldSizeVariant
The large text field size.
linux → const FTextFieldSizeVariant
The Linux platform variant.
macOS → const FTextFieldSizeVariant
The macOS platform variant.
md → const FTextFieldSizeVariant
The medium (default) text field size.
sm → const FTextFieldSizeVariant
The small text field size.
touch → const FTextFieldSizeVariant
A platform variant that matches all touch-based platforms, android, iOS and fuchsia.
web → const FTextFieldSizeVariant
The web platform variant.
windows → const FTextFieldSizeVariant
The Windows platform variant.