FRawTileContentStyle class

A tile-specific FRawItemContentStyle.

Inheritance
Implemented types
Available extensions

Constructors

FRawTileContentStyle({required FVariants<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta> prefixIconStyle, required FVariants<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta> childTextStyle, EdgeInsetsGeometry padding = const .symmetric(horizontal: 15, vertical: 14.5), double prefixIconSpacing = 10})
Creates a FRawTileContentStyle.
FRawTileContentStyle.inherit({required FColors colors, required FTypography typography, required Color prefix, required Color color})
Creates a FRawTileContentStyle that inherits its properties.

Properties

childTextStyle → FVariants<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
padding → EdgeInsetsGeometry
no setterinherited
prefixIconSpacing → double
no setterinherited
prefixIconStyle → FVariants<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(covariant Object _) → FRawTileContentStyle
Returns itself.
inherited
copyWith({FVariantsDelta<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta>? prefixIconStyle, FVariantsDelta<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta>? childTextStyle, EdgeInsetsGeometryDelta? padding, double? prefixIconSpacing}) → FRawItemContentStyle

Available on FRawItemContentStyle, provided by the $FRawItemContentStyleTransformations extension

Returns a copy of this FRawItemContentStyle with the given properties replaced.
copyWith({FVariantsDelta<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta>? prefixIconStyle, FVariantsDelta<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta>? childTextStyle, EdgeInsetsGeometryDelta? padding, double? prefixIconSpacing}) → FRawTileContentStyle

Available on FRawTileContentStyle, provided by the $FRawTileContentStyleTransformations extension

Returns a copy of this FRawTileContentStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FRawItemContentStyle other, double t) → FRawItemContentStyle

Available on FRawItemContentStyle, provided by the $FRawItemContentStyleTransformations extension

Linearly interpolate between this and another FRawItemContentStyle using the given factor t.
lerp(FRawTileContentStyle other, double t) → FRawTileContentStyle

Available on FRawTileContentStyle, provided by the $FRawTileContentStyleTransformations extension

Linearly interpolate between this and another FRawTileContentStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited