variant property

FItemVariant variant
final

The variant used to resolve the style from FTileStyles.

Defaults to FItemVariant.primary. The current platform variant is automatically included during style resolution. To change the platform variant, update the enclosing FTheme.platform/FAdaptiveScope.platform.

For example, to create a destructive tile:

FTile(
  variant: .destructive,
  title: Text('Delete'),
)

Implementation

final FItemVariant variant;