FTileGroupStyle class

A FTileGroup's style.

Inheritance
Implemented types
Available extensions

Constructors

FTileGroupStyle({required Decoration decoration, required FVariants<FItemGroupVariantConstraint, FItemGroupVariant, Color, Delta> dividerColor, required double dividerWidth, required FTileStyles tileStyles, required FVariants<FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta> labelTextStyle, required FVariants<FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta> descriptionTextStyle, required FVariants<FFormFieldErrorVariantConstraint, FFormFieldErrorVariant, TextStyle, TextStyleDelta> errorTextStyle, required Future<void> slidePressHapticFeedback(), FVariants<FItemGroupVariantConstraint, FItemGroupVariant, bool, Delta> slideableTiles = const .all(true), EdgeInsetsGeometry labelPadding = const .symmetric(vertical: 7.7), EdgeInsetsGeometry descriptionPadding = const .only(top: 7.5), EdgeInsetsGeometry errorPadding = const .only(top: 5), EdgeInsetsGeometry childPadding = .zero, FLabelMotion labelMotion = const FLabelMotion()})
Creates a FTileGroupStyle.
FTileGroupStyle.inherit({required FColors colors, required FTypography typography, required FStyle style, required FHapticFeedback hapticFeedback})
Creates a FTileGroupStyle that inherits from the given arguments.
factory

Properties

childPadding → EdgeInsetsGeometry
no setterinherited
decoration → Decoration
The group's decoration.
final
descriptionPadding → EdgeInsetsGeometry
no setterinherited
descriptionTextStyle → FVariants<FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta>
no setterinherited
dividerColor → FVariants<FItemGroupVariantConstraint, FItemGroupVariant, Color, Delta>
The divider's style.
final
dividerWidth → double
The divider's width.
final
errorPadding → EdgeInsetsGeometry
no setterinherited
errorTextStyle → FVariants<FFormFieldErrorVariantConstraint, FFormFieldErrorVariant, TextStyle, TextStyleDelta>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
labelMotion → FLabelMotion
no setterinherited
labelPadding → EdgeInsetsGeometry
no setterinherited
labelTextStyle → FVariants<FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slideableTiles → FVariants<FItemGroupVariantConstraint, FItemGroupVariant, bool, Delta>
Whether the tiles support pressing a tile and sliding to another. Defaults to true.
final
slidePressHapticFeedback → Future<void> Function()
The haptic feedback for when the user slides from one tile to another when slideableTiles is enabled.
final
tileStyles → FTileStyles
The tile's styles.
final

Methods

call(covariant Object _) → FTileGroupStyle
Returns itself.
inherited
copyWith({FVariantsDelta<FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta>? labelTextStyle, FVariantsDelta<FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta>? descriptionTextStyle, FVariantsDelta<FFormFieldErrorVariantConstraint, FFormFieldErrorVariant, TextStyle, TextStyleDelta>? errorTextStyle}) → FFormFieldStyle

Available on FFormFieldStyle, provided by the $FFormFieldStyleTransformations extension

Returns a copy of this FFormFieldStyle with the given properties replaced.
copyWith({EdgeInsetsGeometryDelta? labelPadding, EdgeInsetsGeometryDelta? descriptionPadding, EdgeInsetsGeometryDelta? errorPadding, EdgeInsetsGeometryDelta? childPadding, FLabelMotionDelta? labelMotion, FVariantsDelta<FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta>? labelTextStyle, FVariantsDelta<FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta>? descriptionTextStyle, FVariantsDelta<FFormFieldErrorVariantConstraint, FFormFieldErrorVariant, TextStyle, TextStyleDelta>? errorTextStyle}) → FLabelStyle

Available on FLabelStyle, provided by the $FLabelStyleTransformations extension

Returns a copy of this FLabelStyle with the given properties replaced.
copyWith({DecorationDelta? decoration, FVariantsValueDelta<FItemGroupVariantConstraint, FItemGroupVariant, Color, Delta>? dividerColor, double? dividerWidth, FVariantsDelta<FItemVariantConstraint, FItemVariant, FTileStyle, FTileStyleDelta>? tileStyles, Future<void> slidePressHapticFeedback()?, FVariantsValueDelta<FItemGroupVariantConstraint, FItemGroupVariant, bool, Delta>? slideableTiles, EdgeInsetsGeometryDelta? labelPadding, EdgeInsetsGeometryDelta? descriptionPadding, EdgeInsetsGeometryDelta? errorPadding, EdgeInsetsGeometryDelta? childPadding, FLabelMotionDelta? labelMotion, FVariantsDelta<FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta>? labelTextStyle, FVariantsDelta<FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta>? descriptionTextStyle, FVariantsDelta<FFormFieldErrorVariantConstraint, FFormFieldErrorVariant, TextStyle, TextStyleDelta>? errorTextStyle}) → FTileGroupStyle

Available on FTileGroupStyle, provided by the $FTileGroupStyleTransformations extension

Returns a copy of this FTileGroupStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FFormFieldStyle other, double t) → FFormFieldStyle

Available on FFormFieldStyle, provided by the $FFormFieldStyleTransformations extension

Linearly interpolate between this and another FFormFieldStyle using the given factor t.
lerp(FLabelStyle other, double t) → FLabelStyle

Available on FLabelStyle, provided by the $FLabelStyleTransformations extension

Linearly interpolate between this and another FLabelStyle using the given factor t.
lerp(FTileGroupStyle other, double t) → FTileGroupStyle

Available on FTileGroupStyle, provided by the $FTileGroupStyleTransformations extension

Linearly interpolate between this and another FTileGroupStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited