slidePressHapticFeedback property
The haptic feedback for when the user slides from one tile to another when slideableTiles is enabled.
Implementation
@override
final Future<void> Function() slidePressHapticFeedback;
The haptic feedback for when the user slides from one tile to another when slideableTiles is enabled.
@override
final Future<void> Function() slidePressHapticFeedback;