clearable property
If true, the input field will show a clear button when a time is selected. Defaults to false.
Implementation
final bool clearable;
If true, the input field will show a clear button when a time is selected. Defaults to false.
final bool clearable;