suffixBuilder property

FFieldIconBuilder<FTextFieldStyle>? suffixBuilder
final

Builds a widget at the end of the input field that can be pressed to toggle the popover. Defaults to no suffix.

Implementation

final FFieldIconBuilder<FTextFieldStyle>? suffixBuilder;