FTimeFieldControl.lifted constructor
const
FTimeFieldControl.lifted({
- required FTime? time,
- required ValueChanged<
FTime?> onChange, - Duration duration,
- Curve curve,
Creates lifted state control.
The time parameter contains the current selected time.
The onChange callback is invoked when the user selects a time.
The duration when animating to time from an invalid/different time. Defaults to 200 milliseconds.
The curve when animating to time from an invalid/different time. Defaults to Curves.easeOutCubic.
Implementation
const factory lifted({required FTime? time, required ValueChanged<FTime?> onChange, Duration duration, Curve curve}) =
_Lifted;