FTimeFieldStyle class

A time field's style.

Implemented types
Mixed-in types
Available extensions

Constructors

FTimeFieldStyle({required FTextFieldSizeStyles fieldStyles, required FPopoverStyle popoverStyle, required FTimePickerStyle pickerStyle})
Creates a FTimeFieldStyle.
FTimeFieldStyle.inherit({required FColors colors, required FTypography typography, required FStyle style, required FHapticFeedback hapticFeedback, required bool touch})
Creates a FTimeFieldStyle that inherits its properties.

Properties

fieldStyles → FTextFieldSizeStyles
The time field's text field size styles.
final
hashCode → int
The hash code for this object.
no setterinherited
pickerStyle → FTimePickerStyle
The time field's picker style.
final
popoverStyle → FPopoverStyle
The time field picker's popover style.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(covariant Object _) → FTimeFieldStyle
Returns itself.
inherited
copyWith({FVariantsDelta<FTextFieldSizeVariantConstraint, FTextFieldSizeVariant, FTextFieldStyle, FTextFieldStyleDelta>? fieldStyles, FPopoverStyleDelta? popoverStyle, FTimePickerStyleDelta? pickerStyle}) → FTimeFieldStyle

Available on FTimeFieldStyle, provided by the $FTimeFieldStyleTransformations extension

Returns a copy of this FTimeFieldStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FTimeFieldStyle other, double t) → FTimeFieldStyle

Available on FTimeFieldStyle, provided by the $FTimeFieldStyleTransformations extension

Linearly interpolate between this and another FTimeFieldStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited