FTimePickerStyle class

The style of a time picker.

Inheritance
Implemented types
Available extensions

Constructors

FTimePickerStyle({required TextStyle textStyle, required Decoration selectionDecoration, required FFocusedOutlineStyle focusedOutlineStyle, required Future<void> hapticFeedback(), int hourFlex = 1, int minuteFlex = 1, int periodFlex = 1, EdgeInsetsDirectional padding = const .only(start: 10, end: 10), double diameterRatio = 1.07, double squeeze = 1, double magnification = 1, double overAndUnderCenterOpacity = 0.25, double spacing = 0, TextHeightBehavior textHeightBehavior = const TextHeightBehavior(applyHeightToFirstAscent: false, applyHeightToLastDescent: false), double selectionHeightAdjustment = 5})
Creates a FTimePickerStyle.
const
FTimePickerStyle.inherit({required FColors colors, required FStyle style, required FTypography typography, required FHapticFeedback hapticFeedback, required bool touch})
Creates a FTimePickerStyle that inherits its properties.

Properties

diameterRatio → double
no setterinherited
focusedOutlineStyle → FFocusedOutlineStyle
no setterinherited
hapticFeedback → Future<void> Function()
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hourFlex → int
The hour wheel's flex factor. Defaults to 1.
final
magnification → double
no setterinherited
minuteFlex → int
The minute wheel's flex factor. Defaults to 1.
final
overAndUnderCenterOpacity → double
no setterinherited
padding → EdgeInsetsDirectional
The padding. Defaults to EdgeInsetsDirectional.only(start: 10, end: 10).
final
periodFlex → int
The period (AM/PM) wheel's flex factor. Defaults to 1.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectionDecoration → Decoration
no setterinherited
selectionHeightAdjustment → double
no setterinherited
spacing → double
no setterinherited
squeeze → double
no setterinherited
textHeightBehavior → TextHeightBehavior
no setterinherited
textStyle → TextStyle
no setterinherited

Methods

call(covariant Object _) → FTimePickerStyle
Returns itself.
inherited
copyWith({TextStyleDelta? textStyle, DecorationDelta? selectionDecoration, FFocusedOutlineStyleDelta? focusedOutlineStyle, Future<void> hapticFeedback()?, double? diameterRatio, double? squeeze, double? magnification, double? overAndUnderCenterOpacity, double? spacing, TextHeightBehavior? textHeightBehavior, double? selectionHeightAdjustment}) → FPickerStyle

Available on FPickerStyle, provided by the $FPickerStyleTransformations extension

Returns a copy of this FPickerStyle with the given properties replaced.
copyWith({int? hourFlex, int? minuteFlex, int? periodFlex, EdgeInsetsDirectionalDelta? padding, TextStyleDelta? textStyle, DecorationDelta? selectionDecoration, FFocusedOutlineStyleDelta? focusedOutlineStyle, Future<void> hapticFeedback()?, double? diameterRatio, double? squeeze, double? magnification, double? overAndUnderCenterOpacity, double? spacing, TextHeightBehavior? textHeightBehavior, double? selectionHeightAdjustment}) → FTimePickerStyle

Available on FTimePickerStyle, provided by the $FTimePickerStyleTransformations extension

Returns a copy of this FTimePickerStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FPickerStyle other, double t) → FPickerStyle

Available on FPickerStyle, provided by the $FPickerStyleTransformations extension

Linearly interpolate between this and another FPickerStyle using the given factor t.
lerp(FTimePickerStyle other, double t) → FTimePickerStyle

Available on FTimePickerStyle, provided by the $FTimePickerStyleTransformations extension

Linearly interpolate between this and another FTimePickerStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited