FTimePickerStyleDelta.delta constructor
const
FTimePickerStyleDelta.delta({
- int? hourFlex,
- int? minuteFlex,
- int? periodFlex,
- EdgeInsetsDirectionalDelta? padding,
- double? diameterRatio,
- double? squeeze,
- double? magnification,
- double? overAndUnderCenterOpacity,
- double? spacing,
- TextStyleDelta? textStyle,
- TextHeightBehavior? textHeightBehavior,
- double? selectionHeightAdjustment,
- DecorationDelta? selectionDecoration,
- FFocusedOutlineStyleDelta? focusedOutlineStyle,
- Future<
void> hapticFeedback()?,
Creates a partial modification of a FTimePickerStyle.
Parameters
- FTimePickerStyle.hourFlex - The hour wheel's flex factor.
- FTimePickerStyle.minuteFlex - The minute wheel's flex factor.
- FTimePickerStyle.periodFlex - The period (AM/PM) wheel's flex factor.
- FTimePickerStyle.padding - The padding.
- FTimePickerStyle.diameterRatio - A ratio between the diameter of the cylinder and the viewport's size.
- FTimePickerStyle.squeeze - The angular compactness of the children on the wheel.
- FTimePickerStyle.magnification - The zoomed-in rate of the magnifier.
- FTimePickerStyle.overAndUnderCenterOpacity - The opacity value applied to the wheel above and below the magnifier.
- FTimePickerStyle.spacing - The spacing between the picker's wheels.
- FTimePickerStyle.textStyle - The picker's text style.
- FTimePickerStyle.textHeightBehavior - The picker's text height behavior.
- FTimePickerStyle.selectionHeightAdjustment - An amount to add to the height of the selection.
- FTimePickerStyle.selectionDecoration - The selection's decoration.
- FTimePickerStyle.focusedOutlineStyle - The focused outline style.
- FTimePickerStyle.hapticFeedback - The haptic feedback for when the picker snaps to an item.
Implementation
const factory FTimePickerStyleDelta.delta({
int? hourFlex,
int? minuteFlex,
int? periodFlex,
EdgeInsetsDirectionalDelta? padding,
double? diameterRatio,
double? squeeze,
double? magnification,
double? overAndUnderCenterOpacity,
double? spacing,
TextStyleDelta? textStyle,
TextHeightBehavior? textHeightBehavior,
double? selectionHeightAdjustment,
DecorationDelta? selectionDecoration,
FFocusedOutlineStyleDelta? focusedOutlineStyle,
Future<void> Function()? hapticFeedback,
}) = _FTimePickerStyleDelta;