FToast class

A toast.

See:

Inheritance

Constructors

FToast({required Widget title, FToastVariant variant = .primary, FToastStyleDelta style = const .context(), Clip clipBehavior = .none, Widget? icon, Widget? description, Widget? suffix, Key? key})
Creates a FToast.
const

Properties

clipBehavior → Clip
The clip behavior applied to the toast's content.
final
description → Widget?
The toast's description. Defaults to a maximum of 100 lines. Set Text.maxLines to change this.
final
hashCode → int
The hash code for this object.
no setterinherited
icon → Widget?
An optional icon aligned to the start of the toast (left in LTR locales).
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → FToastStyleDelta
The style delta applied to the style resolved by variant.
final
suffix → Widget?
An optional widget aligned to the end of the toast (left in LTR locales).
final
title → Widget
The toast's title. Defaults to a maximum of 100 lines. Set Text.maxLines to change this.
final
variant → FToastVariant
The variants used to resolve the style from FToastStyles.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited