style property

FToastStyleDelta style
final

The style delta applied to the style resolved by variant.

The final style is computed by first resolving the base style from FToastStyles using variant, then applying this delta. This allows modifying variant-specific styles:

FToast(
  variant: .destructive,
  style: .delta(iconStyle: .delta(size: 24)), // modifies the destructive style
  title: Text('Large icon destructive toast'),
)

CLI

To generate and customize this style:

dart run forui style create toast

Implementation

final FToastStyleDelta style;