FToastMotion class

The motion-related properties for FToaster that affect individual toasts.

See FToasterMotion for motion properties that affect the entire toaster.

When FAccessibility.motion is:

Implemented types
Mixed-in types
Available extensions

Constructors

FToastMotion({Duration entranceDuration = const Duration(milliseconds: 400), Duration dismissDuration = const Duration(milliseconds: 300), Duration transitionDuration = const Duration(milliseconds: 400), Duration reentranceDuration = const Duration(milliseconds: 400), Duration exitDuration = const Duration(milliseconds: 400), Duration swipeCompletionDuration = const Duration(milliseconds: 150), Curve entranceCurve = Curves.easeOutCubic, Curve dismissCurve = Curves.easeOutCubic, Curve transitionCurve = Curves.easeOutCubic, Curve reentranceCurve = Curves.easeOutCubic, Curve exitCurve = Curves.easeOutCubic, Curve swipeCompletionCurve = Curves.easeInCubic, Animatable<double> entranceDismissFadeTween = const FImmutableTween(begin: 0.0, end: 1.0)})
Creates a FToastMotion.
const

Properties

dismissCurve → Curve
The toast's exit animation curve. Defaults to Curves.easeOutCubic.
final
dismissDuration → Duration
The duration of the toast's exit animation when it is dismissed. Defaults to 300ms.
final
entranceCurve → Curve
The toast's initial entrance animation curve. Defaults to Curves.easeOutCubic.
final
entranceDismissFadeTween → Animatable<double>
The toast's initial entrance's opacity and dismiss's fade tween. Defaults to [0, 1].
final
entranceDuration → Duration
The duration of the toast's entrance when it is initially added to to toaster. Defaults to 400ms.
final
exitCurve → Curve
The curve of the toast's fade-out animation when the number of toasts in a toaster exceeds the maximum allowed and this toast is hidden. Defaults to Curves.easeOutCubic.
final
exitDuration → Duration
The duration of the toast's fade-out animation when the number of toasts in a toaster exceeds the maximum allowed and this toast is hidden. Defaults to 400ms.
final
hashCode → int
The hash code for this object.
no setterinherited
reentranceCurve → Curve
The curve of the toast's fade-in animation when another toast has been dismissed and this toast re-enters the toaster. Defaults to Curves.easeOutCubic.
final
reentranceDuration → Duration
The duration of the toast's fade-in animation when another toast has been dismissed and this toast re-enters the toaster. Defaults to 400ms.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
swipeCompletionCurve → Curve
The toast's swipe completion animation curve. Defaults to Curves.easeInCubic.
final
swipeCompletionDuration → Duration
The toast's swipe completion animation duration. Defaults to 150ms.
final
transitionCurve → Curve
The toast's transition animation curve. Defaults to Curves.easeOutCubic.
final
transitionDuration → Duration
The duration of the toast's transition between places in the toaster. Defaults to 400ms.
final

Methods

call(covariant Object _) → FToastMotion
Returns itself.
inherited
copyWith({Duration? entranceDuration, Duration? dismissDuration, Duration? transitionDuration, Duration? reentranceDuration, Duration? exitDuration, Duration? swipeCompletionDuration, Curve? entranceCurve, Curve? dismissCurve, Curve? transitionCurve, Curve? reentranceCurve, Curve? exitCurve, Curve? swipeCompletionCurve, Animatable<double>? entranceDismissFadeTween}) → FToastMotion

Available on FToastMotion, provided by the $FToastMotionTransformations extension

Returns a copy of this FToastMotion with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FToastMotion other, double t) → FToastMotion

Available on FToastMotion, provided by the $FToastMotionTransformations extension

Linearly interpolate between this and another FToastMotion using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited