FToastStyle class

The toast's style.

Implemented types
Mixed-in types
Available extensions

Constructors

FToastStyle({required Decoration decoration, required IconThemeData iconStyle, required TextStyle titleTextStyle, required TextStyle descriptionTextStyle, required EdgeInsetsGeometry padding, BoxConstraints constraints = const BoxConstraints(maxHeight: 250, maxWidth: 400), ImageFilter? backgroundFilter, double iconSpacing = 10, double titleSpacing = 1, double suffixSpacing = 12, FToastMotion motion = const FToastMotion()})
Creates a FToastStyle.
FToastStyle.inherit({required FColors colors, required FTypography typography, required FStyle style, required bool touch})
Creates a FToastStyle that inherits its properties.
factory

Properties

backgroundFilter → ImageFilter?
An optional background filter. This only takes effect if the decoration has a transparent or translucent background color.
final
constraints → BoxConstraints
The toast's constraints. Defaults to BoxConstraints(maxHeight: 250, maxWidth: 400).
final
decoration → Decoration
The toast's decoration.
final
descriptionTextStyle → TextStyle
The description's text style.
final
hashCode → int
The hash code for this object.
no setterinherited
iconSpacing → double
The spacing between the icon and the title. Defaults to 10.
final
iconStyle → IconThemeData
The style of the toast's prefix icon.
final
motion → FToastMotion
The motion-related properties. Defaults to FToastMotion.
final
padding → EdgeInsetsGeometry
The toast content's padding.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suffixSpacing → double
The spacing between the content and the suffix. Defaults to 12.
final
titleSpacing → double
The spacing between the title and description. Defaults to 4 on primarily touch devices and 2 on non-primarily touch devices.
final
titleTextStyle → TextStyle
The title's text style.
final

Methods

call(covariant Object _) → FToastStyle
Returns itself.
inherited
copyWith({DecorationDelta? decoration, IconThemeDataDelta? iconStyle, TextStyleDelta? titleTextStyle, TextStyleDelta? descriptionTextStyle, EdgeInsetsGeometryDelta? padding, BoxConstraints? constraints, ImageFilter? backgroundFilter = Sentinels.imageFilter, double? iconSpacing, double? titleSpacing, double? suffixSpacing, FToastMotionDelta? motion}) → FToastStyle

Available on FToastStyle, provided by the $FToastStyleTransformations extension

Returns a copy of this FToastStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FToastStyle other, double t) → FToastStyle

Available on FToastStyle, provided by the $FToastStyleTransformations extension

Linearly interpolate between this and another FToastStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited