FToastVariantConstraint extension type

Represents a combination of variants.

See also:

on
Implemented types
Implementers

Constructors

FToastVariantConstraint.not(FToastVariant variant)
Creates a FToastVariantConstraint that negates variant.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

and(FToastVariantConstraint other) FToastVariantConstraint
Combines this with other using a logical AND operation.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
satisfiedBy(Set<FVariant> variants) bool
Returns true if all variants in this constraint are present in variants.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

android → const FToastVariant
The Android platform variant.
desktop → const FToastVariant
A platform variant that matches all desktop-based platforms, windows, macOS and linux.
destructive → const FToastVariant
The destructive toast style.
fuchsia → const FToastVariant
The Fuchsia platform variant.
iOS → const FToastVariant
The iOS platform variant.
linux → const FToastVariant
The Linux platform variant.
macOS → const FToastVariant
The macOS platform variant.
primary → const FToastVariant
The primary toast style.
touch → const FToastVariant
A platform variant that matches all touch-based platforms, android, iOS and fuchsia.
web → const FToastVariant
The web platform variant.
windows → const FToastVariant
The Windows platform variant.