FToasterMotion class

The motion-related properties for FToaster that affect all toasts.

See FToastMotion for motion properties that affect individual toasts.

When FAccessibility.motion is:

Implemented types
Mixed-in types
Available extensions

Constructors

FToasterMotion({Duration expandDuration = const Duration(milliseconds: 400), Duration collapseDuration = const Duration(milliseconds: 300), Curve expandCurve = Curves.easeOutCubic, Curve collapseCurve = Curves.easeOut})
Creates a FToasterMotion.
const

Properties

collapseCurve → Curve
The animation curve for the toasts' collapsing. Defaults to Curves.easeOut.
final
collapseDuration → Duration
The duration of the toasts' collapsing. Defaults to 300ms.
final
expandCurve → Curve
The animation curve for the toasts' expansion and collapsing. Defaults to Curves.easeOutCubic.
final
expandDuration → Duration
The duration of the toasts' expansion. Defaults to 400ms.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(covariant Object _) → FToasterMotion
Returns itself.
inherited
copyWith({Duration? expandDuration, Duration? collapseDuration, Curve? expandCurve, Curve? collapseCurve}) → FToasterMotion

Available on FToasterMotion, provided by the $FToasterMotionTransformations extension

Returns a copy of this FToasterMotion with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FToasterMotion other, double t) → FToasterMotion

Available on FToasterMotion, provided by the $FToasterMotionTransformations extension

Linearly interpolate between this and another FToasterMotion using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited