FToasterStyle class

FToaster's style.

Implemented types
Mixed-in types
Available extensions

Constructors

FToasterStyle({required FToastStyles toastStyles, double max = 3, EdgeInsetsGeometry padding = const .symmetric(horizontal: 20, vertical: 15), FToasterExpandBehavior expandBehavior = .hoverOrPress, Duration expandHoverEnterDuration = const Duration(milliseconds: 200), Duration expandHoverExitDuration = const Duration(milliseconds: 200), double expandStartSpacing = 0, double expandSpacing = 10, double collapsedProtrusion = 12, double collapsedScale = 0.9, FToasterMotion motion = const FToasterMotion(), FToastAlignment toastAlignment = .bottomEnd})
Creates a FToasterStyle.
const
FToasterStyle.inherit({required FColors colors, required FTypography typography, required FStyle style, required bool touch})
Creates a FToasterStyle that inherits its properties.

Properties

collapsedProtrusion → double
The protrusion of the collapsed toasts behind the front toast. This is scaled by the number of toasts in front of the toast.
final
collapsedScale → double
The scaling factor pf the collapsed toasts behind the front toast. This is scaled by the number of toasts in front of the toast.
final
expandBehavior → FToasterExpandBehavior
The toaster's expansion behavior. Defaults to FToasterExpandBehavior.hoverOrPress.
final
expandHoverEnterDuration → Duration
The duration to wait after entering the toaster before expanding the toasts. Defaults to 200ms.
final
expandHoverExitDuration → Duration
The duration to wait after exiting the toaster before collapsing the toasts.
final
expandSpacing → double
The spacing between the toasts when they are expanded. Defaults to 10.0.
final
expandStartSpacing → double
The spacing below or above the toasts when they are expanded. Defaults to 0.
final
hashCode → int
The hash code for this object.
no setterinherited
max → double
The maximum number of entries shown per FToastAlignment. Defaults to to 3.
final
motion → FToasterMotion
The motion-related properties. Defaults to FToasterMotion.
final
padding → EdgeInsetsGeometry
The toaster's padding. Defaults to EdgeInsets.symmetric(horizontal: 20, vertical: 15).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toastAlignment → FToastAlignment
The toast's alignment relative to a FToaster. Defaults to FToastAlignment.topCenter on touch devices, and FToastAlignment.bottomEnd otherwise.
final
toastStyles → FToastStyles
The toast variant styles.
final

Methods

call(covariant Object _) → FToasterStyle
Returns itself.
inherited
copyWith({FVariantsDelta<FToastVariantConstraint, FToastVariant, FToastStyle, FToastStyleDelta>? toastStyles, double? max, EdgeInsetsGeometryDelta? padding, FToasterExpandBehavior? expandBehavior, Duration? expandHoverEnterDuration, Duration? expandHoverExitDuration, double? expandStartSpacing, double? expandSpacing, double? collapsedProtrusion, double? collapsedScale, FToasterMotionDelta? motion, FToastAlignment? toastAlignment}) → FToasterStyle

Available on FToasterStyle, provided by the $FToasterStyleTransformations extension

Returns a copy of this FToasterStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FToasterStyle other, double t) → FToasterStyle

Available on FToasterStyle, provided by the $FToasterStyleTransformations extension

Linearly interpolate between this and another FToasterStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited