FTooltipControl.lifted constructor

const FTooltipControl.lifted({
  1. required bool shown,
  2. required ValueChanged<bool> onChange,
})

Creates a FTooltipControl for controlling a tooltip using lifted state.

The shown parameter indicates whether the tooltip is currently shown. The onChange callback is invoked when the user triggers a show/hide action.

Implementation

const factory FTooltipControl.lifted({required bool shown, required ValueChanged<bool> onChange}) = _Lifted;