FTooltipGroup class

Groups FTooltips together such that subsequent tooltips after the first one appears instantly until the group becomes inactive after activeDuration.

FTheme contains a tooltip group by default.

See:

Inheritance

Constructors

FTooltipGroup({required Widget child, FTooltipStyleDelta style = const .context(), Duration activeDuration = const Duration(milliseconds: 300), bool hover = true, bool longPress = true, Key? key})
Creates a tooltip group.
const

Properties

activeDuration → Duration
The duration subsequent tooltips in this group will appear instantly on hover. Defaults to 300ms.
final
child → Widget
The child widget tree containing FTooltips.
final
hashCode → int
The hash code for this object.
no setterinherited
hover → bool
True if child FTooltips should be shown when hovered over. Defaults to true.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
longPress → bool
True if child FTooltips should be shown when long pressed. Defaults to true.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → FTooltipStyleDelta
The tooltip's style.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<FTooltipGroup>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited