style property

FTooltipStyleDelta style
final

The tooltip's style.

This style is passed down to all child FTooltips in this group. Individual tooltips can override this style using their own FTooltip.style parameter.

Implementation

final FTooltipStyleDelta style;