FTooltipStyle class

A FTooltip's style.

Implemented types
Mixed-in types
Available extensions

Constructors

FTooltipStyle({required Decoration decoration, required TextStyle textStyle, required Future<void> hapticFeedback(), ImageFilter? backgroundFilter, EdgeInsets padding = const .symmetric(horizontal: 14, vertical: 10), FTooltipMotion motion = const FTooltipMotion(), Duration hoverEnterDuration = const Duration(milliseconds: 500), Duration hoverExitDuration = .zero, Duration longPressExitDuration = const Duration(milliseconds: 1500)})
Creates a FTooltipStyle.
const
FTooltipStyle.inherit({required FColors colors, required FTypography typography, required FStyle style, FTooltipMotion motion = const FTooltipMotion(), Duration hoverEnterDuration = const Duration(milliseconds: 500), Duration hoverExitDuration = .zero, Duration longPressExitDuration = const Duration(milliseconds: 1500)})
Creates a FTooltipStyle that inherits its properties.

Properties

backgroundFilter ImageFilter?
An optional background filter applied to the tooltip.
final
decoration Decoration
The box decoration.
final
hapticFeedback Future<void> Function()
The haptic feedback for when the tooltip is shown via long press.
final
hashCode int
The hash code for this object.
no setterinherited
hoverEnterDuration Duration
The duration to wait before showing the tooltip after the user hovers over the target. Defaults to 500ms.
final
hoverExitDuration Duration
The duration to wait before hiding the tooltip after the user has stopped hovering over the target.
final
longPressExitDuration Duration
The duration to wait before hiding the tooltip after the user has stopped pressing the target. Defaults to 1500ms.
final
motion FTooltipMotion
The tooltip's motion configuration.
final
padding EdgeInsets
The padding surrounding the tooltip's text.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textStyle TextStyle
The tooltip's default text style.
final

Methods

call(covariant Object _) FTooltipStyle
Returns itself.
inherited
copyWith({DecorationDelta? decoration, ImageFilter? backgroundFilter = Sentinels.imageFilter, EdgeInsetsDelta? padding, TextStyleDelta? textStyle, Future<void> hapticFeedback()?, FTooltipMotionDelta? motion, Duration? hoverEnterDuration, Duration? hoverExitDuration, Duration? longPressExitDuration}) FTooltipStyle

Available on FTooltipStyle, provided by the $FTooltipStyleTransformations extension

Returns a copy of this FTooltipStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FTooltipStyle other, double t) FTooltipStyle

Available on FTooltipStyle, provided by the $FTooltipStyleTransformations extension

Linearly interpolate between this and another FTooltipStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

shadow → const List<BoxShadow>
The tooltip's default shadow in FTooltipStyle.inherit.