hoverExitDuration property
The duration to wait before hiding the tooltip after the user has stopped hovering over the target.
Defaults to 100ms. It is not recommended to set this below 100ms as it does not conform with WCAG 1.4.13, since the tip may hide before the pointer can move onto it.
Implementation
@override
final Duration hoverExitDuration;