FTooltipStyleDelta.delta constructor
const
FTooltipStyleDelta.delta({
- DecorationDelta? decoration,
- ImageFilter? backgroundFilter,
- EdgeInsetsDelta? padding,
- TextStyleDelta? textStyle,
- Future<
void> hapticFeedback()?, - FTooltipMotionDelta? motion,
- Duration? hoverEnterDuration,
- Duration? hoverExitDuration,
- Duration? longPressExitDuration,
Creates a partial modification of a FTooltipStyle.
Parameters
- FTooltipStyle.decoration - The box decoration.
- FTooltipStyle.backgroundFilter - An optional background filter applied to the tooltip.
- FTooltipStyle.padding - The padding surrounding the tooltip's text.
- FTooltipStyle.textStyle - The tooltip's default text style.
- FTooltipStyle.hapticFeedback - The haptic feedback for when the tooltip is shown via long press.
- FTooltipStyle.motion - The tooltip's motion configuration.
- FTooltipStyle.hoverEnterDuration - The duration to wait before showing the tooltip after the user hovers over the target.
- FTooltipStyle.hoverExitDuration - The duration to wait before hiding the tooltip after the user has stopped hovering over the target.
- FTooltipStyle.longPressExitDuration - The duration to wait before hiding the tooltip after the user has stopped pressing the target.
Implementation
const factory FTooltipStyleDelta.delta({
DecorationDelta? decoration,
ImageFilter? backgroundFilter,
EdgeInsetsDelta? padding,
TextStyleDelta? textStyle,
Future<void> Function()? hapticFeedback,
FTooltipMotionDelta? motion,
Duration? hoverEnterDuration,
Duration? hoverExitDuration,
Duration? longPressExitDuration,
}) = _FTooltipStyleDelta;