FAccessibility class final
The accessibility features which Forui widgets adhere to.
- Mixed-in types
Constructors
- FAccessibility({required FAccessibilityMotion motion, required bool focusHighlight})
-
Creates a FAccessibility.
const
Properties
-
True if a screen reader or similar service is changing the interaction model.
final
- focusHighlight → bool
-
True if focused widgets should show a focus highlight, such as a focus ring.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- motion → FAccessibilityMotion
-
The motion preference.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{FAccessibilityMotion? motion, bool? focusHighlight}) → FAccessibility - Returns a copy of this FAccessibility with the given fields replaced.
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override