FAccessibilityScope class

Provides the FAccessibility features to descendants and updates them when the platform settings change.

Inheritance

Constructors

FAccessibilityScope({required Widget child, FAccessibility? data, Key? key})
Creates an FAccessibilityScope.
const

Properties

child → Widget
The widget below this widget in the tree.
final
data → FAccessibility?
The features to expose. When null, the platform features are observed instead.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<FAccessibilityScope>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

accessibleNavigationOf(BuildContext context) → bool
Returns FAccessibility.accessibleNavigation of the nearest FAccessibilityScope in the given context.
focusHighlightOf(BuildContext context) → bool
Returns FAccessibility.focusHighlight of the nearest FAccessibilityScope in the given context.
motionOf(BuildContext context) → FAccessibilityMotion
Returns FAccessibility.motion of the nearest FAccessibilityScope in the given context.