cutout property
An optional non-interactive cutout that can be used to create a hole in the barrier for the underlying layer.
Implementation
final RenderBox? cutout;
An optional non-interactive cutout that can be used to create a hole in the barrier for the underlying layer.
final RenderBox? cutout;