FOverlayControl.lifted constructor
const
FOverlayControl.lifted({
- required bool shown,
- required ValueChanged<
bool> onChange,
Creates a FOverlayControl for controlling an overlay using lifted state.
The shown parameter indicates whether the overlay is currently shown.
The onChange callback is invoked when the user triggers a show/hide action.
Implementation
const factory FOverlayControl.lifted({required bool shown, required ValueChanged<bool> onChange}) = _Lifted;