padding property
The additional padding between the edges of the view and the edges of the portal.
This is applied on top of any padding from useViewPadding and useViewInsets.
Defaults to EdgeInsets.zero.
Implementation
final EdgeInsetsGeometry padding;