FPortalArrowDecoration class
A Decoration that combines a portal's existing decoration with an arrow.
The arrow's direction and positioning is derived from geometry and painted outside of the decorated box.
Contract
The decorated box must be positioned at the portal's origin, e.g. no Padding around the portal's DecoratedBox.
decoration must be a ShapeDecoration with an OutlinedBorder shape, or a BoxDecoration with a uniform border. In addition, decoration must not have an image and the border must be BorderSide.strokeAlignInside.
See:
- FPortalArrowAlignment for positioning the arrow along the edge.
- Inheritance
-
- Object
- Decoration
- FPortalArrowDecoration
- Available extensions
Constructors
-
FPortalArrowDecoration({required FPortalArrowStyle style, required Decoration decoration, required ValueListenable<
FPortalGeometry?> geometry, FPortalArrowAlignment alignment = .childCenter}) -
Creates a FPortalArrowDecoration.
factory
Properties
- alignment → FPortalArrowAlignment
-
The arrow's position along the edge facing the child. Defaults to FPortalArrowAlignment.childCenter.
final
- backgroundBlendMode → BlendMode?
-
Available on Decoration, provided by the Decorations extension
The BlendMode applied to the color or gradient background, or null if the decoration doesn't define one.no setter - border → ShapeBorder?
-
Available on Decoration, provided by the Decorations extension
The shape border, or null if one can't be derived.no setter - borderRadius → BorderRadiusGeometry?
-
Available on Decoration, provided by the Decorations extension
The BorderRadiusGeometry, or null if the decoration doesn't define one.no setter - color → Color?
-
Available on Decoration, provided by the Decorations extension
The background color, or null if the decoration doesn't define one.no setter - decoration → Decoration
-
The wrapped decoration.
final
-
geometry
→ ValueListenable<
FPortalGeometry?> -
The portal's geometry.
final
- gradient → Gradient?
-
Available on Decoration, provided by the Decorations extension
The Gradient, or null if the decoration doesn't define one.no setter - hashCode → int
-
The hash code for this object.
no setteroverride
- image → DecorationImage?
-
Available on Decoration, provided by the Decorations extension
The DecorationImage, or null if the decoration doesn't define one.no setter - isComplex → bool
-
Whether this decoration is complex enough to benefit from caching its painting.
no setteroverride
- padding → EdgeInsetsGeometry
-
Returns the insets to apply when using this decoration on a box
that has contents, so that the contents do not overlap the edges
of the decoration. For example, if the decoration draws a frame
around its edge, the padding would return the distance by which
to inset the children so as to not overlap the frame.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
shadows
→ List<
BoxShadow> ? -
Available on Decoration, provided by the Decorations extension
The list of shadows, or null if the decoration doesn't define one.no setter - style → FPortalArrowStyle
-
The arrow's style.
final
Methods
-
createBoxPainter(
[VoidCallback? onChanged]) → BoxPainter -
Returns a BoxPainter that will paint this decoration.
override
-
debugAssertIsValid(
) → bool -
In debug mode, throws an exception if the object is not in a
valid configuration. Otherwise, returns true.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
override
-
getClipPath(
Rect rect, TextDirection textDirection) → Path -
Returns a closed Path that describes the outer edge of this decoration.
override
-
hitTest(
Size size, Offset position, {TextDirection? textDirection}) → bool -
Tests whether the given point, on a rectangle of a given size,
would be considered to hit the decoration or not. For example,
if the decoration only draws a circle, this function might
return true if the point was inside the circle and false
otherwise.
override
-
lerpFrom(
Decoration? a, double t) → Decoration? -
Linearly interpolates from another Decoration (which may be of a
different class) to
this.inherited -
lerpTo(
Decoration? b, double t) → Decoration? -
Linearly interpolates from
thisto another Decoration (which may be of a different class).inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override