FPortalArrowStyle class

An arrow's shape.

                tipRadius
                    ╭╮                  ▲
                   ╱  ╲                 │
                  ╱    ╲                │ height
                 ╱      ╲               │
                ╱        ╲              │
╭──────────────╯          ╰────────     ▼
│◄────────────► ◄────────►│
│ cornerSpacing   width   ╰ baseRadius
Implemented types
Mixed-in types
Available extensions

Constructors

FPortalArrowStyle({double cornerSpacing = 0, double baseRadius = 3, double width = 14, double height = 7, double tipRadius = 2})
Creates a FPortalArrowStyle.
const

Properties

baseRadius → double
The radius of the rounded corners where the arrow's sides meet the decoration's edge. Defaults to 3.
final
cornerSpacing → double
The minimum spacing between the arrow and the decoration's rounded corners. Defaults to 0.
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
The height from base to tip. Defaults to 7.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tipRadius → double
The tip's radius. Defaults to 2.
final
width → double
The base's width. Defaults to 14.
final

Methods

call(covariant Object _) → FPortalArrowStyle
Returns itself.
inherited
copyWith({double? cornerSpacing, double? baseRadius, double? width, double? height, double? tipRadius}) → FPortalArrowStyle

Available on FPortalArrowStyle, provided by the $FPortalArrowStyleTransformations extension

Returns a copy of this FPortalArrowStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FPortalArrowStyle other, double t) → FPortalArrowStyle

Available on FPortalArrowStyle, provided by the $FPortalArrowStyleTransformations extension

Linearly interpolate between this and another FPortalArrowStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited