onLongPressDown property
A callback for when a primary pointer that might cause a long press has contacted the widget.
Analogous to GestureDetector.onLongPressDown.
There is no equivalent GestureDetector.onLongPressUp. Use onLongPressEnd instead.
Implementation
final GestureLongPressDownCallback? onLongPressDown;