onSecondaryLongPressCancel property
A callback for when the pointer that previously triggered onSecondaryLongPressDown will not end up causing a long press.
Analogous to GestureDetector.onSecondaryLongPressCancel.
Implementation
final GestureLongPressCancelCallback? onSecondaryLongPressCancel;