DecorationDelta class abstract
A delta that applies modifications to a Decoration.
- Mixed-in types
Constructors
-
DecorationDelta.boxDelta({Color? color, DecorationImage? image, BoxBorder? border, BorderRadiusGeometry? borderRadius, List<
BoxShadow> ? boxShadow, Gradient? gradient, BlendMode? backgroundBlendMode()?, BoxShape? shape}) -
Creates a partial modification that always produces a BoxDecoration.
constfactory
-
DecorationDelta.shapeDelta({Color? color, DecorationImage? image, Gradient? gradient, List<
BoxShadow> ? shadows, ShapeBorder? shape}) -
Creates a partial modification that always produces a ShapeDecoration.
constfactory
- DecorationDelta.value(Decoration decoration)
-
Creates a complete replacement for a Decoration.
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
covariant Decoration? decoration) → Decoration -
Applies this delta to the given value.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited