Decorations extension

Provides function to access common visual properties from a Decoration.

This is a best-effort conversion. Only BoxDecoration and ShapeDecoration are supported, all other Decorations will always return null.

on

Properties

backgroundBlendMode BlendMode?

Available on Decoration, provided by the Decorations extension

The BlendMode applied to the color or gradient background, or null if the decoration doesn't define one.
no setter
border ShapeBorder?

Available on Decoration, provided by the Decorations extension

The shape border, or null if one can't be derived.
no setter
borderRadius BorderRadiusGeometry?

Available on Decoration, provided by the Decorations extension

The BorderRadiusGeometry, or null if the decoration doesn't define one.
no setter
color Color?

Available on Decoration, provided by the Decorations extension

The background color, or null if the decoration doesn't define one.
no setter
gradient Gradient?

Available on Decoration, provided by the Decorations extension

The Gradient, or null if the decoration doesn't define one.
no setter
image DecorationImage?

Available on Decoration, provided by the Decorations extension

The DecorationImage, or null if the decoration doesn't define one.
no setter
shadows List<BoxShadow>?

Available on Decoration, provided by the Decorations extension

The list of shadows, or null if the decoration doesn't define one.
no setter