EdgeInsetsDelta class abstract
A delta that applies modifications to an EdgeInsets.
- Mixed-in types
Constructors
- EdgeInsetsDelta.add({double? left, double? top, double? right, double? bottom})
-
Creates an additive modification, adding the specified values to the current edges.
constfactory
- EdgeInsetsDelta.delta({double? left, double? top, double? right, double? bottom})
-
Creates a partial modification of LTRB edges, replacing only the specified edges.
constfactory
- EdgeInsetsDelta.scale(double factor)
-
Scales all edges by
factor.constfactory - EdgeInsetsDelta.value(EdgeInsets insets)
-
Creates a complete replacement for an EdgeInsets.
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
covariant EdgeInsets? insets) → EdgeInsets -
Applies this delta to the given value.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited