EdgeInsetsDirectionalDelta class abstract
A delta that applies modifications to an EdgeInsetsDirectional.
- Mixed-in types
Constructors
- EdgeInsetsDirectionalDelta.add({double? start, double? top, double? end, double? bottom})
-
Creates an additive modification, adding the specified values to the current edges.
constfactory
- EdgeInsetsDirectionalDelta.delta({double? start, double? top, double? end, double? bottom})
-
Creates a partial modification of directional edges, replacing only the specified edges.
constfactory
- EdgeInsetsDirectionalDelta.scale(double factor)
-
Scales all edges by
factor.constfactory - EdgeInsetsDirectionalDelta.value(EdgeInsetsDirectional insets)
-
Creates a complete replacement for an EdgeInsetsDirectional.
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
covariant EdgeInsetsDirectional? insets) → EdgeInsetsDirectional -
Applies this delta to the given value.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited