errorNotification property
Provides a haptic feedback indicating that a task or action has failed.
Defaults to HapticFeedback.errorNotification.
Implementation
final Future<void> Function() errorNotification;
Provides a haptic feedback indicating that a task or action has failed.
Defaults to HapticFeedback.errorNotification.
final Future<void> Function() errorNotification;