successNotification property
Provides a haptic feedback indicating that a task or action has completed successfully.
Defaults to HapticFeedback.successNotification.
Implementation
final Future<void> Function() successNotification;
Provides a haptic feedback indicating that a task or action has completed successfully.
Defaults to HapticFeedback.successNotification.
final Future<void> Function() successNotification;