FPlatformThemeData class
A pair of FThemeData for desktop and touch platforms.
Constructors
- FPlatformThemeData({required FThemeData desktop(), required FThemeData touch()})
- Creates a FPlatformThemeData.
Properties
- desktop → FThemeData
-
The desktop theme.
latefinal
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- touch → FThemeData
-
The touch theme.
latefinal
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited