FScalableExtension<T extends FScalableExtension<T> > class
abstract
A ThemeExtension that scales with the font size scalar, used for typographical tokens in a FTypography and FTypeface.
- Inheritance
-
- Object
- ThemeExtension<
T> - FScalableExtension
- Implementers
Constructors
- FScalableExtension()
-
Creates a FScalableExtension.
const
Properties
Methods
-
copyWith(
) → FScalableExtension< T> -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(
covariant FScalableExtension< T> ? other, double t) → FScalableExtension<T> -
Linearly interpolate with another ThemeExtension object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
scale(
{double sizeScalar = 1.0}) → FScalableExtension< T> -
Scales this FScalableExtension by
sizeScalar. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited