FSizes class final
Tokens for the various size categories.
These are the canonical heights used by Forui widgets:
- Mixed-in types
Constructors
Properties
- calendar → double
-
The calendar day tile size.
final
- field → ({double lg, double md, double sm, double xs})
-
The field heights at each scale.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- item → double
-
The item height.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tile → double
-
The tile height.
final
Methods
-
copyWith(
{({double lg, double md, double sm, double xs})? field, double? item, double? tile, double? calendar}) → FSizes - Returns a copy of this FSizes with the given properties replaced.
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
override
-
lerp(
FSizes other, double t) → FSizes -
Linearly interpolate between this and
otherusing the given factort. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
scale(
double scalar) → FSizes -
Scales all sizes by the given
scalar. -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override