FTypographyExtension<T extends FTypographyExtension<T> > class
abstract
A ThemeExtension for typography tokens.
- Inheritance
-
- Object
- ThemeExtension<
T> - FTypographyExtension
Constructors
- FTypographyExtension()
-
Creates a FTypographyExtension.
const
Properties
Methods
-
copyWith(
) → FTypographyExtension< T> -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(
covariant FTypographyExtension< T> ? other, double t) → FTypographyExtension<T> -
Linearly interpolate with another ThemeExtension object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
scale(
{double sizeScalar = 1.0}) → FTypographyExtension< T> -
Scales this FTypographyExtension by
sizeScalar. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited