FAccordionStyleDelta class abstract
A delta that applies modifications to a FAccordionStyle.
A FAccordionStyle is itself a FAccordionStyleDelta.
- Mixed-in types
- Implementers
Constructors
- FAccordionStyleDelta.context()
-
Creates a delta that returns the FAccordionStyle in the current context.
constfactory
-
FAccordionStyleDelta.delta({FVariantsDelta<
FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta> ? titleTextStyle, TextStyleDelta? childTextStyle, EdgeInsetsGeometryDelta? titlePadding, EdgeInsetsGeometryDelta? childPadding, FVariantsDelta<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta> ? iconStyle, FFocusedOutlineStyleDelta? focusedOutlineStyle, FDividerStyleDelta? dividerStyle, FTappableStyleDelta? tappableStyle, FAccordionMotionDelta? motion}) -
Creates a partial modification of a FAccordionStyle.
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
covariant FAccordionStyle value) → FAccordionStyle -
Applies this delta to the given value.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited