contentEmptyBuilder property
The builder that is called when the select is empty. Defaults to defaultContentEmptyBuilder.
Pass null to hide the popover entirely when there are no results.
Implementation
final Widget Function(BuildContext context, FAutocompleteContentStyle style)? contentEmptyBuilder;