contentLoadingBuilder property
A callback that is used to show a loading indicator while the results is processed.
Pass null to hide the popover entirely while loading.
Implementation
final Widget Function(BuildContext context, FAutocompleteContentStyle style)? contentLoadingBuilder;