style property
The style delta applied to the style resolved by variant.
The final style is computed by first resolving the base style from FBadgeStyles using variant, then applying this delta. This allows modifying variant-specific styles:
FBadge(
variant: .destructive,
style: .delta(decoration: .delta(borderRadius: .all(.circular(4)))),
child: Text('Custom destructive badge'),
)
CLI
To generate and customize this style:
dart run forui style create badges
Implementation
final FBadgeStyleDelta style;