variant property
The variants used to resolve the style from FBadgeStyles.
Defaults to FBadgeVariant.primary. The current platform variant is automatically included during style resolution. To change the platform variant, update the enclosing FTheme.platform/FAdaptiveScope.platform.
For example, to create a destructive badge:
FBadge(
variant: .destructive,
child: Text('Destructive'),
)
Implementation
final FBadgeVariant variant;