FCalendarController class sealed

A controller for a FCalendar.

DateTimes outside the start and end dates are unselectable.

See:

Inheritance
Implementers

Properties

currentMonth DateTime
The current year and month that the day picker shows.
no setter
disposed bool
True if this notifier has been disposed.
no setterinherited
end DateTime
The end date, inclusive. Defaults to DateTime.utc(2100).
final
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start DateTime
The start date, inclusive. Defaults to DateTime.utc(1900).
final
today DateTime
Today's date. Defaults to DateTime.now.
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

defaultSelectable(DateTime date) bool
The default selectable predicate that always returns true.