FCalendarManagedControl class sealed

A FCalendarManagedControl enables widgets to manage their own controller internally while exposing parameters for common configurations.

Subclass ManagedControl to create variants with different defaults or behaviors, e.g., FDateSelectionControl.date() vs FDateSelectionControl.range().

Inheritance
Implementers

Properties

controller FCalendarController?
The controller.
final
end DateTime?
The end date, inclusive. Defaults to DateTime.utc(2100).
final
hashCode int
The hash code for this object.
no setterinherited
initial DateTime?
The initial month shown. Defaults to today.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectable bool Function(DateTime)?
A predicate that determines if a date can be selected. Defaults to always true.
final
start DateTime?
The start date, inclusive. Defaults to DateTime.utc(1900).
final
today DateTime?
Today's date. Defaults to DateTime.now.
final

Methods

createController() FCalendarController
Creates a FCalendarController.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited