FCalendarManagedControl<T> class abstract

A FCalendarManagedControl enables widgets to manage their own controller internally while exposing parameters for common configurations.

Subclass ManagedControl to create variants with different defaults or behaviors, e.g., FCalendarControl.date() vs FCalendarControl.range().

Inheritance

Constructors

FCalendarManagedControl({FCalendarController<T>? controller, T? initial, Predicate<DateTime>? selectable, bool truncateAndStripTimezone = true, ValueChanged<T>? onChange})
Creates a FCalendarControl.
const

Properties

controller FCalendarController<T>?
The controller.
final
hashCode int
The hash code for this object.
no setterinherited
initial → T?
The initial value. Defaults to null.
final
onChange ValueChanged<T>?
Called when the selected value changes.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectable → Predicate<DateTime>?
A predicate that determines if a date can be selected. Defaults to always true.
final
truncateAndStripTimezone bool
Whether to truncate and convert all DateTimes to dates in UTC timezone. Defaults to true.
final

Methods

createController() FCalendarController<T>
Creates a FCalendarController<T>.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
handleOnChange(FCalendarController<Object?> controller) → void
Calls onChange with the controller's value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited