FCalendarMonthPickerStyle class
A month picker's style.
- Implemented types
- Mixed-in types
- Available extensions
Constructors
- FCalendarMonthPickerStyle({required FCalendarMonthStyles monthStyles, required Size monthSize, double headerSpacing = 6, double monthSpacing = 4})
-
Creates a FCalendarMonthPickerStyle.
const
- FCalendarMonthPickerStyle.inherit({required FColors colors, required FTypography typography, required FStyle style})
-
Creates a FCalendarMonthPickerStyle that inherits its properties.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerSpacing → double
-
The spacing between the header and the month picker. Defaults to 6. Does nothing if there is no header.
final
- monthSize → Size
-
The size of each month. Defaults to a width that aligns the 3-column grid with the day picker's 7-column grid.
final
- monthSpacing → double
-
The vertical spacing between rows of months in the month picker. Defaults to 4.
final
- monthStyles → FCalendarMonthStyles
-
The styles of the month tiles.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
covariant Object _) → FCalendarMonthPickerStyle -
Returns itself.
inherited
-
copyWith(
{double? headerSpacing, FVariantsDelta< FCalendarMonthVariantConstraint, FCalendarMonthVariant, FCalendarMonthStyle, FCalendarMonthStyleDelta> ? monthStyles, Size? monthSize, double? monthSpacing}) → FCalendarMonthPickerStyle -
Available on FCalendarMonthPickerStyle, provided by the $FCalendarMonthPickerStyleTransformations extension
Returns a copy of this FCalendarMonthPickerStyle with the given properties replaced. -
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
lerp(
FCalendarMonthPickerStyle other, double t) → FCalendarMonthPickerStyle -
Available on FCalendarMonthPickerStyle, provided by the $FCalendarMonthPickerStyleTransformations extension
Linearly interpolate between this and another FCalendarMonthPickerStyle using the given factort. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited