FCalendarMonthPickerStyleDelta class abstract
A delta that applies modifications to a FCalendarMonthPickerStyle.
A FCalendarMonthPickerStyle is itself a FCalendarMonthPickerStyleDelta.
- Mixed-in types
- Implementers
Constructors
- FCalendarMonthPickerStyleDelta.context()
-
Creates a delta that returns the FCalendarMonthPickerStyle in the current context.
constfactory
-
FCalendarMonthPickerStyleDelta.delta({double? headerSpacing, FVariantsDelta<
FCalendarMonthVariantConstraint, FCalendarMonthVariant, FCalendarMonthStyle, FCalendarMonthStyleDelta> ? monthStyles, Size? monthSize, double? monthSpacing}) -
Creates a partial modification of a FCalendarMonthPickerStyle.
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
covariant FCalendarMonthPickerStyle value) → FCalendarMonthPickerStyle -
Applies this delta to the given value.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited