FCalendarStyle class

FCalendar's style.

When FAccessibility.motion is:

Implemented types
Mixed-in types
Available extensions

Constructors

FCalendarStyle({required FCalendarHeaderStyle headerStyle, required FCalendarDayPickerStyle dayPickerStyle, required FCalendarMonthPickerStyle monthPickerStyle, required FCalendarYearPickerStyle yearPickerStyle, required FPickerStyle wheelPickerStyle, required Decoration decoration, EdgeInsetsGeometry padding = const .all(12)})
Creates a FCalendarStyle.
FCalendarStyle.inherit({required FColors colors, required FTypography typography, required FIcons icons, required FStyle style, required FHapticFeedback hapticFeedback, required bool touch})
Creates a FCalendarStyle that inherits its properties.
factory

Properties

dayPickerStyle → FCalendarDayPickerStyle
The day picker's style.
final
decoration → Decoration
The decoration surrounding the header & picker.
final
hashCode → int
The hash code for this object.
no setterinherited
headerStyle → FCalendarHeaderStyle
The header's style.
final
monthPickerStyle → FCalendarMonthPickerStyle
The month picker's style.
final
padding → EdgeInsetsGeometry
The padding surrounding the header & picker. Defaults to EdgeInsets.all(12).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wheelPickerStyle → FPickerStyle
The wheel picker's style.
final
yearPickerStyle → FCalendarYearPickerStyle
The year picker's style.
final

Methods

call(covariant Object _) → FCalendarStyle
Returns itself.
inherited
copyWith({FCalendarHeaderStyleDelta? headerStyle, FCalendarDayPickerStyleDelta? dayPickerStyle, FCalendarMonthPickerStyleDelta? monthPickerStyle, FCalendarYearPickerStyleDelta? yearPickerStyle, FPickerStyleDelta? wheelPickerStyle, DecorationDelta? decoration, EdgeInsetsGeometryDelta? padding}) → FCalendarStyle

Available on FCalendarStyle, provided by the $FCalendarStyleTransformations extension

Returns a copy of this FCalendarStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FCalendarStyle other, double t) → FCalendarStyle

Available on FCalendarStyle, provided by the $FCalendarStyleTransformations extension

Linearly interpolate between this and another FCalendarStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited