FCalendarYearPickerController class
Controls a calendar's year picker.
- Inheritance
-
- Object
- FChangeNotifier
- FCalendarYearPickerController
Constructors
- FCalendarYearPickerController({required DateTime start, required DateTime end, required bool selectable(DateTime), required DateTime initial, DateTime? focused})
- Creates a FCalendarYearPickerController.
Properties
- disposed → bool
-
True if this notifier has been disposed.
no setterinherited
- end → DateTime
-
The end date, inclusive.
finalinherited
- focused → DateTime?
-
The currently focused date, or null if nothing is focused.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- hasNext → bool
-
Whether the next page can be displayed.
no setterinherited
- hasPrevious → bool
-
Whether the previous page can be displayed.
no setterinherited
- pages → int
-
The number of pages between
startandend, inclusive.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → DateTime
-
The start date, inclusive.
finalinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
animateTo(
DateTime date, {Duration duration = const Duration(milliseconds: 200), Curve curve = Curves.ease}) → Future< void> -
Animates the current page to the given
date's page.inherited -
dispose(
) → void -
Discards any resources used by the object.
inherited
-
focus(
DateTime? date, {Duration duration = const Duration(milliseconds: 200), Curve curve = Curves.ease}) → Future< void> -
Focuses on
date, animating to its page if necessary. Unfocuses ifdateis null.inherited -
jumpTo(
DateTime date) → void -
Jumps the current page to the given
date's page.inherited -
move(
TraversalDirection direction, TextDirection textDirection, {Duration duration = const Duration(milliseconds: 200), Curve curve = Curves.ease}) → Future< void> -
Moves focus one date horizontally or one row vertically in
direction, honoringtextDirection. Skips unselectable dates and pages across as needed. Does nothing if no selectable date exists in that direction withinstartandend.inherited -
next(
{Duration duration = const Duration(milliseconds: 200), Curve curve = Curves.ease}) → Future< void> -
Animates the current page to the next page. Does nothing if it is the last page.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
previous(
{Duration duration = const Duration(milliseconds: 200), Curve curve = Curves.ease}) → Future< void> -
Animates the current page to the previous page. Does nothing if it is the first page.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited