FCalendarYearPickerStyle class
A year picker's style.
- Implemented types
- Mixed-in types
- Available extensions
Constructors
- FCalendarYearPickerStyle({required FCalendarYearStyles yearStyles, required Size yearSize, double headerSpacing = 6, double yearSpacing = 4})
-
Creates a FCalendarYearPickerStyle.
const
- FCalendarYearPickerStyle.inherit({required FColors colors, required FTypography typography, required FStyle style})
-
Creates a FCalendarYearPickerStyle that inherits its properties.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerSpacing → double
-
The spacing between the header and the year picker. Defaults to 6. Does nothing if there is no header.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- yearSize → Size
-
The size of each year. Defaults to a width that aligns the 3-column grid with the day picker's 7-column grid.
final
- yearSpacing → double
-
The vertical spacing between rows of years in the year picker. Defaults to 4.
final
- yearStyles → FCalendarYearStyles
-
The styles of the year tiles.
final
Methods
-
call(
covariant Object _) → FCalendarYearPickerStyle -
Returns itself.
inherited
-
copyWith(
{double? headerSpacing, FVariantsDelta< FCalendarYearVariantConstraint, FCalendarYearVariant, FCalendarYearStyle, FCalendarYearStyleDelta> ? yearStyles, Size? yearSize, double? yearSpacing}) → FCalendarYearPickerStyle -
Available on FCalendarYearPickerStyle, provided by the $FCalendarYearPickerStyleTransformations extension
Returns a copy of this FCalendarYearPickerStyle with the given properties replaced. -
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
lerp(
FCalendarYearPickerStyle other, double t) → FCalendarYearPickerStyle -
Available on FCalendarYearPickerStyle, provided by the $FCalendarYearPickerStyleTransformations extension
Linearly interpolate between this and another FCalendarYearPickerStyle using the given factort. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited