FCalendarYearPickerStyleDelta class abstract
A delta that applies modifications to a FCalendarYearPickerStyle.
A FCalendarYearPickerStyle is itself a FCalendarYearPickerStyleDelta.
- Mixed-in types
- Implementers
Constructors
- FCalendarYearPickerStyleDelta.context()
-
Creates a delta that returns the FCalendarYearPickerStyle in the current context.
constfactory
-
FCalendarYearPickerStyleDelta.delta({double? headerSpacing, FVariantsDelta<
FCalendarYearVariantConstraint, FCalendarYearVariant, FCalendarYearStyle, FCalendarYearStyleDelta> ? yearStyles, Size? yearSize, double? yearSpacing}) -
Creates a partial modification of a FCalendarYearPickerStyle.
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
covariant FCalendarYearPickerStyle value) → FCalendarYearPickerStyle -
Applies this delta to the given value.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited