liftedOpenRange static method
Creates a lifted FDateSelectionControl for range selection with an open bound.
Both the start and end dates of the range are inclusive. Unlike liftedRange, selecting the first date returns
an open-bound range, (first date, null)/(null, first date), depending on startFirst.
The value is the currently selected range.
onChange is called with the new selection when a date is selected.
startFirst determines whether the first selected date is the range's start or end. Defaults to true.
Implementation
static FDateSelectionControl<(DateTime?, DateTime?)> liftedOpenRange({
required (DateTime?, DateTime?) value,
required ValueChanged<(DateTime?, DateTime?)> onChange,
bool startFirst = true,
}) => _LiftedOpenRange(value: value, onChange: onChange, startFirst: startFirst);