liftedRange static method

FDateSelectionControl<(DateTime, DateTime)?> liftedRange({
  1. required (DateTime, DateTime)? value,
  2. required ValueChanged<(DateTime, DateTime)?> onChange,
})

Creates a lifted FDateSelectionControl for range selection.

The value is the currently selected range. onChange is called with the new selection when a date is selected. Both the start and end dates of the range are inclusive.

Implementation

static FDateSelectionControl<(DateTime, DateTime)?> liftedRange({
  required (DateTime, DateTime)? value,
  required ValueChanged<(DateTime, DateTime)?> onChange,
}) => _LiftedRange(value: value, onChange: onChange);