liftedSingle static method
FDateSelectionControl<DateTime?>
liftedSingle({
- required DateTime? value,
- required ValueChanged<
DateTime?> onChange, - bool toggleable = true,
Creates a lifted FDateSelectionControl for single date selection.
The value is the currently selected date.
onChange is called with the new selection when a date is selected.
toggleable determines whether selecting the selected date unselects it. Defaults to true.
Implementation
static FDateSelectionControl<DateTime?> liftedSingle({
required DateTime? value,
required ValueChanged<DateTime?> onChange,
bool toggleable = true,
}) => _LiftedSingle(value: value, onChange: onChange, toggleable: toggleable);