managedOpenRange static method
FDateSelectionControl<(DateTime?, DateTime?)>
managedOpenRange({
- FDateSelectionController<
(DateTime?, DateTime?)> ? controller, - (DateTime?, DateTime?)? initial,
- ValueChanged<
(DateTime?, DateTime?)> ? onChange, - bool startFirst = true,
Creates a FDateSelectionControl for range selection with an open bound.
Both the start and end dates of the range are inclusive. Unlike managedRange, selecting the first date returns
an open-bound range, (first date, null)/(null, first date), depending on startFirst.
startFirst determines whether the first selected date is the range's start or end. Defaults to true.
Contract
Throws AssertionError if controller is provided and startFirst is false.
Throws AssertionError if both of initial's bounds are given and the end date is less than the start date.
Implementation
static FDateSelectionControl<(DateTime?, DateTime?)> managedOpenRange({
FDateSelectionController<(DateTime?, DateTime?)>? controller,
(DateTime?, DateTime?)? initial,
ValueChanged<(DateTime?, DateTime?)>? onChange,
bool startFirst = true,
}) => _OpenRange(controller: controller, initial: initial, onChange: onChange, startFirst: startFirst);