openRange static method
Creates a FDateSelectionController that allows a range with an open bound to be selected, with the given initial range.
Both the start and end dates of the range are inclusive. Unlike range, selecting the first date returns an
open-bound range, (first date, null)/(null, first date), depending on startFirst.
startFirst determines whether the first selected date is the range's start or end. Defaults to true.
Contract
Throws AssertionError if both bounds are given and the end date is less than start date.
See:
- range for an always complete range selection.
Implementation
static FDateSelectionController<(DateTime?, DateTime?)> openRange({
(DateTime?, DateTime?) initial = (null, null),
bool startFirst = true,
}) => _OpenRangeController(initial: initial, startFirst: startFirst);