range static method
Creates a FDateSelectionController that allows a single range to be selected, with the given initial range.
Both the start and end dates of the range are inclusive. Unlike openRange, selecting the first date returns a
complete range, (first date, first date).
Contract
Throws AssertionError if the end date is less than start date.
See:
- openRange for partial range selection.
Implementation
static FDateSelectionController<(DateTime, DateTime)?> range({(DateTime, DateTime)? initial}) =>
_RangeController(initial: initial);