range static method

Creates a FDateSelectionController that allows a single range to be selected, with the given initial range.

Both the start and end dates of the range are inclusive.

Contract

Throws AssertionError if the end date is less than start date.

Implementation

static FDateSelectionController<(DateTime, DateTime)?> range({(DateTime, DateTime)? initial}) =>
    _RangeController(initial: initial);