single static method
Creates a FDateSelectionController that allows only a single date to be selected, with the given initially selected date.
toggleable determines whether the controller should unselect a date if it is already selected. Defaults to true.
Implementation
static FDateSelectionController<DateTime?> single({DateTime? initial, bool toggleable = true}) =>
_SingleController(initial: initial, toggleable: toggleable);