FWheelCalendarController class

A controller for a FCalendar that toggles between a day grid picker and a month-year wheel picker.

Inheritance

Constructors

FWheelCalendarController({bool selectable(DateTime date) = defaultSelectable, DateTime? start, DateTime? today, DateTime? initial, DateTime? end})
Creates a FWheelCalendarController.

Properties

currentMonth → DateTime
The current year and month that the day picker shows.
no setterinherited
day ↔ FCalendarDayPickerController
The day picker controller.
latefinal
disposed → bool
True if this notifier has been disposed.
no setterinherited
end → DateTime
The end date, inclusive. Defaults to DateTime.utc(2100).
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
monthYear → bool
Whether the month-year wheel picker is currently shown.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → DateTime
The start date, inclusive. Defaults to DateTime.utc(1900).
finalinherited
today → DateTime
Today's date. Defaults to DateTime.now.
finalinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
animateToDayPicker([DateTime? date, Duration duration = const Duration(milliseconds: 200), Curve curve = Curves.ease]) → Future<void>
Shows the day grid on the given date's month, or the current month if date is null.
dispose() → void
Discards any resources used by the object.
override
jumpToDayPicker([DateTime? date]) → void
Shows the day grid on the given date's month, or the current month if date is null.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setMonthYear(int month, int year) → void
Sets the month-year wheel picker's selected month and year, and updates currentMonth. Does nothing if the month-year wheel picker.
toggleMonthYearPicker() → void
Shows the month-year wheel if the day grid is shown, and the day grid otherwise.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited