widgets/date_field library
A date field allows a date to be selected from a calendar or input field.
See https://forui.dev/docs/widgets/form/date-field for working examples.
Classes
- FDateField
- A date field allows a date to be selected from a calendar, input field, or both.
- FDateFieldCalendarProperties
- A date field calendar popover's properties.
- FDateFieldGridCalendarProperties
- A date field calendar that cycles through the day, month and year grid pickers. Mirrors FCalendar.grid.
- FDateFieldGridSplitCalendarProperties
- A date field calendar with a split header whose month and year grid pickers are independently togglable. Mirrors FCalendar.splitGrid.
- FDateFieldStyle
- A date field's style.
- FDateFieldStyleDelta
- A delta that applies modifications to a FDateFieldStyle.
- FDateFieldWheelCalendarProperties
- A date field calendar that toggles between a day grid picker and a month-year wheel picker. Mirrors FCalendar.wheel.
Extensions
- $FDateFieldStyleTransformations on FDateFieldStyle
- Provides copyWith and lerp methods.
Typedefs
- FDateFieldPopoverBuilder = Widget Function(BuildContext context, FCalendarController calendarController, FPopoverController popoverController, Widget content)
- A builder that wraps FDateField's popover content.