FDateFieldCalendarProperties class sealed

A date field calendar popover's properties.

The calendar mode is chosen by the subclass:

Mixed-in types
Implementers

Properties

anchor → AlignmentGeometry
The alignment point on the calendar popover. Defaults to Alignment.topLeft.
final
autoHide → bool
True if the calendar popover should be automatically hidden after a date is selected. Defaults to true.
final
control → FCalendarControl
The control for the calendar's navigation.
no setter
cutout → bool
Whether the barrier should exclude the builder/child's area using a non-interactive cutout.
final
cutoutBuilder → void Function(Path path, Rect bounds)
An optional callback that customizes the cutout shape.
final
fieldAnchor → AlignmentGeometry
The alignment point on the field. Defaults to Alignment.bottomLeft.
final
fixedWeeks → bool
Whether the day grid always shows 6 week-rows instead of adapting its height to the month's 4-6 weeks. Defaults to false.
final
groupId → Object?
An optional group ID that groups TapRegions together so that they operate as one region. If a tap occurs outside of all group members, then group members that are shown will be hidden.
final
hashCode → int
The hash code for this object.
no setteroverride
hideRegion → FPopoverHideRegion
The region that can be tapped to hide the popover.
final
offset → Offset
Additional translation to apply to the popover's position.
final
onTapHide → VoidCallback?
A callback that is called when the popover is hidden by tapping outside of it.
final
overflow → FPortalOverflow
The callback used to shift a popover when it overflows out of the viewport.
final
overlayLocation → OverlayChildLocation
The Overlay that the portal is attached to.
final
popoverBuilder → FDateFieldPopoverBuilder
The builder used to wrap the calendar popover content.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spacing → FPortalSpacing
The spacing between the popover and child anchors.
final
useViewInsets → bool
Whether to avoid the platform view's insets (the soft keyboard).
final
useViewPadding → bool
Whether to avoid the platform view's padding (static safe areas like the notch and status bar).
final

Methods

debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override