rawAnimateTo method
Unconditionally animates the controller to the given value.
Implementation
@protected
Future<void> rawAnimateTo(T value, Duration duration, Curve curve) async {
try {
mutating = true;
await picker?.animateTo(encode(value), duration: duration, curve: curve);
// The value does not need to be explicitly set as the picker will update it via a listener.
} finally {
mutating = false;
}
}