FItemGroupStyle class

An FItemGroup's style.

Implemented types
Mixed-in types
Available extensions

Constructors

FItemGroupStyle({required Decoration decoration, required FVariants<FItemGroupVariantConstraint, FItemGroupVariant, Color, Delta> dividerColor, required double dividerWidth, required FVariants<FItemVariantConstraint, FItemVariant, FItemStyle, FItemStyleDelta> itemStyles, FVariants<FItemGroupVariantConstraint, FItemGroupVariant, bool, Delta> slideableItems = const .all(true), double spacing = 4})
Creates a FItemGroupStyle.
FItemGroupStyle.inherit({required FColors colors, required FTypography typography, required FStyle style, required bool touch})
Creates a FItemGroupStyle that inherits from the given arguments.

Properties

decoration Decoration
The group's decoration.
final
dividerColor FVariants<FItemGroupVariantConstraint, FItemGroupVariant, Color, Delta>
The divider's style.
final
dividerWidth double
The divider's width.
final
hashCode int
The hash code for this object.
no setterinherited
itemStyles FVariants<FItemVariantConstraint, FItemVariant, FItemStyle, FItemStyleDelta>
The item's styles.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slideableItems FVariants<FItemGroupVariantConstraint, FItemGroupVariant, bool, Delta>
Whether the items support pressing an item and sliding to another. Defaults to true.
final
spacing double
The vertical spacing at the top and bottom of each group. Defaults to 4.
final

Methods

call(covariant Object _) FItemGroupStyle
Returns itself.
inherited
copyWith({DecorationDelta? decoration, double? spacing, FVariantsValueDelta<FItemGroupVariantConstraint, FItemGroupVariant, Color, Delta>? dividerColor, double? dividerWidth, FVariantsDelta<FItemVariantConstraint, FItemVariant, FItemStyle, FItemStyleDelta>? itemStyles, FVariantsValueDelta<FItemGroupVariantConstraint, FItemGroupVariant, bool, Delta>? slideableItems}) FItemGroupStyle

Available on FItemGroupStyle, provided by the $FItemGroupStyleTransformations extension

Returns a copy of this FItemGroupStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FItemGroupStyle other, double t) FItemGroupStyle

Available on FItemGroupStyle, provided by the $FItemGroupStyleTransformations extension

Linearly interpolate between this and another FItemGroupStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited