FItemStyle class

A FItem's style.

┌─ shape ──────────────────────────────┐
│  backgroundColor     ↕ padding       │
│  ┌─ contentDecoration ─────────────┐ │
│  │  content                        │ │
│  └─────────────────────────────────┘ │
└──────────────────────────────────────┘
Implemented types
Mixed-in types
Implementers
Available extensions

Constructors

FItemStyle({required FVariants<FTappableVariantConstraint, FTappableVariant, Color?, Delta> backgroundColor, required FVariants<FTappableVariantConstraint, FTappableVariant, Decoration, DecorationDelta> contentDecoration, required FItemContentStyle contentStyle, required FRawItemContentStyle rawContentStyle, required FTappableStyle tappableStyle, required FFocusedOutlineStyle? focusedOutlineStyle, EdgeInsetsGeometry padding = const .symmetric(horizontal: 4), ShapeBorder? shape})
Creates a FItemStyle.
FItemStyle.inherit({required FColors colors, required FTypography typography, required FStyle style, required bool touch})
Creates a FItemStyle that inherits from the given arguments.

Properties

backgroundColor → FVariants<FTappableVariantConstraint, FTappableVariant, Color?, Delta>
The item's background color, enclosing the padding and content, and below contentDecoration.
final
contentDecoration → FVariants<FTappableVariantConstraint, FTappableVariant, Decoration, DecorationDelta>
The content's decoration, enclosed within padding and shape, and above backgroundColor.
final
contentStyle → FItemContentStyle
The content's style.
final
focusedOutlineStyle → FFocusedOutlineStyle?
The focused outline style.
final
hashCode → int
The hash code for this object.
no setterinherited
padding → EdgeInsetsGeometry
The padding around the contentDecoration. Defaults to EdgeInsets.symmetric(horizontal: 4).
final
rawContentStyle → FRawItemContentStyle
The raw content's style.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → ShapeBorder?
The item's shape, only applied when outside an FItemGroup or other similar groups.
final
tappableStyle → FTappableStyle
The tappable style.
final

Methods

call(covariant Object _) → FItemStyle
Returns itself.
inherited
copyWith({FVariantsValueDelta<FTappableVariantConstraint, FTappableVariant, Color?, Delta>? backgroundColor, FVariantsDelta<FTappableVariantConstraint, FTappableVariant, Decoration, DecorationDelta>? contentDecoration, FItemContentStyleDelta? contentStyle, FRawItemContentStyleDelta? rawContentStyle, FTappableStyleDelta? tappableStyle, FFocusedOutlineStyle? focusedOutlineStyle = Sentinels.focusedOutlineStyle, EdgeInsetsGeometryDelta? padding, ShapeBorder? shape = Sentinels.shapeBorder}) → FItemStyle

Available on FItemStyle, provided by the $FItemStyleTransformations extension

Returns a copy of this FItemStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FItemStyle other, double t) → FItemStyle

Available on FItemStyle, provided by the $FItemStyleTransformations extension

Linearly interpolate between this and another FItemStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited