FItemStyle class

A FItem's style.

Implemented types
Mixed-in types
Implementers
Available extensions

Constructors

FItemStyle({required FVariants<FTappableVariantConstraint, FTappableVariant, Color?, Delta> backgroundColor, required FVariants<FTappableVariantConstraint, FTappableVariant, Decoration, DecorationDelta> decoration, required FItemContentStyle contentStyle, required FRawItemContentStyle rawItemContentStyle, required FTappableStyle tappableStyle, required FFocusedOutlineStyle? focusedOutlineStyle, required EdgeInsetsGeometry margin, ShapeBorder? shape})
Creates a FItemStyle.
FItemStyle.inherit({required FColors colors, required FTypography typography, required FStyle style, required bool touch})
Creates a FTileGroupStyle that inherits from the given arguments.
factory

Properties

backgroundColor FVariants<FTappableVariantConstraint, FTappableVariant, Color?, Delta>
The item's background color.
final
contentStyle FItemContentStyle
The default item content's style.
final
decoration FVariants<FTappableVariantConstraint, FTappableVariant, Decoration, DecorationDelta>
The item's decoration.
final
focusedOutlineStyle FFocusedOutlineStyle?
The focused outline style.
final
hashCode int
The hash code for this object.
no setterinherited
margin EdgeInsetsGeometry
The margin around the item, including the decoration.
final
rawItemContentStyle FRawItemContentStyle
THe default raw item content's style.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shape ShapeBorder?
The item's outer shape when outside of an FItemGroup or other similar groups.
final
tappableStyle FTappableStyle
The tappable style.
final

Methods

call(covariant Object _) FItemStyle
Returns itself.
inherited
copyWith({ShapeBorder? shape = Sentinels.shapeBorder, FVariantsValueDelta<FTappableVariantConstraint, FTappableVariant, Color?, Delta>? backgroundColor, EdgeInsetsGeometryDelta? margin, FVariantsDelta<FTappableVariantConstraint, FTappableVariant, Decoration, DecorationDelta>? decoration, FItemContentStyleDelta? contentStyle, FRawItemContentStyleDelta? rawItemContentStyle, FTappableStyleDelta? tappableStyle, FFocusedOutlineStyle? focusedOutlineStyle = Sentinels.focusedOutlineStyle}) FItemStyle

Available on FItemStyle, provided by the $FItemStyleTransformations extension

Returns a copy of this FItemStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FItemStyle other, double t) FItemStyle

Available on FItemStyle, provided by the $FItemStyleTransformations extension

Linearly interpolate between this and another FItemStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

The padding and margin for the item when used in a menu.
selectInsets({required bool touch}) → ({EdgeInsetsGeometry margin, EdgeInsetsGeometry suffixedPadding, EdgeInsetsGeometry unsuffixedPadding})
The padding and margin for the item when used in a autocomplete/select.