backgroundColor property
The item's background color, enclosing the padding and content, and below contentDecoration.
┌─ shape ──────────────────────────────┐
│ backgroundColor ↕ padding │
│ ┌─ contentDecoration ─────────────┐ │
│ │ content │ │
│ └─────────────────────────────────┘ │
└──────────────────────────────────────┘
As it is below contentDecoration, setting a decoration color will paint over the backgroundColor.
Implementation
@override
final FVariants<FTappableVariantConstraint, FTappableVariant, Color?, Delta> backgroundColor;