contentDecoration property
FVariants<FTappableVariantConstraint, FTappableVariant, Decoration, DecorationDelta>
contentDecoration
final
The content's decoration, enclosed within padding and shape, and above backgroundColor.
┌─ shape ──────────────────────────────┐
│ backgroundColor ↕ padding │
│ ┌─ contentDecoration ─────────────┐ │
│ │ content │ │
│ └─────────────────────────────────┘ │
└──────────────────────────────────────┘
The content's background color will default to backgroundColor if the decoration does not have a color.
Implementation
@override
final FVariants<FTappableVariantConstraint, FTappableVariant, Decoration, DecorationDelta> contentDecoration;