FLabelLayout enum
Values
- horizontalLeading → const FLabelLayout
-
The label/description/error is on the left, child on the right, assuming LTR text direction.
|--------------------------| | [label] [child] | | [description] | | [error] | |--------------------------| - horizontalTrailing → const FLabelLayout
-
The child is on the left, label/description/error on the right, assuming LTR text direction.
Used by default in FCheckbox, FRadio, FSwitch.
|--------------------------| | [child] [label] | | [description] | | [error] | |--------------------------| - vertical → const FLabelLayout
-
The label is above the child, description/error below.
Used in FTextField.
|-----------------| | [label] | | [child] | | [description] | | [error] | |-----------------|
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
FLabelLayout> - A constant List of the values in this enum, in order of their declaration.