FLineCalendarScrollController class
A ScrollController that scrolls an FLineCalendar to a DateTime.
Use jumpToDate and animateToDate to programmatically scroll the calendar. The controller must be attached to an FLineCalendar via FLineCalendarScrollControl.managed before either method is called.
- Inheritance
-
- Object
- ChangeNotifier
- ScrollController
- FLineCalendarScrollController
Constructors
- FLineCalendarScrollController({AlignmentDirectional initialAlignment = .center, DateTime? start, DateTime? end, DateTime? today, DateTime? initialDate, bool keepScrollOffset = true, String? debugLabel})
- Creates a FLineCalendarScrollController.
Properties
- debugLabel → String?
-
A label that is used in the toString output. Intended to aid with
identifying scroll controller instances in debug output.
finalinherited
- end → DateTime?
-
The end date, exclusive. It is always in UTC and truncated to the nearest date. Defaults to null.
final
- hasClients → bool
-
Whether any ScrollPosition objects have attached themselves to the
ScrollController using the attach method.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- initialAlignment → AlignmentDirectional
-
The alignment to which the initially scrolled date will be aligned. Defaults to Alignment.center.
final
- initialDate ↔ DateTime
-
The initial date to which the calendar will be scrolled. It is always in UTC. Defaults to today.
latefinal
- initialScrollOffset → double
-
The initial value to use for offset.
no setteroverride
- keepScrollOffset → bool
-
Each time a scroll completes, save the current scroll offset with
PageStorage and restore it if this controller's scrollable is recreated.
finalinherited
- offset → double
-
The current scroll offset of the scrollable widget.
no setterinherited
- onAttach → ScrollControllerCallback?
-
Called when a ScrollPosition is attached to the scroll controller.
finalinherited
- onDetach → ScrollControllerCallback?
-
Called when a ScrollPosition is detached from the scroll controller.
finalinherited
- position → ScrollPosition
-
Returns the attached ScrollPosition, from which the actual scroll offset
of the ScrollView can be obtained.
no setterinherited
-
positions
→ Iterable<
ScrollPosition> -
The currently attached positions.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → DateTime
-
The start date, inclusive. It is always in UTC and truncated to the nearest date. Defaults to
DateTime.utc(1900).final - today → DateTime
-
The current date. It is always in UTC and truncated to the nearest date. Defaults to DateTime.now.
final
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
animateTo(
double offset, {required Duration duration, required Curve curve}) → Future< void> -
Animates the position from its current value to the given value.
inherited
-
animateToDate(
DateTime date, {Duration duration = const Duration(milliseconds: 300), Curve curve = Curves.easeOutCubic, AlignmentDirectional alignment = .center}) → Future< void> -
Animates to
date. -
attach(
ScrollPosition position) → void -
Register the given position with this controller.
inherited
-
createScrollPosition(
ScrollPhysics physics, ScrollContext context, ScrollPosition? oldPosition) → ScrollPosition -
Creates a ScrollPosition for use by a Scrollable widget.
inherited
-
debugFillDescription(
List< String> description) → void -
Add additional information to the given description for use by toString.
inherited
-
detach(
ScrollPosition position) → void -
Unregister the given position with this controller.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
jumpTo(
double value) → void -
Jumps the scroll position from its current value to the given value,
without animation, and without checking if the new value is in range.
inherited
-
jumpToDate(
DateTime date, {AlignmentDirectional alignment = .center}) → void -
Jumps to
datewithout animation. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited