FLineCalendarScrollManagedControl class
A FLineCalendarScrollManagedControl enables widgets to manage their own controller internally while exposing parameters for common configurations.
Subclass ManagedControl to create variants with different defaults or behaviors, e.g., FCalendarControl.date()
vs FCalendarControl.range().
- Inheritance
-
- Object
- FLineCalendarScrollControl
- FLineCalendarScrollManagedControl
Constructors
-
FLineCalendarScrollManagedControl({FLineCalendarScrollController? controller, DateTime? start, DateTime? end, DateTime? today, DateTime? initialDate, AlignmentDirectional? initialAlignment, ValueChanged<
double> ? onChange}) -
Creates a FLineCalendarScrollManagedControl.
const
Properties
- controller → FLineCalendarScrollController?
-
The controller.
final
- end → DateTime?
-
The end date, exclusive. It is truncated to the nearest date. Defaults to null.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialAlignment → AlignmentDirectional?
-
The alignment to which the initially scrolled date will be aligned. Defaults to Alignment.center.
final
- initialDate → DateTime?
-
The initial date to which the calendar will be scrolled. Defaults to
today.final -
onChange
→ ValueChanged<
double> ? -
Called when the scroll offset changes.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → DateTime?
-
The start date, inclusive. It is truncated to the nearest date. Defaults to the
DateTime.utc(1900).final - today → DateTime?
-
The current date. It is truncated to the nearest date. Defaults to the DateTime.now.
final
Methods
-
createController(
) → FLineCalendarScrollController - Creates a FLineCalendarScrollController.
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited