FOtpFieldItemVariant extension type
Represents a variant.
Each variant has a tier that determines its specificity. Higher tiers take precedence during resolution.
See also:
- FOtpFieldItemVariantConstraint, which represents combinations of variants.
- on
- Implemented types
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
and(
FOtpFieldItemVariantConstraint other) → FOtpFieldItemVariantConstraint -
Combines this with
otherusing a logical AND operation.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
satisfiedBy(
Set< FVariant> variants) → bool -
Returns true if all variants in this constraint are present in
variants.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- android → const FOtpFieldItemVariant
- The Android platform variant.
- disabled → const FOtpFieldItemVariant
- The semantic variant when this widget is disabled and cannot be interacted with.
- end → const FOtpFieldItemVariant
- The variant for the last item in a group (e.g. the last item or the last item before a divider).
- error → const FOtpFieldItemVariant
- The semantic variant when this widget is in an error state.
- focused → const FOtpFieldItemVariant
- The interaction variant when the given widget or any of its descendants have focus.
- fuchsia → const FOtpFieldItemVariant
- The Fuchsia platform variant.
- hovered → const FOtpFieldItemVariant
- The interaction variant when the user drags their mouse cursor over the given widget.
- iOS → const FOtpFieldItemVariant
- The iOS platform variant.
- linux → const FOtpFieldItemVariant
- The Linux platform variant.
- macOS → const FOtpFieldItemVariant
- The macOS platform variant.
- pressed → const FOtpFieldItemVariant
- The interaction variant when the user is actively pressing down on the given widget.
- start → const FOtpFieldItemVariant
- The variant for the first item in a group (e.g. the first item or the first item after a divider).
- web → const FOtpFieldItemVariant
- The web platform variant.
- windows → const FOtpFieldItemVariant
- The Windows platform variant.