start constant
FOtpFieldItemVariant
const start
The variant for the first item in a group (e.g. the first item or the first item after a divider).
Implementation
static const start = FOtpFieldItemVariant._(.new(1, 'start'));