FOtpFieldStyle class
The FOtpField's style.
- Inheritance
-
- Object
- FFormFieldStyle
- FLabelStyle
- FOtpFieldStyle
- Implemented types
- Available extensions
Constructors
-
FOtpFieldStyle({required Brightness keyboardAppearance, required Size itemSize, required FOtpFieldItemStyles itemStyles, required FVariants<
FOtpFieldItemVariantConstraint, FOtpFieldItemVariant, Color, Delta> dividerColor, required FVariants<FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta> labelTextStyle, required FVariants<FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta> descriptionTextStyle, required FVariants<FFormFieldErrorVariantConstraint, FFormFieldErrorVariant, TextStyle, TextStyleDelta> errorTextStyle, Color cursorColor = CupertinoColors.activeBlue, double cursorWidth = 2.0, bool? cursorOpacityAnimates, EdgeInsetsGeometry dividerPadding = const .symmetric(horizontal: 8), Size dividerSize = const Size(12, 1), EdgeInsetsGeometry labelPadding = const .only(bottom: 6), EdgeInsetsGeometry descriptionPadding = const .only(top: 6), EdgeInsetsGeometry errorPadding = const .only(top: 6), EdgeInsetsGeometry childPadding = .zero, FLabelMotion labelMotion = const FLabelMotion()}) - Creates a FOtpFieldStyle.
- FOtpFieldStyle.inherit({required FColors colors, required FTypography typography, required FStyle style, required bool touch})
- Creates a FOtpFieldStyle that inherits its properties.
Properties
- childPadding → EdgeInsetsGeometry
-
no setterinherited
- cursorColor → Color
-
The color of the cursor. Defaults to CupertinoColors.activeBlue.
final
- cursorOpacityAnimates → bool?
-
Whether the cursor opacity animates. Defaults to the current platform's behavior (true on iOS and macOS, false on
other platforms).
final
- cursorWidth → double
-
The width of the cursor. Defaults to 2.0.
final
- descriptionPadding → EdgeInsetsGeometry
-
no setterinherited
-
descriptionTextStyle
→ FVariants<
FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta> -
no setterinherited
-
dividerColor
→ FVariants<
FOtpFieldItemVariantConstraint, FOtpFieldItemVariant, Color, Delta> -
The divider's color.
final
- dividerPadding → EdgeInsetsGeometry
-
The divider's padding. Defaults to
EdgeInsets.symmetric(horizontal: 8).final - dividerSize → Size
-
The divider's size. Defaults to
Size(12, 1).final - errorPadding → EdgeInsetsGeometry
-
no setterinherited
-
errorTextStyle
→ FVariants<
FFormFieldErrorVariantConstraint, FFormFieldErrorVariant, TextStyle, TextStyleDelta> -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemSize → Size
-
The item size.
final
- itemStyles → FOtpFieldItemStyles
-
The item styles per variant.
final
- keyboardAppearance → Brightness
-
The appearance of the keyboard. Defaults to FColors.brightness.
final
- labelMotion → FLabelMotion
-
no setterinherited
- labelPadding → EdgeInsetsGeometry
-
no setterinherited
-
labelTextStyle
→ FVariants<
FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta> -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
covariant Object _) → FOtpFieldStyle -
Returns itself.
inherited
-
copyWith(
{FVariantsDelta< FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta> ? labelTextStyle, FVariantsDelta<FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta> ? descriptionTextStyle, FVariantsDelta<FFormFieldErrorVariantConstraint, FFormFieldErrorVariant, TextStyle, TextStyleDelta> ? errorTextStyle}) → FFormFieldStyle -
Available on FFormFieldStyle, provided by the $FFormFieldStyleTransformations extension
Returns a copy of this FFormFieldStyle with the given properties replaced. -
copyWith(
{EdgeInsetsGeometryDelta? labelPadding, EdgeInsetsGeometryDelta? descriptionPadding, EdgeInsetsGeometryDelta? errorPadding, EdgeInsetsGeometryDelta? childPadding, FLabelMotionDelta? labelMotion, FVariantsDelta< FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta> ? labelTextStyle, FVariantsDelta<FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta> ? descriptionTextStyle, FVariantsDelta<FFormFieldErrorVariantConstraint, FFormFieldErrorVariant, TextStyle, TextStyleDelta> ? errorTextStyle}) → FLabelStyle -
Available on FLabelStyle, provided by the $FLabelStyleTransformations extension
Returns a copy of this FLabelStyle with the given properties replaced. -
copyWith(
{Brightness? keyboardAppearance, Color? cursorColor, double? cursorWidth, bool? cursorOpacityAnimates()?, Size? itemSize, FVariantsDelta< FOtpFieldItemVariantConstraint, FOtpFieldItemVariant, FOtpFieldItemStyle, FOtpFieldItemStyleDelta> ? itemStyles, EdgeInsetsGeometryDelta? dividerPadding, Size? dividerSize, FVariantsValueDelta<FOtpFieldItemVariantConstraint, FOtpFieldItemVariant, Color, Delta> ? dividerColor, EdgeInsetsGeometryDelta? labelPadding, EdgeInsetsGeometryDelta? descriptionPadding, EdgeInsetsGeometryDelta? errorPadding, EdgeInsetsGeometryDelta? childPadding, FLabelMotionDelta? labelMotion, FVariantsDelta<FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta> ? labelTextStyle, FVariantsDelta<FFormFieldVariantConstraint, FFormFieldVariant, TextStyle, TextStyleDelta> ? descriptionTextStyle, FVariantsDelta<FFormFieldErrorVariantConstraint, FFormFieldErrorVariant, TextStyle, TextStyleDelta> ? errorTextStyle}) → FOtpFieldStyle -
Available on FOtpFieldStyle, provided by the $FOtpFieldStyleTransformations extension
Returns a copy of this FOtpFieldStyle with the given properties replaced. -
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
lerp(
FFormFieldStyle other, double t) → FFormFieldStyle -
Available on FFormFieldStyle, provided by the $FFormFieldStyleTransformations extension
Linearly interpolate between this and another FFormFieldStyle using the given factort. -
lerp(
FLabelStyle other, double t) → FLabelStyle -
Available on FLabelStyle, provided by the $FLabelStyleTransformations extension
Linearly interpolate between this and another FLabelStyle using the given factort. -
lerp(
FOtpFieldStyle other, double t) → FOtpFieldStyle -
Available on FOtpFieldStyle, provided by the $FOtpFieldStyleTransformations extension
Linearly interpolate between this and another FOtpFieldStyle using the given factort. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited