showEdges property
bool
get
showEdges
Whether to show the first and last pages in the pagination. Defaults to true.
If true, the pagination will always display the first and last page, regardless of the current page.
This can be useful for allowing users to quickly navigate to the beginning or end of the paginated content.
Implementation
bool get showEdges => _showEdges;
set
showEdges
(bool showEdges)
Implementation
set showEdges(bool showEdges) {
if (_showEdges == showEdges) {
return;
}
_showEdges = showEdges;
notifyListeners();
}