FPaginationManagedControl class
A FPaginationManagedControl enables widgets to manage their own controller internally while exposing parameters for common configurations.
Subclass ManagedControl to create variants with different defaults or behaviors, e.g., FCalendarControl.date()
vs FCalendarControl.range().
- Inheritance
-
- Object
- FPaginationControl
- FPaginationManagedControl
- Mixed-in types
Constructors
-
FPaginationManagedControl({FPaginationController? controller, int? initial, int? pages, int? siblings, bool? showEdges, ValueChanged<
int> ? onChange}) -
Creates a FPaginationControl.
const
Properties
- controller → FPaginationController?
-
The controller.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initial → int?
-
The initial page index. Defaults to 0.
final
-
onChange
→ ValueChanged<
int> ? -
Called when the page changes.
final
- pages → int?
-
The total number of pages. Defaults to 1.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showEdges → bool?
-
Whether to show first/last page buttons. Defaults to true.
final
- siblings → int?
-
The number of sibling pages to show. Defaults to 1.
final
Methods
-
createController(
) → FPaginationController - Creates a FPaginationController.
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited