copyWith method
- @useResult
- BoxDecorationDelta? decoration,
- ImageFilter barrierFilter()? = imageFilterFunctionSentinel,
- ImageFilter backgroundFilter()? = imageFilterFunctionSentinel,
- EdgeInsetsGeometryDelta? viewInsets,
Returns a copy of this FPopoverStyle with the given properties replaced.
See customizing widget styles.
Parameters
- FPopoverStyle.decoration - The popover's decoration.
- FPopoverStyle.barrierFilter - An optional callback that takes the current animation transition value (0.0 to 1.0) and returns an ImageFilter that is used as the barrier.
- FPopoverStyle.backgroundFilter - An optional callback that takes the current animation transition value (0.0 to 1.0) and returns an ImageFilter that is used as the background.
- FPopoverStyle.viewInsets - The additional insets of the view.
Implementation
@useResult
FPopoverStyle copyWith({
BoxDecorationDelta? decoration,
ImageFilter Function(double)? barrierFilter = imageFilterFunctionSentinel,
ImageFilter Function(double)? backgroundFilter = imageFilterFunctionSentinel,
EdgeInsetsGeometryDelta? viewInsets,
}) => .new(
decoration: decoration?.call(this.decoration) ?? this.decoration,
barrierFilter: barrierFilter == imageFilterFunctionSentinel ? this.barrierFilter : barrierFilter,
backgroundFilter: backgroundFilter == imageFilterFunctionSentinel ? this.backgroundFilter : backgroundFilter,
viewInsets: viewInsets?.call(this.viewInsets) ?? this.viewInsets,
);