FPopoverControl.lifted constructor
const
FPopoverControl.lifted({
- required bool shown,
- required ValueChanged<
bool> onChange,
Creates a FPopoverControl for controlling a popover using lifted state.
The shown parameter indicates whether the popover is currently shown.
The onChange callback is invoked when the user triggers a show/hide action.
Implementation
const factory FPopoverControl.lifted({required bool shown, required ValueChanged<bool> onChange}) = _Lifted;