FPopoverStyle class
A FPopover's style.
- Implemented types
- Mixed-in types
- Implementers
- Available extensions
Constructors
- FPopoverStyle({required Decoration decoration, ImageFilter barrierFilter(double animation)?, ImageFilter backgroundFilter(double animation)?, EdgeInsetsGeometry popoverPadding = const .all(5)})
-
Creates a FPopoverStyle.
const
- FPopoverStyle.inherit({required FColors colors, required FStyle style})
- Creates a FPopoverStyle that inherits its properties.
Properties
- backgroundFilter → ImageFilter Function(double animation)?
-
An optional callback that takes the current animation transition value (0.0 to 1.0) and returns an ImageFilter
that is used as the background. Defaults to null.
final
- barrierFilter → ImageFilter Function(double animation)?
-
An optional callback that takes the current animation transition value (0.0 to 1.0) and returns an ImageFilter
that is used as the barrier. Defaults to null.
final
- decoration → Decoration
-
The popover's decoration.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- popoverPadding → EdgeInsetsGeometry
-
The additional padding between the edges of the view and the edges of the popover.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
covariant Object _) → FPopoverStyle -
Returns itself.
inherited
-
copyWith(
{DecorationDelta? decoration, ImageFilter barrierFilter(double)? = Sentinels.imageFilterFunction, ImageFilter backgroundFilter(double)? = Sentinels.imageFilterFunction, EdgeInsetsGeometryDelta? popoverPadding}) → FPopoverStyle -
Available on FPopoverStyle, provided by the $FPopoverStyleTransformations extension
Returns a copy of this FPopoverStyle with the given properties replaced. -
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
lerp(
FPopoverStyle other, double t) → FPopoverStyle -
Available on FPopoverStyle, provided by the $FPopoverStyleTransformations extension
Linearly interpolate between this and another FPopoverStyle using the given factort. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited