widgets/popover_menu library
A popover menu displays a menu in a portal aligned to a child.
See https://forui.dev/docs/overlay/popover-menu for working examples.
Classes
- FPopoverMenu
- A popover menu displays a menu in a portal aligned to a child.
- FPopoverMenuMotion
- Motion-related properties for the submenu fade effect in FPopoverMenu.
- FPopoverMenuMotionDelta
- A delta that applies modifications to a FPopoverMenuMotion.
- FPopoverMenuStyle
- A FPopoverMenuStyle's style.
- FPopoverMenuStyleDelta
- A delta that applies modifications to a FPopoverMenuStyle.
- An item that opens a nested popover menu.
- A tile that opens a nested popover menu to the side on tap.
Extensions
- $FPopoverMenuMotionTransformations on FPopoverMenuMotion
- Provides copyWith and lerp methods.
- $FPopoverMenuStyleTransformations on FPopoverMenuStyle
- Provides copyWith and lerp methods.