FPopoverMenuStyleDelta.delta constructor
const
FPopoverMenuStyleDelta.delta({
- FItemGroupStyleDelta? itemGroupStyle,
- FTileGroupStyleDelta? tileGroupStyle,
- double? maxWidth,
- DecorationDelta? decoration,
- ImageFilter Function(double)? barrierFilter()?,
- ImageFilter Function(double)? backgroundFilter()?,
- EdgeInsetsGeometryDelta? popoverPadding,
Creates a partial modification of a FPopoverMenuStyle.
Parameters
- FPopoverMenuStyle.itemGroupStyle - The item group's style.
- FPopoverMenuStyle.tileGroupStyle - The tile group's style.
- FPopoverMenuStyle.maxWidth - The menu's max width.
- FPopoverMenuStyle.decoration - The popover's decoration.
- FPopoverMenuStyle.barrierFilter - An optional callback that takes the current animation transition value (0.0 to 1.0) and returns an ImageFilter that is used as the barrier.
- FPopoverMenuStyle.backgroundFilter - An optional callback that takes the current animation transition value (0.0 to 1.0) and returns an ImageFilter that is used as the background.
- FPopoverMenuStyle.popoverPadding - The additional padding between the edges of the view and the edges of the popover.
Implementation
const factory FPopoverMenuStyleDelta.delta({
FItemGroupStyleDelta? itemGroupStyle,
FTileGroupStyleDelta? tileGroupStyle,
double? maxWidth,
DecorationDelta? decoration,
ImageFilter Function(double)? Function()? barrierFilter,
ImageFilter Function(double)? Function()? backgroundFilter,
EdgeInsetsGeometryDelta? popoverPadding,
}) = _FPopoverMenuStyleDelta;