FResizableRegion.flex constructor
const
FResizableRegion.flex({
- required ValueWidgetBuilder<
FResizableRegionData> builder, - int flex,
- int? minFlex,
- Widget? child,
- Key? key,
Creates a FResizableRegion that is sized proportionally from the remaining space.
flex determines the region's share of the remaining space after concrete-extent regions are placed. The parent
FResizable must have finite main-axis constraints.
minFlex constrains how small the region can be resized, expressed as a flex proportion.
Implementation
const factory FResizableRegion.flex({
required ValueWidgetBuilder<FResizableRegionData> builder,
int flex,
int? minFlex,
Widget? child,
Key? key,
}) = FlexResizableRegion;