FPersistentSheetStyle.inherit constructor
FPersistentSheetStyle.inherit()
Creates a FPersistentSheetStyle that inherits its properties from the given arguments.
Implementation
// This is needed because the CLI generator scans all style inherit constructors to generate the style mappings.
FPersistentSheetStyle.inherit() : this();