hapticFeedbackVelocity property
The minimum absolute per-frame drag delta, in pixels, required for FSliderHaptic.collision to fire when an active edge collides with the track's limit, the other thumb, or a minimum range extent.
Contract
Should be a non-negative finite number.
Implementation
final double hapticFeedbackVelocity;