collisionHapticFeedback property
The haptic feedback when the active edge collides with the track's limit, the other thumb, or a configured min range extent.
Defaults to FHapticFeedback.lightImpact. The minimum velocity is controlled by FSliderController.hapticFeedbackVelocity.
Implementation
@override
final Future<void> Function() collisionHapticFeedback;