FSwitchStyle class
FSwitch's style.
- Implemented types
- Mixed-in types
- Available extensions
Constructors
-
FSwitchStyle({required Color focusColor, required FVariants<
FSwitchVariantConstraint, FSwitchVariant, Color, Delta> trackColor, required FVariants<FSwitchVariantConstraint, FSwitchVariant, Color, Delta> thumbColor, required FLabelStyle leadingLabelStyle, required FLabelStyle trailingLabelStyle}) -
Creates a FSwitchStyle.
const
- FSwitchStyle.inherit({required FColors colors, required FStyle style})
-
Creates a FSwitchStyle that inherits its properties.
factory
Properties
- focusColor → Color
-
This FSwitch's color when focused.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- leadingLabelStyle → FLabelStyle
-
The label style when FSwitch.leadingLabel is true.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
thumbColor
→ FVariants<
FSwitchVariantConstraint, FSwitchVariant, Color, Delta> -
The thumb's color.
final
-
trackColor
→ FVariants<
FSwitchVariantConstraint, FSwitchVariant, Color, Delta> -
The track's color.
final
- trailingLabelStyle → FLabelStyle
-
The label style when FSwitch.leadingLabel is false (the default).
final
Methods
-
call(
covariant Object _) → FSwitchStyle -
Returns itself.
inherited
-
copyWith(
{Color? focusColor, FVariantsValueDelta< FSwitchVariantConstraint, FSwitchVariant, Color, Delta> ? trackColor, FVariantsValueDelta<FSwitchVariantConstraint, FSwitchVariant, Color, Delta> ? thumbColor, FLabelStyleDelta? leadingLabelStyle, FLabelStyleDelta? trailingLabelStyle}) → FSwitchStyle -
Available on FSwitchStyle, provided by the $FSwitchStyleTransformations extension
Returns a copy of this FSwitchStyle with the given properties replaced. -
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
lerp(
FSwitchStyle other, double t) → FSwitchStyle -
Available on FSwitchStyle, provided by the $FSwitchStyleTransformations extension
Linearly interpolate between this and another FSwitchStyle using the given factort. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited