expands property
Whether the tab content should expand to fill the remaining available space. Defaults to false.
When true, swipe gestures on touch devices and scroll wheel navigation on desktop switch between tabs. Use contentPhysics to customize or disable that interaction.
Contract
Throws an error if true and placed in a container with unbound height constraint, e.g. ListView.
Implementation
final bool expands;