FTileContentStyle class

A tile-specific FItemContentStyle.

Inheritance
Implemented types
Available extensions

Constructors

FTileContentStyle({required FVariants<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta> prefixIconStyle, required FVariants<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta> titleTextStyle, required FVariants<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta> subtitleTextStyle, required FVariants<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta> detailsTextStyle, required FVariants<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta> suffixIconStyle, EdgeInsetsGeometry padding = const EdgeInsets.fromLTRB(15, 13, 10, 13), double prefixIconSpacing = 10, double titleSpacing = 3, double middleSpacing = 4, double suffixIconSpacing = 5})
Creates a FTileContentStyle.
FTileContentStyle.inherit({required FColors colors, required FTypography typography, required Color prefix, required Color foreground, required Color mutedForeground})
Creates a FTileContentStyle that inherits its properties.
factory

Properties

detailsTextStyle FVariants<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
middleSpacing double
no setterinherited
padding EdgeInsetsGeometry
no setterinherited
prefixIconSpacing double
no setterinherited
prefixIconStyle FVariants<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitleTextStyle FVariants<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta>
no setterinherited
suffixIconSpacing double
no setterinherited
suffixIconStyle FVariants<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta>
no setterinherited
titleSpacing double
no setterinherited
titleTextStyle FVariants<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta>
no setterinherited

Methods

call(covariant Object _) FTileContentStyle
Returns itself.
inherited
copyWith({EdgeInsetsGeometryDelta? padding, FVariantsDelta<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta>? prefixIconStyle, double? prefixIconSpacing, FVariantsDelta<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta>? titleTextStyle, double? titleSpacing, FVariantsDelta<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta>? subtitleTextStyle, double? middleSpacing, FVariantsDelta<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta>? detailsTextStyle, FVariantsDelta<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta>? suffixIconStyle, double? suffixIconSpacing}) FItemContentStyle

Available on FItemContentStyle, provided by the $FItemContentStyleTransformations extension

Returns a copy of this FItemContentStyle with the given properties replaced.
copyWith({EdgeInsetsGeometryDelta? padding, FVariantsDelta<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta>? prefixIconStyle, double? prefixIconSpacing, FVariantsDelta<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta>? titleTextStyle, double? titleSpacing, FVariantsDelta<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta>? subtitleTextStyle, double? middleSpacing, FVariantsDelta<FTappableVariantConstraint, FTappableVariant, TextStyle, TextStyleDelta>? detailsTextStyle, FVariantsDelta<FTappableVariantConstraint, FTappableVariant, IconThemeData, IconThemeDataDelta>? suffixIconStyle, double? suffixIconSpacing}) FTileContentStyle

Available on FTileContentStyle, provided by the $FTileContentStyleTransformations extension

Returns a copy of this FTileContentStyle with the given properties replaced.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(FItemContentStyle other, double t) FItemContentStyle

Available on FItemContentStyle, provided by the $FItemContentStyleTransformations extension

Linearly interpolate between this and another FItemContentStyle using the given factor t.
lerp(FTileContentStyle other, double t) FTileContentStyle

Available on FTileContentStyle, provided by the $FTileContentStyleTransformations extension

Linearly interpolate between this and another FTileContentStyle using the given factor t.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited