FToastStyles extension type
The toast styles.
- on
- Implemented types
Constructors
-
FToastStyles(FVariants<
FToastVariantConstraint, FToastVariant, FToastStyle, FToastStyleDelta> _) - FToastStyles.inherit({required FColors colors, required FTypography typography, required FStyle style, required bool touch})
-
Creates a FToastStyles that inherits its properties.
factory
Properties
- base → FToastStyle
-
The base variant.
finalinherited
- destructive → FToastStyle
-
The destructive toast style.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- primary → FToastStyle
-
The primary toast style.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
variants
→ Map<
FToastVariantConstraint, FToastStyle> -
The variants.
finalinherited
Methods
-
apply(
List< FVariantOperation< operations) → FVariants<FToastVariantConstraint, FToastVariant, FToastStyle, FToastStyleDelta> >FToastVariantConstraint, FToastVariant, FToastStyle, FToastStyleDelta> -
Applies a sequence of delta-based
operationsto this FVariants.inherited -
applyValues(
List< FVariantValueDeltaOperation< operations) → FVariants<FToastVariantConstraint, FToastVariant, FToastStyle, FToastStyleDelta> >FToastVariantConstraint, FToastVariant, FToastStyle, FToastStyleDelta> -
Applies a sequence of value-based
operationsto this FVariants.inherited -
call(
covariant FVariants< FToastVariantConstraint, FToastVariant, FToastStyle, FToastStyleDelta> _) → FVariants<FToastVariantConstraint, FToastVariant, FToastStyle, FToastStyleDelta> -
Applies this delta to the given value.
inherited
-
cast<
T1 extends FVariantConstraint, T2 extends FVariant> () → FVariants< T1, T2, FToastStyle, FToastStyleDelta> -
Returns a new FVariants with the variant type parameters cast to
T1andT2.inherited -
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
Set< FVariant> variants) → FToastStyle -
Returns most specific matching variant, or base if no constraints match.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited