spacing property
The spacing between the tipAnchor and childAnchor. Defaults to FPortalSpacing(7).
Applied before overflow.
It is recommended that spacing be at least FPortalArrowStyle.height to prevent the arrow overlapping with the child when arrow is set.
Implementation
final FPortalSpacing spacing;