hoverExitDuration property

  1. @override
Duration hoverExitDuration
final

The duration to wait before hiding the tooltip after the user has stopped hovering over the target.

Defaults to Duration.zero.

Implementation

@override
final Duration hoverExitDuration;