hoverExitDuration property
The duration to wait before hiding the tooltip after the user has stopped hovering over the target.
Defaults to Duration.zero.
Implementation
@override
final Duration hoverExitDuration;
The duration to wait before hiding the tooltip after the user has stopped hovering over the target.
Defaults to Duration.zero.
@override
final Duration hoverExitDuration;